.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER USER" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
ALTER USER \- データベースロールを変更する

.SH SYNOPSIS
.sp
.nf
ALTER USER \fIname\fR [ [ WITH ] \fIoption\fR [ ... ] ]

\fIoption\fRは次の通りです。

      SUPERUSER | NOSUPERUSER
    | CREATEDB | NOCREATEDB
    | CREATEROLE | NOCREATEROLE
    | CREATEUSER | NOCREATEUSER
    | INHERIT | NOINHERIT
    | LOGIN | NOLOGIN
    | CONNECTION LIMIT \fIconnlimit\fR
    | [ ENCRYPTED | UNENCRYPTED ] PASSWORD '\fIpassword\fR'
    | VALID UNTIL '\fItimestamp\fR' 

ALTER USER \fIname\fR RENAME TO \fInewname\fR

ALTER USER \fIname\fR SET \fIconfiguration_parameter\fR { TO | = } { \fIvalue\fR | DEFAULT }
ALTER USER \fIname\fR RESET \fIconfiguration_parameter\fR
.sp
.fi
.SH "説明"
.PP
\fBALTER USER\fRはALTER ROLE [\fBalter_role\fR(l)]の別名になりました。
詳細はALTER ROLE [\fBalter_role\fR(l)]を参照してください。
.SH "互換性"
.PP
\fBALTER USER\fR文は、PostgreSQLの拡張です。 
標準SQLでは、ユーザの定義は実装に任されています。
.SH "関連項目"
ALTER ROLE [\fBalter_role\fR(l)]
