.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP OPERATOR CLASS" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
DROP OPERATOR CLASS \- 演算子クラスを削除する

.SH SYNOPSIS
.sp
.nf
DROP OPERATOR CLASS [ IF EXISTS ] \fIname\fR USING \fIindex_method\fR [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBDROP OPERATOR CLASS\fRは既存の演算子クラスを削除します。
このコマンドを実行するには、演算子クラスの所有者でなければなりません。
.SH "パラメータ"
.TP
\fBIF EXISTS\fR
演算子クラスが存在しない場合でもエラーになりません。
この場合注意メッセージが発行されます。
.TP
\fB\fIname\fB\fR
既存の演算子クラスの名前です（スキーマ修飾名も可）。
.TP
\fB\fIindex_method\fB\fR
この演算子クラスを使用するインデックスアクセスメソッドの名前です。
.TP
\fBCASCADE\fR
この演算子クラスに依存しているオブジェクトを自動的に削除します。
.TP
\fBRESTRICT\fR
依存しているオブジェクトがある場合に、その演算子クラスの削除を拒否します。
こちらがデフォルトです。
.SH "例"
.PP
widget_opsという名前のB-tree演算子クラスを削除します。
.sp
.nf
DROP OPERATOR CLASS widget_ops USING btree;
.sp
.fi
演算子クラスを使用するインデックスが存在する場合、このコマンドは実行できません。
このようなインデックスを演算子クラスとともに削除するには、CASCADEを指定します。
.SH "互換性"
.PP
標準SQLには\fBDROP OPERATOR CLASS\fRは存在しません。
.SH "関連項目"
ALTER OPERATOR CLASS [\fBalter_operator_class\fR(l)], CREATE OPERATOR CLASS [\fBcreate_operator_class\fR(l)]
