.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DECLARE" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
DECLARE \- カーソルを定義する

.SH SYNOPSIS
.sp
.nf
DECLARE \fIname\fR [ BINARY ] [ INSENSITIVE ] [ [ NO ] SCROLL ]
    CURSOR [ { WITH | WITHOUT } HOLD ] FOR \fIquery\fR
    [ FOR { READ ONLY | UPDATE [ OF \fIcolumn\fR [, ...] ] } ]
.sp
.fi
.SH "説明"
.PP
\fBDECLARE\fRを使うと、巨大な問い合わせの結果から一度に少数の行を取り出す機能であるカーソルが使用できるようになります。
FETCH [\fBfetch\fR(l)]を使うと、カーソルからテキスト形式またはバイナリ形式でデータを取り出すことができます。
.PP
通常のカーソルは、\fBSELECT\fRの出力と同じテキスト形式でデータを返します。
元のデータは固有のバイナリ形式で保存されているので、システムがテキスト形式を生成するためにデータを変換する必要があります。
情報がテキスト形式で返された後、クライアントアプリケーション側で情報を処理するためにバイナリ形式に変換しなければならないことがあります。
また、テキスト形式は、対応するバイナリ形式よりサイズが大きくなりがちです。
BINARYカーソルを使うと、データをバイナリ表現のまま返すことができ、この方が操作がより簡単になる可能性があります。
それでも、データをテキストとして表示する場合は、テキスト形式でデータを取り出すことにより、クライアント側の処理を軽減できます。
.PP
例えば、問い合わせが整数の列から値として1を返す場合、デフォルトのカーソルからは1という文字列を取得することになりますが、バイナリ形式のカーソルからは、内部表現を使った4バイトの値を取得することになります（バイトオーダはビッグエンディアン）。
.PP
バイナリ形式のカーソルは注意して使わなければなりません。
\fBpsql\fRなどの多くのアプリケーションは、データはテキスト形式で返されるものとみなしており、バイナリ形式のカーソルを扱うことができません。
.sp
.RS
.B "Note:"
クライアントアプリケーションが``拡張問い合わせ''プロトコルを使用して\fBFETCH\fRコマンドを発行する場合、テキスト形式とバイナリ形式のどちらでデータを受け取るのかは、バインドプロトコルメッセージで指定します。
この選択は、カーソル定義での指定を上書きします。
全てのカーソルをテキスト形式/バイナリ形式のどちらでも扱うことができる拡張問い合わせプロトコルでは、バイナリカーソルの概念はサポートされていません。
.RE
.sp
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
作成されるカーソルの名前です。
.TP
\fBBINARY\fR
カーソルによるデータの取得が、テキスト形式ではなくバイナリ形式になります。
.TP
\fBINSENSITIVE\fR
カーソルが存在する間、カーソルから取り出されたデータが背後にあるテーブルの更新の影響を受けないことを示します。
しかし、PostgreSQLでは、どのような場合であってもカーソルは更新の影響を受けません。
したがって、このキーワードを使用しても現在のところ効果はありません。このキーワードは、標準SQLとの互換性を保持するために存在しています。
.TP
\fBSCROLL\fR
.TP
\fBNO SCROLL\fR
SCROLLは、そのカーソルから通常の順序通りでない方法で（例えば後方から）行を取り出すことを指定します。
問い合わせの実行計画が複雑になると、SCROLLの指定によって問い合わせの実行時間が増大する可能性があります。
NO SCROLLは、そのカーソルから順序通りでない方法では行を取り出せないことを指定します。
デフォルトでは、いくつかの場合でスクロール可能です。
これはSCROLLの指定と同じではありません。
詳細は注釈 [\fBdeclare\fR(l)]を参照してください。
.TP
\fBWITH HOLD\fR
.TP
\fBWITHOUT HOLD\fR
WITH HOLDは、カーソルを生成したトランザクションが正常にコミット処理を行った後も、そのカーソルの使用を続けられることを指定します。
WITHOUT HOLDは、カーソルを生成したトランザクションの外部では、そのカーソルを使用できないことを指定します。
WITH HOLDもWITHOUT HOLDも指定されない場合、WITHOUT HOLDがデフォルトとなります。
.TP
\fB\fIquery\fB\fR
カーソルによって返される行を提供するSELECT [\fBselect\fR(l)]またはVALUES [\fBvalues\fR(l)]コマンドです。
.TP
\fBFOR READ ONLY\fR
.TP
\fBFOR UPDATE\fR
FOR READ ONLYは、カーソルが読み取り専用モードで使用されることを示します。
FOR UPDATEは、カーソルがテーブルを更新するために使用されることを示します。
現時点では、PostgreSQLはカーソルでの更新をサポートしていません。したがって、FOR UPDATEを指定するとエラーメッセージが表示されます。また、FOR READ ONLYを指定しても効果はありません。
.TP
\fB\fIcolumn\fB\fR
カーソルによって更新される列（複数可）です。
現時点では、PostgreSQLはカーソルでの更新をサポートしていません。したがって、FOR UPDATE句を指定するとエラーメッセージが表示されます。
.PP
BINARY、INSENSITIVE、SCROLLキーワードは任意の順番で指定することができます。
.PP
.SH "注釈"
.PP
WITH HOLDが指定されなければ、このコマンドで生成されるカーソルは現在のトランザクションの中でのみ使用することができます。
したがって、WITH HOLDのない\fBDECLARE\fRはトランザクションブロックの外側では意味がありません。
その場合、カーソルはこの文が完了するまでのみ有効です。
そのため、PostgreSQLはトランザクションブロックの外部でこのコマンドが使用された場合エラーを報告します。
トランザクションブロックを定義するには、BEGIN [\fBbegin\fR(l)]、COMMIT [\fBcommit\fR(l)]、ROLLBACK [\fBrollback\fR(l)]を使用してください。
.PP
WITH HOLDが指定された場合、カーソルを作成したトランザクションのコミットに成功していても、同一セッション内のその後のトランザクションからそのカーソルにアクセスすることができます
（ただし、トランザクションがアボートされた場合、そのカーソルは削除されます）。
WITH HOLD付きで作成されたカーソルは、そのカーソルに対して明示的な\fBCLOSE\fRが発行された場合やセッションが終了した時に閉じられます。
現在の実装では、保持されたカーソルを使って表される行は、その後のトランザクションでも利用できるように、一時ファイルかメモリ領域にコピーされます。
.PP
カーソルから逆方向にデータを取り出す時には、SCROLLオプションを指定しなければなりません。
これは標準SQLでは必須となっています。
しかし、以前のバージョンとの互換性を保持するために、PostgreSQLでは、カーソルの問い合わせ計画が単純であり、そのサポートに余計なオーバーヘッドが必要ない場合、 SCROLLなしでも逆方向にデータを取り出すことができます。
しかし、SCROLLを付けなくても逆方向にデータが取り出せることを利用してアプリケーションを開発するのはお勧めしません。
NO SCROLLを指定した場合は、どのような場合でも逆方向に取り出すことはできません。
.PP
標準SQLでは、組み込みSQLにおけるカーソルのみが規定されています。
PostgreSQLサーバはカーソル用の\fBOPEN\fR文を実装していません。
カーソルは宣言された時に開いたものとみなされています。
しかし、PostgreSQL用の埋め込みSQLプリプロセッサである\fBECPG\fRでは、\fBDECLARE\fRと\fBOPEN\fR文などを含め、標準SQLのカーソル規定をサポートしています。
.PP
\fBpg_cursors\fRシステムビューを問い合わせることで、利用可能なすべてのカーソルを確認することができます。
.SH "例"
.PP
カーソルを宣言します。
.sp
.nf
DECLARE liahona CURSOR FOR SELECT * FROM films;
.sp
.fi
カーソル使用のより多くの例についてはFETCH [\fBfetch\fR(l)]を参照してください。
.SH "互換性"
.PP
標準SQLでは、カーソルを埋め込みSQL内とモジュール内でのみ使用できます。
PostgreSQLでは、対話式にカーソルを使うことができます。
.PP
標準SQLでは、カーソルを使ってデータベースのデータを更新することができます。
全てのPostgreSQLのカーソルは読み取り専用です。 
.PP
バイナリカーソルはPostgreSQLの拡張です。
.SH "関連項目"
CLOSE [\fBclose\fR(l)], FETCH [\fBfetch\fR(l)], MOVE [\fBmove\fR(l)]
