.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ROLLBACK TO SAVEPOINT" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
ROLLBACK TO SAVEPOINT \- セーブポイントまでロールバックする

.SH SYNOPSIS
.sp
.nf
ROLLBACK [ WORK | TRANSACTION ] TO [ SAVEPOINT ] \fIsavepoint_name\fR
.sp
.fi
.SH "説明"
.PP
セーブポイントの設定後に実行されたコマンドを全てロールバックします。
セーブポイントは有効なまま残るので、必要に応じて、その後再度ロールバックすることができます。
.PP
\fBROLLBACK TO SAVEPOINT\fRは、指定したセーブポイントより後に設定した全てのセーブポイントを暗黙的に破棄します。
.SH "パラメータ"
.TP
\fB\fIsavepoint_name\fB\fR
ロールバック先のセーブポイントです。
.SH "注釈"
.PP
セーブポイントの設定後に実行されたコマンドの結果を維持したままセーブポイントを破棄するには、RELEASE SAVEPOINT [\fBrelease_savepoint\fR(l)]を使用してください。
.PP
設定されていないセーブポイントの名前を指定するとエラーになります。
.PP
カーソルはセーブポイントという観点から見るとトランザクションの外にあるかのように振舞います。
セーブポイントの内部で開かれたカーソルは全て、そのセーブポイントがロールバックした時に閉ざされます。
セーブポイントの前に開かれたカーソルに対し\fBFETCH\fRコマンドを実行した場合、その後、セーブポイントまでロールバックされたとしても、カーソルの位置は\fBFETCH\fRの結果、移動した位置から変わりません
（つまり\fBFETCH\fRはロールバックされません）。
また、カーソルのクローズはロールバックしても取り消すことはできません。
カーソルの実行によってトランザクションのアボートが引き起こされた場合、そのカーソルは実行不可能状態に遷移します。
この場合、トランザクションは\fBROLLBACK TO SAVEPOINT\fRを使用して戻すことができますが、そのカーソルは使用することができません。
.SH "例"
.PP
my_savepointの設定後に実行されたコマンドの効果を取り消します。
.sp
.nf
ROLLBACK TO SAVEPOINT my_savepoint;
.sp
.fi
.PP
セーブポイントへのロールバックは、カーソル位置に影響を与えません。
.sp
.nf
BEGIN;

DECLARE foo CURSOR FOR SELECT 1 UNION SELECT 2;

SAVEPOINT foo;

FETCH 1 FROM foo;
 ?column? 
----------
        1

ROLLBACK TO SAVEPOINT foo;

FETCH 1 FROM foo;
 ?column? 
----------
        2

COMMIT;
.sp
.fi
.SH "互換性"
.PP
標準SQLでは、SAVEPOINTキーワードは必須です。
しかし、PostgreSQLとOracleでは省略することができます。
SQLで使用できるのは、WORKのみです。
TRANSACTIONは使用できず、ROLLBACKの後のノイズワードとして扱われます。
また、SQLでは省略可能なAND [ NO ] CHAIN句がありますが、これはPostgreSQLでは現在サポートされていません。
その他については、このコマンドは標準SQLと互換性を持ちます。
.SH "関連項目"
BEGIN [\fBbegin\fR(l)], COMMIT [\fBcommit\fR(l)], RELEASE SAVEPOINT [\fBrelease_savepoint\fR(l)], ROLLBACK [\fBrollback\fR(l)], SAVEPOINT [\fBsavepoint\fR(l)]
