.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP TRIGGER" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
DROP TRIGGER \- トリガを削除する

.SH SYNOPSIS
.sp
.nf
DROP TRIGGER [ IF EXISTS ] \fIname\fR ON \fItable\fR [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBDROP TRIGGER\fRは既存のトリガ定義を削除します。
このコマンドを実行できるのは、トリガが定義されたテーブルの所有者のみです。
.SH "パラメータ"
.TP
\fBIF EXISTS\fR
トリガが存在しない場合でもエラーになりません。この場合注意メッセージが発行されます。
.TP
\fB\fIname\fB\fR
削除するトリガの名前です。
.TP
\fB\fItable\fB\fR
トリガが定義されたテーブルの名前です（スキーマ修飾名も可）。
.TP
\fBCASCADE\fR
このトリガに依存しているオブジェクトを自動的に削除します。
.TP
\fBRESTRICT\fR
依存しているオブジェクトがある場合に、トリガの削除を拒否します。
こちらがデフォルトです。
.SH "例"
.PP
filmsテーブルにあるif_dist_existsというトリガを削除します。
.sp
.nf
DROP TRIGGER if_dist_exists ON films;
.sp
.fi
.SH "互換性"
.PP
PostgreSQLの\fBDROP TRIGGER\fR文には標準SQLとの互換性がありません。
標準SQLでは、トリガ名がテーブルに局所化されていないので、DROP TRIGGER \fIname\fRというコマンドが使われています。
.SH "関連項目"
CREATE TRIGGER [\fBcreate_trigger\fR(l)]
