.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CREATE LANGUAGE" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
CREATE LANGUAGE \- 新しい手続き言語を定義する

.SH SYNOPSIS
.sp
.nf
CREATE [ PROCEDURAL ] LANGUAGE \fIname\fR
CREATE [ TRUSTED ] [ PROCEDURAL ] LANGUAGE \fIname\fR
    HANDLER \fIcall_handler\fR [ VALIDATOR \fIvalfunction\fR ]
.sp
.fi
.SH "説明"
.PP
PostgreSQLユーザは、\fBCREATE LANGUAGE\fRを使って新しい手続き言語をPostgreSQLデータベースに登録することができます。
これにより、関数とトリガプロシージャを新しい言語で定義できるようになります。
新しい言語を登録するには、PostgreSQLのスーパーユーザ権限を持っていなければいけません。
.PP
\fBCREATE LANGUAGE\fRは、言語名とその言語で作成された関数の実行に責任を持つ呼び出しハンドラを、効率的に関連付けます。
言語呼び出しハンドラについての詳細は、in the documentationを参照してください。
.PP
\fBCREATE LANGUAGE\fRコマンドには2種類の形式があります。
最初の形式は、ユーザは必要な言語の名前のみを単に指定するものです。
この場合、PostgreSQLサーバは\fBpg_pltemplate\fRシステムカタログを参照し、正しいパラメータを決定します。
2番目の形式では、ユーザは言語名の他に言語のパラメータも入力します。
この形式で、\fBpg_pltemplate\fRで定義されていない言語を作成することができますが、この手法は廃棄予定です。
.PP
指定された言語名に対応する\fBpg_pltemplate\fRカタログの項目をサーバが見つけると、コマンドに言語のパラメータが含まれていたとしてもカタログのデータを使用します。
この動作により、古すぎる言語のサポート関数に関する情報を含む、古いダンプファイルからの読み込みが簡単になります。
.SH "パラメータ"
.TP
\fBTRUSTED\fR
TRUSTEDは、その言語の呼び出しハンドラが安全であることを指定します。
安全であるとは、権限を持たないユーザにはアクセス制限を無視する機能を一切与えないということです。
言語の登録時にこのキーワードを省略すると、PostgreSQLのスーパーユーザ権限を持つユーザのみが、この言語を使って新しい関数を作れるようになります。
.TP
\fBPROCEDURAL\fR
これはノイズワードです。
.TP
\fB\fIname\fB\fR
新しい手続き言語の名前です。
言語名は大文字/小文字の区別がありません。
この名前はデータベースの言語の中で一意でなければなりません。

後方互換を保持するため、この名前を単一引用符で囲むこともできます。
.TP
\fBHANDLER \fIcall_handler\fB\fR
\fIcall_handler\fRは手続き言語の関数を実行するために呼び出される関数の名前で、事前に登録しておく必要があります。
このハンドラは、Version-1呼び出し規約に則って、C言語のようなコンパイル言語で書かれている必要があります。また、引数を取らず\fBlanguage_handler\fR型を返す関数として、PostgreSQLに登録されていなければなりません。
\fBlanguage_handler\fR型は、単に関数を呼び出しハンドラとして識別するのに使用するプレースホルダ型です。
.TP
\fBVALIDATOR \fIvalfunction\fB\fR
\fIvalfunction\fRは、事前に登録された検証用関数の名前です。新しい関数が当該言語で作成された場合、その関数を検証するために呼び出されます。 
検証用関数が指定されていない場合、新しい関数は作成時にチェックされません。
検証用関数は、\fBoid\fR型の引数を1つ取る必要があります。
この引数は作成される関数のOIDになります。
また、通常\fBvoid\fR型を返します。

検証用関数は、通常、関数本体が構文上正しいかどうかを検査するために使用されます。
しかし、それだけでなく、関数のプロパティも検査可能です。例えば、その言語が処理できない特定のデータ型が引数に含まれていないかなどがチェックできます。
エラーを通知するには、検証用関数で\fBereport()\fR関数を使用すべきです。
関数の戻り値は無視されます。
.PP
サーバが指定した言語名に対応する\fBpg_pltemplate\fRの項目を見つけた場合、TRUSTEDオプションとサポート関数名は無視されます。
.PP
.SH "注釈"
.PP
\fBcreatelang\fR(1)は\fBCREATE LANGUAGE\fRに対する簡単なラッパプログラムです。
これを使用して簡単にシェルコマンドラインから手続き言語をインストールすることができます。
.PP
手続き言語を削除するには、DROP LANGUAGE [\fBdrop_language\fR(l)]、または\fBdroplang\fR(1)を使用してください（後者を勧めます）。
.PP
システムカタログ\fBpg_language\fR（ in the documentation参照）には、現在インストールされている言語に関する情報が記録されています。
また、\fBcreatelang\fRにはインストールされた言語を列挙するオプションがあります。
.PP
手続き言語で関数を作成するには、ユーザはその言語に対するUSAGE権限を持たなければなりません。
デフォルトでは、信頼された言語のUSAGEはPUBLICに（つまり全員に）付与されています。
これは必要に応じて取り除くことができます。
.PP
手続き言語は各データベースに局所的です。
しかし、言語をtemplate1データベースにインストールすることができます。
この場合、その後に作成されたすべてのデータベースで自動的にその言語は使用できるようになります。
.PP
呼び出しハンドラ関数と検証関数（もしあれば）は、サーバが\fBpg_pltemplate\fR内にその言語に関する項目を持っていない場合には、存在しなければなりません。
しかし、その項目があったとしても、関数がすでに存在しているとは限りません。
データベース内に存在していなければ自動的に定義されます。
（言語を実装する共有ライブラリがインストレーションで利用できない場合、これにより\fBCREATE LANGUAGE\fRが失敗する可能性があります。）
.PP
PostgreSQL 7.3より前のバージョンでは、ハンドラ関数が返すプレースホルダ型を\fBlanguage_handler\fR型ではなく\fBopaque\fR型と宣言する必要がありました。
古いダンプファイルのロードをサポートするために、\fBCREATE LANGUAGE\fRは\fBopaque\fR型を返すと宣言された関数を受け入れます。
しかし、注意を促すメッセージを表示し、宣言された関数の戻り値型を\fBlanguage_handler\fRに変換します。
.SH "例"
.PP
標準的な手続き言語を作成する推奨方法は単に以下のように行うことです。
.sp
.nf
CREATE LANGUAGE plpgsql;
.sp
.fi
.PP
\fBpg_pltemplate\fRカタログ内に存在しない言語では、以下のような処理が必要です。
.sp
.nf
CREATE FUNCTION plsample_call_handler() RETURNS language_handler
    AS '$libdir/plsample'
    LANGUAGE C;
CREATE LANGUAGE plsample
    HANDLER plsample_call_handler;
.sp
.fi
.SH "互換性"
.PP
\fBCREATE LANGUAGE\fRはPostgreSQLの拡張です。
.SH "関連項目"
ALTER LANGUAGE [\fBalter_language\fR(l)], CREATE FUNCTION [\fBcreate_function\fR(l)], DROP LANGUAGE [\fBdrop_language\fR(l)], GRANT [\fBgrant\fR(l)], REVOKE [\fBrevoke\fR(l)], createlang [\fBcreatelang\fR(1)], droplang [\fBdroplang\fR(1)]
