.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP TABLESPACE" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
DROP TABLESPACE \- テーブル空間を削除する

.SH SYNOPSIS
.sp
.nf
DROP TABLESPACE [ IF EXISTS ] \fItablespacename\fR
.sp
.fi
.SH "説明"
.PP
\fBDROP TABLESPACE\fRはシステムからテーブル空間を削除します。
.PP
テーブル空間を削除できるのは、その所有者もしくはスーパーユーザのみです。
テーブル空間を削除する前に、全てのデータベースオブジェクトが空になっていなければなりません。
現在のデータベース内のオブジェクトが使用していなかったとしても、他のデータベース内のオブジェクトがそのテーブル空間上にあることがあります。
.SH "パラメータ"
.TP
\fBIF EXISTS\fR
テーブル空間が存在しない場合でもエラーになりません。
この場合注意メッセージが発行されます。
.TP
\fB\fItablespacename\fB\fR
テーブル空間の名前です。
.SH "注釈"
.PP
トランザクションブロック内で\fBDROP TABLESPACE\fRを実行することはできません。
.SH "例"
.PP
mystuffテーブル空間をシステムから削除します。
.sp
.nf
DROP TABLESPACE mystuff;
.sp
.fi
.SH "互換性"
.PP
\fBDROP TABLESPACE\fRはPostgreSQLの拡張です。
.SH "関連項目"
CREATE TABLESPACE [\fBcreate_tablespace\fR(l)], ALTER TABLESPACE [\fBalter_tablespace\fR(l)]
