.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "COMMIT" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
COMMIT \- 現在のトランザクションをコミットする

.SH SYNOPSIS
.sp
.nf
COMMIT [ WORK | TRANSACTION ]
.sp
.fi
.SH "説明"
.PP
\fBCOMMIT\fRは現在のトランザクションをコミットします。
そのトランザクションで行われた全ての変更が他のユーザから見えるようになり、クラッシュが起きても一貫性が保証されるようになります。
.SH "パラメータ"
.TP
\fBWORK\fR
.TP
\fBTRANSACTION\fR
省略可能なキーワードです。何も効果はありません。
.SH "注釈"
.PP
トランザクションをアボートするにはROLLBACK [\fBrollback\fR(l)]を使用してください。
.PP
トランザクションの外部で\fBCOMMIT\fRを発行しても特に問題は発生しません。
ただし、警告メッセージが表示されます。
.SH "例"
.PP
現在のトランザクションをコミットし、全ての変更を永続化します。
.sp
.nf
COMMIT;
.sp
.fi
.SH "互換性"
.PP
標準SQLが規定しているのは、COMMITとCOMMIT WORKという2つの構文のみです。
その他の点は完全な互換性があります。
.SH "関連項目"
BEGIN [\fBbegin\fR(l)], ROLLBACK [\fBrollback\fR(l)]
