.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP AGGREGATE" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
DROP AGGREGATE \- 集約関数を削除する

.SH SYNOPSIS
.sp
.nf
DROP AGGREGATE [ IF EXISTS ] \fIname\fR ( \fItype\fR [ , ... ] ) [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBDROP AGGREGATE\fRを実行すると、既存の集約関数定義を削除することができます。
このコマンドを実行するには、現在のユーザがその集約関数を所有している必要があります。
.SH "パラメータ"
.TP
\fBIF EXISTS\fR
集約が存在しない場合でもエラーになりません。
この場合注意メッセージが発行されます。
.TP
\fB\fIname\fB\fR
既存の集約関数の名前です（スキーマ修飾名も可）。
.TP
\fB\fItype\fB\fR
集約関数の操作対象となる入力データ型です。
引数を持たない関数を参照する場合は、入力データ型の一覧の場所に*を記述してください。
.TP
\fBCASCADE\fR
その集約関数に依存しているオブジェクトを自動的に削除します。
.TP
\fBRESTRICT\fR
依存しているオブジェクトがある場合、その集約関数の削除要求を拒否します。
こちらがデフォルトです。
.SH "例"
.PP
integer型のmyavg集約関数を削除します。
.sp
.nf
DROP AGGREGATE myavg(integer);
.sp
.fi
.SH "互換性"
.PP
標準SQLには、\fBDROP AGGREGATE\fR文はありません。 
.SH "関連項目"
ALTER AGGREGATE [\fBalter_aggregate\fR(l)], CREATE AGGREGATE [\fBcreate_aggregate\fR(l)]
