.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER SCHEMA" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
ALTER SCHEMA \- スキーマ定義を変更する

.SH SYNOPSIS
.sp
.nf
ALTER SCHEMA \fIname\fR RENAME TO \fInewname\fR
ALTER SCHEMA \fIname\fR OWNER TO \fInewowner\fR
.sp
.fi
.SH "説明"
.PP
\fBALTER SCHEMA\fRはスキーマ定義を変更します。
.PP
\fBALTER SCHEMA\fRを使用するにはスキーマの所有者でなければなりません。
スキーマ名を変更するには、そのデータベースのCREATE権限を持たなければなりません。
所有者を変更するには、直接または間接的に新しい所有者ロールのメンバでなければなりません。
また、そのロールがデータベースにおいてCREATEを持たなければなりません。
（スーパーユーザがこれらの権限をすべて自動的に持つことに注意してください。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
既存のスキーマの名前です。
.TP
\fB\fInewname\fB\fR
新しいスキーマの名前です。
pg_から始まる名前は、システムスキーマとして予約されているため使用することができません。
.TP
\fB\fInewowner\fB\fR
新しいスキーマの所有者です。
.SH "互換性"
.PP
標準SQLには\fBALTER SCHEMA\fR文はありません。
.SH "関連項目"
CREATE SCHEMA [\fBcreate_schema\fR(l)], DROP SCHEMA [\fBdrop_schema\fR(l)]
