.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP OWNED" "" "2007-05-04" "SQL言語" "SQLコマンド"
.SH NAME
DROP OWNED \- データベースロールにより所有されるデータベースオブジェクトを削除します。

.SH SYNOPSIS
.sp
.nf
DROP OWNED BY \fIname\fR [, ...] [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBDROP OWNED\fRは、現在のデータベース内にある、指定したロールが所有するオブジェクトをすべて削除します。
また、現在のデータベース内にあるオブジェクトに対して指定したロールに与えられた権限も取り上げられます。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
所有するオブジェクトを削除し、その権限が取り上げられるロールの名称です。
.TP
\fBCASCADE\fR
関連するオブジェクトに依存するオブジェクトを自動的に削除します。
.TP
\fBRESTRICT\fR
他のデータベースオブジェクトが関連オブジェクトに依存する場合、ロールにより所有されるオブジェクトの削除を取りやめます。
これがデフォルトです。
.SH "注釈"
.PP
\fBDROP OWNED\fRはよく、複数ロールの削除の前処理として使用されます。
\fBDROP OWNED\fRは現在のデータベース内のオブジェクトにのみ影響しますので、このコマンドを通常、削除予定のロールが所有するオブジェクトを持つデータベース毎に実行する必要があります。
.PP
CASCADEオプションを使用することで、このコマンドで再帰的に他のユーザが所有するオブジェクトを処理することができます。
.PP
REASSIGN OWNED [\fBreassign_owned\fR(l)]コマンドは、複数のロールが所有するすべてのデータベースオブジェクトの所有権を再割り当てする、別の方法です。
.SH "互換性"
.PP
\fBDROP OWNED\fR文はPostgreSQLの拡張です。
.SH "関連項目"
REASSIGN OWNED [\fBreassign_owned\fR(l)], DROP ROLE [\fBdrop_role\fR(l)]
