.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CREATE TABLE" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
CREATE TABLE \- 新しいテーブルを定義する

.SH SYNOPSIS
.sp
.nf
CREATE [ [ GLOBAL | LOCAL ] { TEMPORARY | TEMP } ] TABLE \fItable_name\fR ( [
  { \fIcolumn_name\fR \fIdata_type\fR [ DEFAULT \fIdefault_expr\fR ] [ \fIcolumn_constraint\fR [ ... ] ]
    | \fItable_constraint\fR
    | LIKE \fIparent_table\fR [ { INCLUDING | EXCLUDING } { DEFAULTS | CONSTRAINTS } ] ... }
    [, ... ]
] )
[ INHERITS ( \fIparent_table\fR [, ... ] ) ]
[ WITH ( \fIstorage_parameter\fR [= \fIvalue\fR] [, ... ] ) | WITH OIDS | WITHOUT OIDS ]
[ ON COMMIT { PRESERVE ROWS | DELETE ROWS | DROP } ]
[ TABLESPACE \fItablespace\fR ]

\fIcolumn_constraint\fRには、次の構文が入ります。

[ CONSTRAINT \fIconstraint_name\fR ]
{ NOT NULL | 
  NULL | 
  UNIQUE \fIindex_parameters\fR |
  PRIMARY KEY \fIindex_parameters\fR |
  CHECK ( \fIexpression\fR ) |
  REFERENCES \fIreftable\fR [ ( \fIrefcolumn\fR ) ] [ MATCH FULL | MATCH PARTIAL | MATCH SIMPLE ]
    [ ON DELETE \fIaction\fR ] [ ON UPDATE \fIaction\fR ] }
[ DEFERRABLE | NOT DEFERRABLE ] [ INITIALLY DEFERRED | INITIALLY IMMEDIATE ]

また、\fItable_constraint\fRには、次の構文が入ります。

[ CONSTRAINT \fIconstraint_name\fR ]
{ UNIQUE ( \fIcolumn_name\fR [, ... ] ) \fIindex_parameters\fR |
  PRIMARY KEY ( \fIcolumn_name\fR [, ... ] ) \fIindex_parameters\fR |
  CHECK ( \fIexpression\fR ) |
  FOREIGN KEY ( \fIcolumn_name\fR [, ... ] ) REFERENCES \fIreftable\fR [ ( \fIrefcolumn\fR [, ... ] ) ]
    [ MATCH FULL | MATCH PARTIAL | MATCH SIMPLE ] [ ON DELETE \fIaction\fR ] [ ON UPDATE \fIaction\fR ] }
[ DEFERRABLE | NOT DEFERRABLE ] [ INITIALLY DEFERRED | INITIALLY IMMEDIATE ]

UNIQUEおよびPRIMARY KEY制約内の\fIindex_parameters\fRは以下の通りです。

[ WITH ( \fIstorage_parameter\fR [= \fIvalue\fR] [, ... ] ) ]
[ USING INDEX TABLESPACE \fItablespace\fR ]
.sp
.fi
.SH "説明"
.PP
\fBCREATE TABLE\fRは、現在のデータベースに新しい空のテーブルを作成します。
作成したテーブルはこのコマンドを実行したユーザが所有します。
.PP
スキーマ名が付けられている場合（例えば、CREATE TABLE myschema.mytable ...）、テーブルは指定されたスキーマで作成されます。
スキーマ名がなければ、テーブルは現在のスキーマで作成されます。
また、一時テーブルは特別なスキーマに存在するため、一時テーブルの作成時にスキーマ名を与えることはできません。
テーブル名は、同じスキーマ内の他のテーブル、シーケンス、インデックス、ビューとは異なる名前にする必要があります。
.PP
さらに、\fBCREATE TABLE\fRは、作成するテーブルの1行に対応する複合型のデータ型を作成します。
したがって、テーブルは、同じスキーマ内の既存のデータ型と同じ名前を持つことができません。
.PP
制約句には、挿入、更新操作を行うために、新しい行、または更新する行が満たさなければならない制約（検査項目）を指定します。制約句は省略可能です。
制約は、テーブル内で様々な有効な値の集合を定義する際、役に立つSQLオブジェクトです。
.PP
制約の定義にはテーブル制約と列制約という2種類があります。
列制約は列定義の一部として定義されます。
テーブル制約定義は、特定の列とは結びつけられておらず、複数の列を含有することができます。
また、全ての列制約はテーブル制約として記述することができます。
列制約は、1つの列にのみ影響する制約のための、簡便な記述方法に過ぎません。
.SH "パラメータ"
.TP
\fBTEMPORARY or TEMP\fR
このパラメータが指定された場合、テーブルは一時テーブルとして作成されます。
一時テーブルは、そのセッションの終わり、場合によっては、現在のトランザクションの終わり（後述のON COMMITを参照）に自動的に削除されます。
一時テーブルが存在する場合、同じ名前を持つ既存の永続テーブルは、スキーマ修飾名で参照されていない限り、現在のセッションでは非可視になります。
一時テーブルで作られるインデックスも、全て自動的に一時的なものとなります。

GLOBALまたはLOCALをTEMPORARYやTEMPの前に記述することができます（省略可能）。
PostgreSQLでは、これらを指定しても動作の違いはありません。
互換性 [\fBcreate_table\fR(l)]を参照してください。
.TP
\fB\fItable_name\fB\fR
作成するテーブルの名前です（スキーマ修飾名でも可）。
.TP
\fB\fIcolumn_name\fB\fR
新しいテーブルで作成される列の名前です。
.TP
\fB\fIdata_type\fB\fR
列のデータ型です。
これには、配列指定子が含まれる場合があります。
PostgreSQLでサポートされるデータ型の情報に関する詳細はin the documentationを参照してください。
.TP
\fBDEFAULT\fR
DEFAULT句を列定義に付けると、その列にデフォルトデータ値が割り当てられます。
値として指定するのは、任意の無変数式です（副問い合わせと現在のテーブル内の他の列へ交差参照は許可されません）。
デフォルト式のデータ型はその列のデータ型と一致する必要があります。

デフォルト式は、全ての挿入操作において、その列に値が指定されていない場合に使用されます。
列にデフォルト値がない場合、デフォルト値はNULLになります。
.TP
\fBINHERITS ( \fIparent_table\fB [, ... ] )\fR
INHERITS句でテーブルの一覧を指定すると、新しいテーブルは指定されたテーブルの全ての列を自動的に継承します。この句は省略可能です。

INHERITSを使用すると、新しい子テーブルとその親テーブル（複数可）との間に永続的な関連が作成されます。
通常、親へのスキーマ修飾子は同様に子にも伝播します。また、デフォルトでは、親テーブルの走査結果には子テーブルのデータが含まれます。

複数の親テーブルに同一名の列が存在する場合、それらのデータ型が一致していなければ、エラーとして報告されます。
競合がなければ、これらの重複した列は新しいテーブルで1つの列の形に融合されます。
新しいテーブルの列名の一覧に継承する列の名前が含まれる場合も、そのデータ型は継承する列のデータ型と一致していなければなりません。さらに、その列定義は1つに融合されます。
しかし、同一名称の新しい列の宣言内で、継承する列と同一の制約を指定する必要はありません。
任意の宣言で提供される制約は、まとめてマージされ、全てが新しいテーブルに適用されます。
新しいテーブルで明示的に列のデフォルト値を指定した場合、継承した列宣言における全てのデフォルト値は上書きされます。
デフォルト値を指定しなかった場合、親側でデフォルト値が指定されている時は、それらのデフォルト値が全て同じ値でなければなりません。
値が違う場合はエラーになります。
.TP
\fBLIKE \fIparent_table\fB [ { INCLUDING | EXCLUDING } { DEFAULTS | CONSTRAINTS } ]\fR
LIKE句にテーブルを指定すると、自動的にそのテーブルの全ての列名、そのデータ型、非NULL制約が新しいテーブルにコピーされます。

INHERITSとの違いは、作成した後、新しいテーブルと元のテーブルが完全に分離されることです。
元のテーブルへの変更は新しいテーブルには適用されません。また、元のテーブルを操作しても新しいテーブルのデータは見つかりません。

コピーする列のデフォルト式は、INCLUDING DEFAULTSが指定された場合にのみコピーされます。
デフォルトでは、デフォルト式がコピーされないため、新しいテーブルのコピーされた列はデフォルト値としてNULLを持つことになります。

非NULL制約は常に新しいテーブルにコピーされます。
CHECK制約は、INCLUDING CONSTRAINTSが指定された場合にのみコピーされます。
他の種類の制約は決してコピーされません。
また、列制約とテーブル制約とを区別しません。
制約が要求される場合は、すべての検査制約がコピーされます。

また、INHERITSと異なり、同じ名前の列や制約を持つ場合、コピーされた列と制約はまとめられません。
同じ名前が明示的に、あるいは他のLIKE句で指定された場合、エラーが通知されます。
.TP
\fBCONSTRAINT \fIconstraint_name\fB\fR
省略可能な列制約、テーブル制約の名前です。
もし、この制約に違反すると、制約名がエラーメッセージに含まれるようになります。
ですので、col must be positive(正数でなければならない)といった名前の制約名を付与することで、クライアントアプリケーションへ有用な制約情報を渡すことができます。
（空白を含む制約名を指定する場合、二重引用符が必要です。）
指定されなければ、システムが名前を生成します。
.TP
\fBNOT NULL\fR
その列がNULL値を持てないことを指定します。
.TP
\fBNULL\fR
その列がNULL値を持てることを指定します。
これがデフォルトです。

この句は非標準的なSQLデータベースとの互換性のためだけに提供されています。
新しいアプリケーションでこれを使用するのはお勧めしません。
.TP
\fBUNIQUE （列制約）\fR
.TP
\fBUNIQUE ( \fIcolumn_name\fB [, ... ] ) （表制約）\fR
UNIQUE制約は、テーブルの1つまたは複数の列からなるグループが、一意な値のみ持つことを指定します。
一意性テーブル制約の動作は一意性列制約と同じですが、さらに複数列にまたがる機能を持ちます。

一意性制約では、NULL値は等しいとはみなされなせん。

それぞれの一意性テーブル制約には、そのテーブルの他の一意性制約もしくはプライマリキー制約によって名付けられた列の集合とは、異なる名前の列の集合を指定しなければなりません
（同じ名前を指定すると、同じ制約が2回現れるだけになります）。
.TP
\fBPRIMARY KEY （列制約）\fR
.TP
\fBPRIMARY KEY ( \fIcolumn_name\fB [, ... ] ) （表制約）\fR
プライマリキー制約は、テーブルの1列または複数列が一意な（重複がない）、非NULL値のみを持つことを指定します。
技術的には、PRIMARY KEYは単なるUNIQUEとNOT NULLの組み合わせです。しかし、プライマリキーであることは他のテーブルがその列集合を一意な行識別子とみなせることを意味するので、列集合をプライマリキーと特定すると、スキーマ設計に関するメタデータを提供することになります。

列制約であるかテーブル制約であるかにかかわらず、1つのテーブルに指定できるプライマリキーは1つだけです。

プライマリキー制約には、そのテーブルに定義された他の一意性制約で指名された列の集合とは違う組み合わせの列の集合を指定しなければなりません。
.TP
\fBCHECK ( \fIexpression\fB )\fR
CHECK句は、挿入や更新操作を行うために、新しい行、または変更する行が満たさなければならない、Boolean型の結果を返す式を指定します。
式の評価がTRUEもしくはUNKNOWNとなれば成功です。
行の挿入、更新操作の結果、式がFALSEとなる場合は、エラー例外が生成され、挿入や更新によるデータベースの変更は行われません。
列制約として指定された検査制約は、その列の値のみを参照しなければなりません。
一方、テーブル制約として現れる式は、複数列を参照することができます。

現在、CHECK式には、副問い合わせや現在の行の列以外の値を含むことはできません。
.TP
\fBREFERENCES \fIreftable\fB [ ( \fIrefcolumn\fB ) ] [ MATCH \fImatchtype\fB ] [ ON DELETE \fIaction\fB ] [ ON UPDATE \fIaction\fB ] （列制約）\fR
.TP
\fBFOREIGN KEY ( \fIcolumn\fB [, ... ] )\fR
これらの句は、外部キー制約を指定します。
外部キー制約は、新しいテーブルの1つまたは複数の列の集合が、被参照テーブルの一部の行の被参照列（複数可）に一致する値を持たなければならないことを指定するものです。
\fIrefcolumn\fRが省略された場合、\fIreftable\fRのプライマリキーが使用されます。
被参照列は、被参照テーブルにおいて一意性制約もしくはプライマリキー制約を持った列でなければなりません。
一時テーブルと永続テーブルとの間で外部キー制約を定義できないことに注意してください。

参照列に挿入された値は、被参照テーブルと被参照列の値に対して、指定した照合型で照会されます。
照合型には3種類があります。
MATCH FULL、MATCH PARTIAL、デフォルトでもあるMATCH SIMPLE照合型です。
MATCH FULLは全ての外部キー列がNULLとなる場合を除き、複数列外部キーのある列がNULLとなることを許可しません。
MATCH SIMPLE照合型は、外部キーの他の部分がNULLでない限り、外部キーの一部をNULLとなることを許可します。
MATCH PARTIALはまだ実装されていません。

さらに、被参照列のデータが変更された場合、このテーブルの列のデータに何らかの動作が発生します。
ON DELETE句は、被参照テーブルの被参照行が削除された場合の動作を指定します。
同様にON UPDATE句は、被参照テーブルの被参照列が新しい値に更新された場合の動作を指定します。
行の更新があった場合でも、被参照列が実際に変更されない場合は、動作は実行されません。
制約が遅延可能と宣言されていても、NO ACTION検査以外の参照動作は遅延させられません。
各句について、以下の動作を指定可能です。
.RS
.TP
\fBNO ACTION\fR
削除もしくは更新が外部キー制約違反となることを示すエラーを発生します。
制約が遅延可能な場合、何らかの参照行が存在する限り、このエラーは制約の検査時点で発生します。
これはデフォルトの動作です。
.TP
\fBRESTRICT\fR
削除もしくは更新が外部キー制約違反となることを示すエラーを発生します。
検査が遅延できない点を除き、NO ACTIONと同じです。
.TP
\fBCASCADE\fR
削除された行を参照している行は全て削除します。また、参照している列の値を、被参照列の新しい値にします。
.TP
\fBSET NULL\fR
参照する列（複数可）をNULLに設定します。
.TP
\fBSET DEFAULT\fR
参照する列（複数可）をそのデフォルト値に設定します。
.RE
.PP

被参照列が頻繁に更新される場合、外部キー列にインデックスを付け、その外部キー列に関連する参照動作がより効率的に実行できるようにする方が良いでしょう。
.TP
\fBDEFERRABLE\fR
.TP
\fBNOT DEFERRABLE\fR
制約を遅延させることが可能かどうかを制御します。
遅延不可の制約は各コマンドの後すぐに検査されます。
遅延可能な制約の検査は、（SET CONSTRAINTS [\fBset_constraints\fR(l)]コマンドを使用して）トランザクションの終了時まで遅延させることができます。
NOT DEFERRABLEがデフォルトです。
現在、外部キー制約のみがこの句を受け付けることができます。
他の制約は遅延させることができません。
.TP
\fBINITIALLY IMMEDIATE\fR
.TP
\fBINITIALLY DEFERRED\fR
制約が遅延可能な場合、この句は制約検査を行うデフォルトの時期を指定します。
制約がINITIALLY IMMEDIATEの場合、各文の実行後に検査されます。
これがデフォルトです。
制約がINITIALLY DEFERREDの場合、トランザクションの終了時にのみ検査されます。
制約検査の時期はSET CONSTRAINTS [\fBset_constraints\fR(l)]コマンドを使用して変更することができます。
.TP
\fBWITH ( \fIstorage_parameter\fB [= \fIvalue\fB] [, ... ] )\fR
この句は、テーブルまたはインデックスに対して省略可能な格納パラメータを指定します。
詳細は格納パラメータ [\fBcreate_table\fR(l)]を参照してください。
テーブル用のWITHには、OIDS=TRUE（もしくは単なるOIDS）を含めて、新しいテーブルの行が行に割り当てられたOID（オブジェクト識別子）を持たなければならないことを指定することもできます。
また、OIDS=FALSEを含めて、OIDを持たないことを指定することもできます。
OIDSが指定されない場合、デフォルトの設定はdefault_with_oids設定パラメータに依存します。
（新しいテーブルがOIDを持つテーブルから継承する場合、コマンドでOIDS=FALSEと指定しても強制的にOIDS=TRUE となります。）

OIDS=FALSEが明示的または暗黙的に指定されている場合、新しいテーブルはOIDを格納しません。また、挿入される行にはOIDが割り当てられません。
このような動作は一般的に有益であると考えられます。それは、OIDの使用を抑え、32ビットのOIDカウンタの回転周期を延長できるためです。
カウンタが一周するとOIDの一意性を保証できなくなるので、その有用性を減少させることになります。
また、OIDをなくすことで、テーブル1行当たり（ほとんどのマシンで）4バイト分、テーブルをディスクに格納するための容量を軽減するので、多少性能が向上します。

テーブルの作成後にOIDを削除するには、ALTER TABLE [\fBalter_table\fR(l)]を使用してください。
.TP
\fBWITH OIDS\fR
.TP
\fBWITHOUT OIDS\fR
これは古い構文で、それぞれWITH (OIDS) and WITH (OIDS=FALSE)と同じです。
OIDSの設定と格納パラメータの設定の両方を指定したい場合は、上述のWITH ( ... )を使用しなければなりません。
.TP
\fBON COMMIT\fR
ON COMMITを使用して、トランザクションブロックの終了時点での一時テーブルの動作を制御することができます。
以下の3つのオプションがあります。
.RS
.TP
\fBPRESERVE ROWS\fR
トランザクションの終了時点で、特別な動作は行われません。
これがデフォルトの動作です。
.TP
\fBDELETE ROWS\fR
一時テーブル内の全ての行は、各トランザクションブロックの終わりで削除されます。
基本的には、コミットの度に自動的にTRUNCATE [\fBtruncate\fR(l)]>が実行されます。
.TP
\fBDROP\fR
一時テーブルは、現在のトランザクションブロックの終了時点で削除されます。
.RE
.PP
.TP
\fBTABLESPACE \fItablespace\fB\fR
\fItablespace\fRは、新しいテーブルが作成されるテーブル空間名です。
指定されていない場合、default_tablespaceが使用されます。
default_tablespaceが空文字列であれば、データベースのデフォルトのテーブル空間が使用されます。
.TP
\fBUSING INDEX TABLESPACE \fItablespace\fB\fR
この句により、UNIQUEまたはPRIMARY KEY制約に関連したインデックスを作成するテーブル空間を選択することができます。
指定されていない場合、default_tablespaceが使用されます。
default_tablespaceが空文字列であれば、データベースのデフォルトのテーブル空間が使用されます。
.SS "格納パラメータ"
.PP
WITH句により、テーブルおよびUNIQUEまたはPRIMARY KEY制約と関連づいたインデックスの\fI格納パラメータ\fRを指定することができます。
インデックスの格納パラメータについてはCREATE INDEX [\fBcreate_index\fR(l)]で説明します。
現在、テーブルでは以下の格納パラメータのみが設定可能です。
.TP
\fBFILLFACTOR\fR
テーブルのfillfactorは10から100までの間の割合（パーセント）です。
100（完全にすべて使用）がデフォルトです。
より小さな値を指定すると、\fBINSERT\fR操作は指定した割合までしかテーブルページを使用しません。
各ページの残りの部分は、そのページ内の行更新用に予約されます。
これにより\fBUPDATE\fRは、元の行と同じページ上に更新済みの行の複製を格納することができるようになります。
これは別のページに更新済みの行の複製を格納することよりも効率的です。
項目の更新がまったくないテーブルでは、完全にすべてを使用することが最善の選択です。
しかし、更新が非常に多いテーブルではより小さめのfillfactorが適切です。
.SH "注釈"
.PP
新規のアプリケーションでOIDを使用するのはお勧めしません。
できる限り、テーブルのプライマリキーとしてSERIALや他のシーケンスジェネレータを使用する方が望ましいと考えられます。
しかし、アプリケーションがテーブルの特定の行を識別するためにOIDを使用する場合は、そのテーブルの\fBoid\fR列に一意性制約を作成することを推奨します。 
これにより、カウンタが一周してしまった場合でも、テーブル内のOIDで一意に行を識別できることが保証されるからです。
OIDがテーブル全体で一意であると考えるのは止めてください。 
データベース全体で一意な識別子が必要な場合は、\fBtableoid\fRと行のOIDの組み合わせを使用してください。 
.sp
.RS
.B "Tip:"
OIDS=FALSEの使用は、プライマリキーのないテーブルでは推奨されません。 
OIDも一意なデータキーも存在しないと、特定行を識別することが難しくなるからです。
.RE
.sp
.PP
PostgreSQLは自動的に各一意性制約とプライマリキー制約に対してインデックスを作成し、その一意性を確実なものにします。
したがって、プライマリキーの列に明示的なインデックスを作成することは必要ありません
（詳細についてはCREATE INDEX [\fBcreate_index\fR(l)]を参照してください）。
.PP
現在の実装では、一意性制約とプライマリキーは継承されません。
これは、継承と一意性制約を組み合わせると障害が発生するからです。
.PP
テーブルは1600列以上の列を持つことはできません
（タプル長の制限により実際の制限はもっと低くなります）。
.SH "例"
.PP
\fBfilms\fRテーブルと\fBdistributors\fRテーブルを作成します。
.sp
.nf
CREATE TABLE films (
    code        char(5) CONSTRAINT firstkey PRIMARY KEY,
    title       varchar(40) NOT NULL,
    did         integer NOT NULL,
    date_prod   date,
    kind        varchar(10),
    len         interval hour to minute
);
.sp
.fi
.sp
.nf
CREATE TABLE distributors (
     did    integer PRIMARY KEY DEFAULT nextval('serial'),
     name   varchar(40) NOT NULL CHECK (name <> '')
);
.sp
.fi
.PP
2次元配列を持つテーブルを作成します。
.sp
.nf
CREATE TABLE array_int (
    vector  int[][]
);
.sp
.fi
.PP
filmsテーブルに 一意性テーブル制約を定義します。
一意性テーブル制約はテーブルの1つ以上の列に定義することができます。
.sp
.nf
CREATE TABLE films (
    code        char(5),
    title       varchar(40),
    did         integer,
    date_prod   date,
    kind        varchar(10),
    len         interval hour to minute,
    CONSTRAINT production UNIQUE(date_prod)
);
.sp
.fi
.PP
検査列制約を定義します。
.sp
.nf
CREATE TABLE distributors (
    did     integer CHECK (did > 100),
    name    varchar(40)
);
.sp
.fi
.PP
検査テーブル制約を定義します。
.sp
.nf
CREATE TABLE distributors (
    did     integer,
    name    varchar(40)
    CONSTRAINT con1 CHECK (did > 100 AND name <> '')
);
.sp
.fi
.PP
\fBfilms\fRテーブルにプライマリキーテーブル制約を定義します。
.sp
.nf
CREATE TABLE films (
    code        char(5),
    title       varchar(40),
    did         integer,
    date_prod   date,
    kind        varchar(10),
    len         interval hour to minute,
    CONSTRAINT code_title PRIMARY KEY(code,title)
);
.sp
.fi
.PP
\fBdistributors\fRテーブルにプライマリキー制約を定義します。
以下の2つの例は同じものです。
前者はテーブル制約構文を使用し、後者は列制約構文を使用します。
.sp
.nf
CREATE TABLE distributors (
    did     integer,
    name    varchar(40),
    PRIMARY KEY(did)
); 
.sp
.fi
.sp
.nf
CREATE TABLE distributors (
    did     integer PRIMARY KEY,
    name    varchar(40)
);
.sp
.fi
.PP
以下では、name列のデフォルト値にリテラル定数を割り当てています。また、did列のデフォルト値として、シーケンスオブジェクトの次の値が生成されるように調整しています。
modtimeのデフォルト値は、その行が挿入された時刻となります。
.sp
.nf
CREATE TABLE distributors (
    name      varchar(40) DEFAULT 'Luso Films',
    did       integer DEFAULT nextval('distributors_serial'),
    modtime   timestamp DEFAULT current_timestamp
);
.sp
.fi
.PP
2つのNOT NULL列制約を\fBdistributors\fRテーブルに定義します。
そのうち1つには明示的な名前を付けています。
.sp
.nf
CREATE TABLE distributors (
    did     integer CONSTRAINT no_null NOT NULL,
    name    varchar(40) NOT NULL
);
.sp
.fi
.PP
name列に対し、一意性制約を定義します。
.sp
.nf
CREATE TABLE distributors (
    did     integer,
    name    varchar(40) UNIQUE
);
.sp
.fi
上をテーブル制約として指定します。
.sp
.nf
CREATE TABLE distributors (
    did     integer,
    name    varchar(40),
    UNIQUE(name)
);
.sp
.fi
.PP
テーブルとその一意性インデックスに70%のfillファクタを指定して、同じテーブルを作成します。
.sp
.nf
CREATE TABLE distributors (
    did     integer,
    name    varchar(40),
    UNIQUE(name) WITH (fillfactor=70)
)
WITH (fillfactor=70);
.sp
.fi
.PP
\fBdiskvol1\fRテーブル空間に\fBcinemas\fRテーブルを作成します。
.sp
.nf
CREATE TABLE cinemas (
        id serial,
        name text,
        location text
) TABLESPACE diskvol1;
.sp
.fi
.SH "互換性"
.PP
\fBCREATE TABLE\fRは、以下の一覧を除いて、標準SQLに従います。
.SS "一時テーブル"
.PP
CREATE TEMPORARY TABLEは標準SQLに類似していますが、その効果は同じではありません。
標準では、一時テーブルは一度だけ定義され、それを必要とするセッションごとに自動的に（空の内容で始まる形で）出現します。
PostgreSQLでは、これと異なり、各セッションで独自に、使用する一時テーブル用のCREATE TEMPORARY TABLEコマンドを発行しなければなりません。
これにより、異なるセッションで同じ名前の一時テーブルを異なる目的で使用することができます。
一方、標準の方法では、ある一時テーブル名を持つインスタンスが、全て同一のテーブル構造を持つという制限があります。
.PP
標準におけるこのような一時テーブルの動作定義はたいてい無視されています。
この点でのPostgreSQLの動作は、他の多くのSQLデータベースと似ています。
.PP
標準における、グローバル一時テーブルとローカル一時テーブルの区別はPostgreSQLにはありません。
この区別はモジュールという概念に依存したものですが、PostgreSQLにはモジュール概念がないからです。
互換性を保持するため、PostgreSQLは一時テーブルの宣言においてGLOBALとLOCALキーワードを受け付けますが、これらには何の効果もありません。
.PP
一時テーブル用のON COMMIT句もまた、標準SQLに類似していますが、数点の違いがあります。
ON COMMIT句が省略された場合、SQLでは、デフォルトの動作はON COMMIT DELETE ROWSであると規定しています。
しかし、PostgreSQLでのデフォルトの動作はON COMMIT PRESERVE ROWSです。
また、ON COMMIT DROPはSQLにはありません。
.SS "列検査制約"
.PP
標準SQLでは、CHECK列制約はそれを適用する列のみを参照でき、複数の列を参照できるのはCHECKテーブル制約のみであるとされています。
PostgreSQLにはこの制限はありません。
列検査制約とテーブル検査制約を同様のものとして扱っています。
.SS "NULL ``制約''"
.PP
NULL``制約''（実際には非制約）は、標準SQLに対するPostgreSQLの拡張で、他のいくつかのデータベースシステムとの互換性のために含まれています（NOT NULL制約と対称になります）。
どんな列に対してもデフォルトとなるため、これはノイズに過ぎません。
.SS "継承"
.PP
INHERITS句による複数継承は、PostgreSQLの言語拡張です。
SQL:1999以降では、異なる構文と意味体系による単一継承を定義しています。
今のところ、SQL:1999方式の継承はPostgreSQLではサポートされていません。
.SS "列を持たないテーブル"
.PP
PostgreSQLでは、列を持たないテーブルを作成することができます
（例えば、CREATE TABLE foo();）。
これは標準SQLからの拡張です。
標準SQLでは列を持たないテーブルは許されません。
列を持たないテーブルそれ自体は役に立ちませんが、これを無効とすると、\fBALTER TABLE DROP COLUMN\fRに対して奇妙な特例を生成することになります。
したがって、この仕様上の制限を無視する方が簡潔であると考えます。
.SS "WITH CLAUSE"
.PP
WITH句はPostgreSQLの拡張です。
格納パラメータもOIDも標準にはありません。
.SS "テーブル空間"
.PP
PostgreSQLのテーブル空間の概念は標準にはありません。
したがって、TABLESPACEとUSING INDEX TABLESPACEは、PostgreSQLにおける拡張です。
.SH "関連項目"
ALTER TABLE [\fBalter_table\fR(l)], DROP TABLE [\fBdrop_table\fR(l)], CREATE TABLESPACE [\fBcreate_tablespace\fR(l)]
