.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "COMMENT" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
COMMENT \- オブジェクトのコメントを定義する、または変更する

.SH SYNOPSIS
.sp
.nf
COMMENT ON
{
  TABLE \fIobject_name\fR |
  COLUMN \fItable_name\fR.\fIcolumn_name\fR |
  AGGREGATE \fIagg_name\fR (\fIagg_type\fR [, ...] ) |
  CAST (\fIsourcetype\fR AS \fItargettype\fR) |
  CONSTRAINT \fIconstraint_name\fR ON \fItable_name\fR |
  CONVERSION \fIobject_name\fR |
  DATABASE \fIobject_name\fR |
  DOMAIN \fIobject_name\fR |
  FUNCTION \fIfunc_name\fR ( [ [ \fIargmode\fR ] [ \fIargname\fR ] \fIargtype\fR [, ...] ] ) |
  INDEX \fIobject_name\fR |
  LARGE OBJECT \fIlarge_object_oid\fR |
  OPERATOR \fIop\fR (\fIleftoperand_type\fR, \fIrightoperand_type\fR) |
  OPERATOR CLASS \fIobject_name\fR USING \fIindex_method\fR |
  [ PROCEDURAL ] LANGUAGE \fIobject_name\fR |
  RULE \fIrule_name\fR ON \fItable_name\fR |
  ROLE \fIobject_name\fR |
  SCHEMA \fIobject_name\fR |
  SEQUENCE \fIobject_name\fR |
  TABLESPACE \fIobject_name\fR |
  TRIGGER \fItrigger_name\fR ON \fItable_name\fR |
  TYPE \fIobject_name\fR |
  VIEW \fIobject_name\fR
} IS \fI'text'\fR
.sp
.fi
.SH "説明"
.PP
\fBCOMMENT\fRは、データベースオブジェクトに関するコメントを保存します。
.PP
コメントを編集するには、同一オブジェクトに対して新しく\fBCOMMENT\fRコマンドを発行してください。
各オブジェクトに保存できるコメント文字列は1つだけです。
コメントを削除するには、テキスト文字列の部分にNULLを記述してください。
オブジェクトが削除された時、コメントは自動的に削除されます。
.PP
コメントは、\fBpsql\fRのコマンド\fB\\dd\fR、\fB\\d+\fR、\fB\\l+\fRで簡単に取り出すことができます。
\fBobj_description()\fR、\fBcol_description()\fR、\fBshobj_description\fRという名前の、\fBpsql\fRが使用する組み込み関数を使うように構築することで、他のユーザインタフェースを使ってコメントを取り出せるようになります
（in the documentationを参照してください）。
.SH "パラメータ"
.TP
\fB\fIobject_name\fB\fR
.TP
\fB\fItable_name.column_name\fB\fR
.TP
\fB\fIagg_name\fB\fR
.TP
\fB\fIconstraint_name\fB\fR
.TP
\fB\fIfunc_name\fB\fR
.TP
\fB\fIop\fB\fR
.TP
\fB\fIrule_name\fB\fR
.TP
\fB\fItrigger_name\fB\fR
コメントを付加するオブジェクトの名前です。
テーブル、集約、ドメイン、関数、インデックス、演算子、演算子クラス、シーケンス、データ型、ビューの名前は、スキーマ修飾することができます。
.TP
\fB\fIagg_type\fB\fR
集約関数が演算する入力データ型です。
引数を持たない集約関数を参照する場合は、入力データ型のリストに*を指定してください。
.TP
\fB\fIsourcetype\fB\fR
キャストの変換元データ型の名前です。
.TP
\fB\fItargettype\fB\fR
キャストの変換先のデータ型の名前です。
.TP
\fB\fIargmode\fB\fR
関数の引数のモードで、IN、OUT、INOUTのいずれかです。
省略時のデフォルトはINです。
関数を識別するには入力引数のみが必要ですので、\fBCOMMENT ON FUNCTION\fRが実際にはOUT引数を無視することに注意してください。
したがって、INとINOUT引数を列挙することで十分です。
.TP
\fB\fIargname\fB\fR
関数の引数の名前です。
関数の識別には引数データ型のみが必要ですので、\fBCOMMENT ON FUNCTION\fRが実際には引数の名前を無視することに注意してください。
.TP
\fB\fIargtype\fB\fR
もしあれば、関数の引数のデータ型（複数可、スキーマ修飾も可）です。
.TP
\fB\fIlarge_object_oid\fB\fR
ラージオブジェクトのOIDです。
.TP
\fBPROCEDURAL\fR
これはノイズワードです。
.TP
\fB\fItext\fB\fR
追加するコメントです。文字列リテラルとして記述します。
コメントを削除する場合はNULLを記述します。
.SH "注釈"
.PP
現在、コメントにはセキュリティ機構は存在しません。
データベースに接続したユーザは誰でも、そのデータベース内のオブジェクトのコメントを参照することができます（ただし、所有していないオブジェクトに関するコメントを変更できるのはスーパーユーザのみです）。
データベース、ロール、テーブル空間などの共有オブジェクトに対するコメントは大域的に格納され、任意のデータベースに接続した任意のユーザが共有オブジェクトに対するコメントをすべて見ることができます。
そのため、コメントにはセキュリティ的に重大な情報を記載してはいけません。
.SH "例"
.PP
mytableテーブルにコメントを付けます。
.sp
.nf
COMMENT ON TABLE mytable IS 'This is my table.';
.sp
.fi
先ほどのコメントを削除します。
.sp
.nf
COMMENT ON TABLE mytable IS NULL;
.sp
.fi
.PP
その他の例をいくつか示します。
.sp
.nf
COMMENT ON AGGREGATE my_aggregate (double precision) IS 'Computes sample variance';
COMMENT ON CAST (text AS int4) IS 'Allow casts from text to int4';
COMMENT ON COLUMN my_table.my_column IS 'Employee ID number';
COMMENT ON CONVERSION my_conv IS 'Conversion to UTF8';
COMMENT ON DATABASE my_database IS 'Development Database';
COMMENT ON DOMAIN my_domain IS 'Email Address Domain';
COMMENT ON FUNCTION my_function (timestamp) IS 'Returns Roman Numeral';
COMMENT ON INDEX my_index IS 'Enforces uniqueness on employee ID';
COMMENT ON LANGUAGE plpython IS 'Python support for stored procedures';
COMMENT ON LARGE OBJECT 346344 IS 'Planning document';
COMMENT ON OPERATOR ^ (text, text) IS 'Performs intersection of two texts';
COMMENT ON OPERATOR - (NONE, text) IS 'This is a prefix operator on text';
COMMENT ON OPERATOR CLASS int4ops USING btree IS '4 byte integer operators for btrees';
COMMENT ON ROLE my_role IS 'Administration group for finance tables';
COMMENT ON RULE my_rule ON my_table IS 'Logs updates of employee records';
COMMENT ON SCHEMA my_schema IS 'Departmental data';
COMMENT ON SEQUENCE my_sequence IS 'Used to generate primary keys';
COMMENT ON TABLE my_schema.my_table IS 'Employee Information';
COMMENT ON TABLESPACE my_tablespace IS 'Tablespace for indexes';
COMMENT ON TRIGGER my_trigger ON my_table IS 'Used for RI';
COMMENT ON TYPE complex IS 'Complex number data type';
COMMENT ON VIEW my_view IS 'View of departmental costs';
.sp
.fi
.SH "互換性"
.PP
標準SQLには\fBCOMMENT\fRはありません。
