.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SET CONSTRAINTS" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
SET CONSTRAINTS \- 現在のトランザクションの制約検査モードを設定する

.SH SYNOPSIS
.sp
.nf
SET CONSTRAINTS { ALL | \fIname\fR [, ...] } { DEFERRED | IMMEDIATE }
.sp
.fi
.SH "説明"
.PP
\fBSET CONSTRAINTS\fRは、現在のトランザクションにおける制約の検査方法を設定します。
\fBIMMEDIATE\fR制約は、1つの文の実行が終わるごとに検査されます。
\fBDEFERRED\fR制約は、トランザクションがコミットされるまで検査されません。
全ての制約は、IMMEDIATEかDEFERREDのどちらかのモードを持ちます。
.PP
制約にはその生成時点で、DEFERRABLE INITIALLY DEFERRED、DEFERRABLE INITIALLY IMMEDIATE、NOT DEFERRABLEの3つのうちのいずれかの性質が与えられます。
3番目のNOT DEFERRABLE制約は、常にIMMEDIATEモードであり、\fBSET CONSTRAINTS\fRコマンドの影響を受けません。
DEFERRABLE INITIALLY DEFERRED制約とDEFERRABLE INITIALLY IMMEDIATE制約の2つは、トランザクションを指定されたモードで開始しますが、トランザクション内で\fBSET CONSTRAINTS\fRを使用するとその振舞いを変更することができます。
.PP
制約名のリストを持った\fBSET CONSTRAINTS\fRが変更するのは、これらの制約のモードのみです
（これらは全て遅延可能です）。
スキーマ名が指定されていない場合、最初に一致する名前を見つけ出すために現在のスキーマ検索パスが使用されます。
\fBSET CONSTRAINTS ALL\fRは遅延可能な全ての制約のモードを変更します。
.PP
制約のモードをDEFERREDからIMMEDIATEに変更した場合は、新しい制約モードが遡及的に有効になります。 
つまりDEFERREDモードであればトランザクションの終了時に検査される未検査のデータ変更が、\fBSET CONSTRAINTS\fRコマンドの実行中に検査されます。
もし、この時に何らかの制約違反があった場合、\fBSET CONSTRAINTS\fRは失敗します
（そして、制約モードは変更されません）。
したがって、\fBSET CONSTRAINTS\fRを利用すれば、トランザクションの特定の時点で強制的に制約の検査を実行することができます。
.PP
今のところ、外部キー制約だけがこの設定の影響を受けます。
検査制約や一意性制約の実行が遅延されることはありません。
.SH "注釈"
.PP
このコマンドが変更するのは、現在のトランザクション内の制約の動作のみです。
したがって、トランザクションブロック（\fBBEGIN\fR/\fBCOMMIT\fRの間）の外部でこのコマンドが実行されても場合、何ら効果はありません。
.SH "互換性"
.PP
このコマンドは、標準SQLで定義された動作に準拠しています。
ただし、PostgreSQLでは適用対象が外部キー制約のみという制限があります。
