.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP FUNCTION" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
DROP FUNCTION \- 関数を削除する

.SH SYNOPSIS
.sp
.nf
DROP FUNCTION [ IF EXISTS ] \fIname\fR ( [ [ \fIargmode\fR ] [ \fIargname\fR ] \fIargtype\fR [, ...] ] )
    [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBDROP FUNCTION\fRは既存の関数定義を削除します。
このコマンドを実行できるのは、その関数の所有者のみです。
関数の引数の型は必ず指定しなければなりません。
異なる引数を持つ同じ名前の関数が複数存在する可能性があるからです。
.SH "パラメータ"
.TP
\fBIF EXISTS\fR
関数が存在しない場合でもエラーになりません。
この場合注意メッセージが発行されます。
.TP
\fB\fIname\fB\fR
既存の関数の名前です（スキーマ修飾名も可）。
.TP
\fB\fIargmode\fB\fR
引数のモードで、IN、OUT、 INOUTのいずれかです。
省略された場合のデフォルトはINです。
関数の識別を行うには入力引数のみが必要ですので、実際には\fBDROP FUNCTION\fRがOUT引数を無視することに注意してください。
ですので、INおよびINOUT引数を列挙することで十分です。
.TP
\fB\fIargname\fB\fR
引数の名前です。
関数の識別を行うには引数のデータ型のみが必要ですので、実際には\fBDROP FUNCTION\fRは引数の名前を無視することに注意してください。
.TP
\fB\fIargtype\fB\fR
もしあれば、その関数の引数のデータ型（複数可）です。
（スキーマで修飾可能です）
.TP
\fBCASCADE\fR
関数に依存するオブジェクト（演算子やトリガなど）を自動的に削除します。
.TP
\fBRESTRICT\fR
依存しているオブジェクトがある場合、その関数の削除を拒否します。
これがデフォルトです。
.SH "例"
.PP
次のコマンドは平方根関数を削除します。
.sp
.nf
DROP FUNCTION sqrt(integer);
.sp
.fi
.SH "互換性"
.PP
\fBDROP FUNCTION\fR文は標準SQLでも定義されていますが、このコマンドとは互換性がありません。
.SH "関連項目"
CREATE FUNCTION [\fBcreate_function\fR(l)], ALTER FUNCTION [\fBalter_function\fR(l)]
