.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SHOW" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
SHOW \- 実行時パラメータの値を表示する

.SH SYNOPSIS
.sp
.nf
SHOW \fIname\fR
SHOW ALL
.sp
.fi
.SH "説明"
.PP
\fBSHOW\fRは、実行時パラメータの現在の設定を表示します。
これらの変数は、\fBSET\fR文、\fIpostgresql.conf\fRの編集、\fBPGOPTIONS\fR環境変数（\fBlibpq\fRあるいは\fBlibpq\fRを使用したアプリケーションの使用時）、または、\fBpostgres\fRの始動時のコマンドラインフラグで設定することができます。
詳細はin the documentationを参照してください。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
実行時パラメータの名前です。
利用可能なパラメータはin the documentationとSET [\fBset\fR(l)]マニュアルページに記載されています。
さらに、表示のみ可能で、変更できない次のようなパラメータがあります。
.RS
.TP
\fBSERVER_VERSION\fR
サーバのバージョン番号を示します。
.TP
\fBSERVER_ENCODING\fR
サーバ側の文字セット符号化方式を表示します。
現時点では、符号化方式はデータベース作成時に決定されるため、このパラメータは表示のみ可能で、変更することができません。
.TP
\fBLC_COLLATE\fR
データベースの照合（テキストの順序付け）についてのロケール設定を示します。
現時点では、この設定は\fBinitdb\fR時に決定されるため、このパラメータは表示のみ可能で、変更することができません。
.TP
\fBLC_CTYPE\fR
文字分類についてのデータベースのロケール設定を表示します。
現時点では、この設定は\fBinitdb\fR時に決定されるため、このパラメータは表示のみ可能で、変更することができません。
.TP
\fBIS_SUPERUSER\fR
現在のセッションの認証識別子がスーパーユーザ権限を持つ場合は真になります。
.RE
.PP
.TP
\fBALL\fR
全ての設定パラメータの値とその説明を表示します。
.SH "注釈"
.PP
\fBcurrent_setting\fR関数は同等の出力を生成します。
in the documentationを参照してください。
.SH "例"
.PP
DateStyleパラメータの現在の設定を表示します。
.sp
.nf
SHOW DateStyle;
 DateStyle
-----------
 ISO, MDY
(1 row)
.sp
.fi
.PP
geqoパラメータの現在の設定を表示します。
.sp
.nf
SHOW geqo;
 geqo
------
 on
(1 row)
.sp
.fi
.PP
全設定を表示します。
.sp
.nf
SHOW ALL;
              name              |            setting             |                                         description                                          
--------------------------------+--------------------------------+----------------------------------------------------------------------------------------------
 add_missing_from               | off                            | Automatically adds missing table references to FROM clauses.
 archive_command                | unset                          | WAL archiving command.
    .
    .
    .
 work_mem                       | 1024                           | Sets the maximum memory to be used for query workspaces.
 zero_damaged_pages             | off                            | Continues processing past damaged page headers.
(146 rows)
.sp
.fi
.SH "互換性"
.PP
\fBSHOW\fRコマンドはPostgreSQLの拡張です。
.SH "関連項目"
SET [\fBset\fR(l)], RESET [\fBreset\fR(l)]
