.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "LOAD" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
LOAD \- 共有ライブラリファイルの読み込み（または再読み込み）を行う

.SH SYNOPSIS
.sp
.nf
LOAD '\fIfilename\fR'
.sp
.fi
.SH "説明"
.PP
\fBLOAD\fRコマンドは、共有ライブラリファイルをPostgreSQLサーバのアドレス空間にロードします。
そのファイルが既にロードされていれば、まず、アンロードします。
このコマンドは、主に、サーバが読み込み済みの共有ライブラリファイルに変更があった場合、それをアンロードして、再ロードする時に使用されます。
共有ライブラリを使用できるようにするには、そこに含まれる関数をCREATE FUNCTION [\fBcreate_function\fR(l)]コマンドを使用して宣言しておかなければなりません。
.PP
共有ライブラリのファイル名は、CREATE FUNCTION [\fBcreate_function\fR(l)]における共有ライブラリ名と同じ方法で特定されます。特に、検索パスやシステム標準の共有ライブラリファイル名拡張子の自動付与に依存する可能性があります。
詳細はin the documentationを参照してください。

.PP
非特権ユーザは\fI$libdir/plugins/\fRにあるライブラリファイルのみを\fBLOAD\fRさせることができます。
つまり、指定した\fIfilename\fRはこの文字列から始まらなければなりません。
（このディレクトリ以下に確実に``安全な''ライブラリのみをインストールすることはデータベース管理者の責任です。）
.SH "互換性"
.PP
\fBLOAD\fRはPostgreSQLの拡張です。
.SH "関連項目"
CREATE FUNCTION [\fBcreate_function\fR(l)]
