.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CREATE USER" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
CREATE USER \- 新しいデータベースロールを定義する

.SH SYNOPSIS
.sp
.nf
CREATE USER \fIname\fR [ [ WITH ] \fIoption\fR [ ... ] ]

ここで\fIoption\fRは以下の通りです。

      SUPERUSER | NOSUPERUSER
    | CREATEDB | NOCREATEDB
    | CREATEROLE | NOCREATEROLE
    | CREATEUSER | NOCREATEUSER
    | INHERIT | NOINHERIT
    | LOGIN | NOLOGIN
    | CONNECTION LIMIT \fIconnlimit\fR
    | [ ENCRYPTED | UNENCRYPTED ] PASSWORD '\fIpassword\fR'
    | VALID UNTIL '\fItimestamp\fR' 
    | IN ROLE \fIrolename\fR [, ...]
    | IN GROUP \fIrolename\fR [, ...]
    | ROLE \fIrolename\fR [, ...]
    | ADMIN \fIrolename\fR [, ...]
    | USER \fIrolename\fR [, ...]
    | SYSID \fIuid\fR 
.sp
.fi
.SH "説明"
.PP
\fBCREATE USER\fRはCREATE ROLE [\fBcreate_role\fR(l)]の別名になりました。詳しくはCREATE ROLE [\fBcreate_role\fR(l)]を参照してください。
唯一の違いは、\fBCREATE USER\fRという名前でコマンドが呼び出されると、デフォルトでLOGINになり、\fBCREATE ROLE\fRという名前でコマンドが呼び出されると、デフォルトでNOLOGINとなる点です。
.SH "互換性"
.PP
\fBCREATE USER\fR文は、PostgreSQLの拡張です。
標準SQLでは、ユーザの定義は実装に任されています。
.SH "関連項目"
CREATE ROLE [\fBcreate_role\fR(l)]
