.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CREATE AGGREGATE" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
CREATE AGGREGATE \- 新しい集約関数を定義する

.SH SYNOPSIS
.sp
.nf
CREATE AGGREGATE \fIname\fR ( \fIinput_data_type\fR [ , ... ] ) (
    SFUNC = \fIsfunc\fR,
    STYPE = \fIstate_data_type\fR
    [ , FINALFUNC = \fIffunc\fR ]
    [ , INITCOND = \fIinitial_condition\fR ]
    [ , SORTOP = \fIsort_operator\fR ]
)

または以下の旧構文

CREATE AGGREGATE \fIname\fR (
    BASETYPE = \fIbase_type\fR,
    SFUNC = \fIsfunc\fR,
    STYPE = \fIstate_data_type\fR
    [ , FINALFUNC = \fIffunc\fR ]
    [ , INITCOND = \fIinitial_condition\fR ]
    [ , SORTOP = \fIsort_operator\fR ]
)
.sp
.fi
.SH "説明"
.PP
\fBCREATE AGGREGATE\fRは、新しい集約関数を定義します。
配布物には基本的、かつ、よく使用される集約関数がいくつか含まれています。これらの集約関数については、in the documentationに文書化されています。
新しい型を定義する場合、またはまだ提供されていない集約関数が必要な場合、必要な機能を実現するために\fBCREATE AGGREGATE\fRを使うことができます。
.PP
スキーマ名が付けられている場合（例えば、CREATE AGGREGATE myschema.myagg ...）、集約関数は指定されたスキーマで作成されます。
スキーマ名がなければ、集約関数は現在のスキーマで作成されます。
.PP
集約関数は名前と入力データ型(複数可)の組み合わせによって識別されます。
演算の対象となる入力データ型が異なっていれば、同じスキーマ内に同じ名前の集約関数があっても構いません。
1つのスキーマ内では、集約関数の名前と入力データ型(複数可)は、通常の関数の名前と入力データ型と異なる必要があります。
.PP
集約関数は1つか2つの通常の関数から作られます。
状態遷移関数\fIsfunc\fRと省略可能な最終計算関数\fIffunc\fRです。
これらは以下のように使われます。
.sp
.nf
\fIsfunc\fR( 内部状態, 次のデータ値 ) ---> 次の内部状態
\fIffunc\fR( 内部状態 ) ---> 集約の結果
.sp
.fi
.PP
PostgreSQLは、集約の現在の内部状態を保持する\fIstype\fRデータ型の一時変数を作成します。
それぞれの入力行に対して、集約引数の値が計算され、現在の状態値と新しい引数値で新しい内部状態変数を計算するために状態遷移関数が呼び出されます。
全ての行が処理されると、集約の出力値を計算するために最終関数が1回呼び出されます。
最終関数がない場合は、終了時の状態値がそのまま返されます。
.PP
集約関数は、内部状態の初期値として初期状態を提供することができます。
これは\fBtext\fR型の値としてデータベースに格納されますが、状態値データ型の定数として有効な外部表現でなければいけません。
初期状態が与えられていない場合、状態値はNULLから始まります。
.PP
状態遷移関数が``厳格（strict）''と宣言されている場合、NULLを入力値にして呼び出すことはできません。
そのような遷移関数では、集約は次のように実行されます。
NULL入力値を持つ行は無視されます。
（関数は呼び出されず、前回の状態値が保持されます。）
初期状態値がNULLである場合、初めて入力行がすべて非NULL入力値であった時にその引数の値で状態値を置き換え、次に入力行がすべて非NULL入力値を持つ時から遷移関数の呼び出しが始まります。
このような動作は、\fBmax\fRのような集約を実装するには便利です。
ただし、\fIstate_data_type\fRが最初の\fIinput_data_type\fRと同じ時にのみ有効であることに注意してください。
これらの型が異なる時は、非NULL初期値を供給するか、厳格でない遷移関数を使わなければいけません。
.PP
状態遷移関数が厳格（strict）でない場合は、それぞれの入力行に対してその関数が無条件に呼び出されるので、NULL入力とNULL遷移値を自分で処理しなければいけません。
これは、関数の作成者が、集約関数におけるNULL値の扱いを完全に制御できることを意味します。
.PP
最終関数が``厳格（strict）''と宣言されていると、終了状態値がNULLの時は、最終関数が呼び出されません。
その場合、NULLという結果が自動的に出力されます
（もちろんこれは、厳格な関数の一般的な動作に過ぎません）。
どのような場合でも、最終関数はNULLを返すことができます。
例えば、\fBavg\fRの最終関数は、入力が0行だとわかるとNULLを返します。
.PP
\fBMIN\fRや\fBMAX\fRのような振舞いをする集約では、すべての入力行を走査せずにインデックスを検索することで最適化できることがあります。
このように最適化される集約の場合、\fIソート演算子\fRを指定することで明示してください。
その演算子で生成されるソート順で集約の最初の要素が生成されなければならないということが基本的な必要条件です。
言い換えると、
.sp
.nf
SELECT agg(col) FROM tab;
.sp
.fi
が
.sp
.nf
SELECT col FROM tab ORDER BY col USING sortop LIMIT 1;
.sp
.fi
と同じでなければならないということです。
更に、集約がNULL入力を無視すること、および、NULL以外の入力がまったくなかった時にのみNULLという結果を返すことも前提となります。
通常、データ型の<演算子は\fBMIN\fRのソート演算子として、また、>演算子は\fBMAX\fRのソート演算子として適切です。
指定した演算子がB-treeインデックス演算子クラスの``より小さい''ストラテジか``より大きい''ストラテジのメンバでない限り、最適化が実際には効果がないことに注意してください。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
作成する集約関数の名前です（スキーマ修飾名も可）。
.TP
\fB\fIinput_data_type\fB\fR
集約関数が演算する入力データ型です。 
引数が存在しない集約関数を作成するには、入力データ型のリストに*と記載してください
（例えば \fBcount(*)\fRなどの集約です）。
.TP
\fB\fIbase_type\fB\fR
\fBCREATE AGGREGATE\fRの旧構文では、入力データ型は集約名称の次に記載されたものではなくbasetypeパラメータにより指定されます。
この構文では１つの入力パラメータしか指定できないことに注意してください。
引数を持たない集約を定義するためには、basetypeを"ANY" （*ではありません）と指定してください。
.TP
\fB\fIsfunc\fB\fR
それぞれの入力行に対して呼び出される状態遷移関数の名前です。
\fIN\fR引数を持つ集約関数では、\fIsfunc\fRは\fIN\fR+1個の引数を取らなければなりません。
最初の引数は\fIstate_data_type\fR型で、残りはその集約の入力データ型として宣言したものと一致していなければなりません。
この関数は\fIstate_data_type\fR型の値を返さなければなりません。
この関数は、現在の状態値と現在の入力データ値を受け取り、次の状態値を返します。
.TP
\fB\fIstate_data_type\fB\fR
集約の状態値のデータ型です。
.TP
\fB\fIffunc\fB\fR
最終関数の名前です。最終関数は、全ての入力行に対する処理が終わった後、集約の結果を計算するために呼び出されます。
この関数は\fIstate_data_type\fR型の引数を1つ取らなければなりません。
集約の出力データ型はこの関数の返り値として定義されます。
\fIffunc\fRが指定されない場合には、集約の結果として終了時の状態値が使われます。出力型は\fIstate_data_type\fRになります。
.TP
\fB\fIinitial_condition\fB\fR
状態値の初期設定です。
データ型\fIstate_data_type\fRとして受け取り可能な文字列定数でなければいけません。
このパラメータが指定されない場合、状態値はNULLから始まります。
.TP
\fB\fIsort_operator\fB\fR
\fBMIN\fRまたは\fBMAX\fRのような集約に対して関連付いたソート演算子です。
これは単なる演算子の名前です（スキーマで修飾可能）。
この演算子は集約（これは単一引数の集約でなければなりません）と同じ入力データ型を持つと前提されています。
.PP
\fBCREATE AGGREGATE\fRのパラメータは、任意の順番で記述することができます。上記の順番で記述する必要はありません。
.PP
.SH "例"
.PP
in the documentationを参照してください。
.SH "互換性"
.PP
\fBCREATE AGGREGATE\fRはPostgreSQLの言語拡張です。
標準SQLには、ユーザ定義の集約関数を使用する機能はありません。
.SH "関連項目"
ALTER AGGREGATE [\fBalter_aggregate\fR(l)], DROP AGGREGATE [\fBdrop_aggregate\fR(l)]
