.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP VIEW" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
DROP VIEW \- ビューを削除する

.SH SYNOPSIS
.sp
.nf
DROP VIEW [ IF EXISTS ] \fIname\fR [, ...] [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBDROP VIEW\fRは既存のビューを削除します。
このコマンドを実行できるのは、ビューの所有者のみです。
.SH "パラメータ"
.TP
\fBIF EXISTS\fR
ビューが存在しなかったとしてもエラーになりません。
この場合注意メッセージが発行されます。
.TP
\fB\fIname\fB\fR
削除するビューの名前です（スキーマ修飾名も可）。
.TP
\fBCASCADE\fR
削除するビューに依存しているオブジェクト（他のビューなど）を自動的に削除します。
.TP
\fBRESTRICT\fR
依存するオブジェクトがある場合は、ビューの削除を拒否します。
こちらがデフォルトです。
.SH "例"
.PP
次のコマンドはkindsという名前のビューを削除します。
.sp
.nf
DROP VIEW kinds;
.sp
.fi
.SH "互換性"
.PP
標準では1コマンドで1つのビューのみを削除できるという点を除き、およびPostgreSQLの拡張であるIF EXISTSオプションを除き、このコマンドは標準SQLに従っています。
.SH "関連項目"
CREATE VIEW [\fBcreate_view\fR(l)]
