.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER AGGREGATE" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
ALTER AGGREGATE \- 集約関数定義を変更する

.SH SYNOPSIS
.sp
.nf
ALTER AGGREGATE \fIname\fR ( \fItype\fR [ , ... ] ) RENAME TO \fInew_name\fR
ALTER AGGREGATE \fIname\fR ( \fItype\fR [ , ... ] ) OWNER TO \fInew_owner\fR
ALTER AGGREGATE \fIname\fR ( \fItype\fR [ , ... ] ) SET SCHEMA \fInew_schema\fR
.sp
.fi
.SH "説明"
.PP
\fBALTER AGGREGATE\fRは集約関数の定義を変更します。
.PP
\fBALTER AGGREGATE\fRを使用するには集約関数の所有者でなければなりません。
集約関数のスキーマを変更するには、新しいスキーマにおけるCREATE権限も必要です。
所有者を変更するには、直接または間接的に新しい所有者ロールのメンバでなければなりません。
また、そのロールが集約関数のスキーマにおいてCREATEを持たなければなりません。
（この制限により、強制的に、所有者の変更が集約関数の削除と再作成で行うことができない何らかの処理を行わないようになります。
しかし、スーパーユーザはすべての集約関数の所有者を変更することができます。）
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
既存の集約関数の名前です（スキーマ修飾名も可）。
.TP
\fB\fItype\fB\fR
集約関数が演算する入力データ型です。
引数を持たない集約関数を参照するには、入力データ型のリストに*と記載してください。
.TP
\fB\fInew_name\fB\fR
新しい集約関数の名前です。
.TP
\fB\fInew_owner\fB\fR
新しい集約関数の所有者です。
.TP
\fB\fInew_schema\fB\fR
集約関数の新しいスキーマです。
.SH "例"
.PP
\fBinteger\fR型用のmyavg集約関数の名前をmy_averageに変更します。
.sp
.nf
ALTER AGGREGATE myavg(integer) RENAME TO my_average;
.sp
.fi
.PP
\fBinteger\fR型用のmyavg集約関数の所有者をjoeに変更します。
.sp
.nf
ALTER AGGREGATE myavg(integer) OWNER TO joe;
.sp
.fi
.PP
\fBinteger\fR型用のmyavg集約関数をmyschemaスキーマに移動します。
.sp
.nf
ALTER AGGREGATE myavg(integer) SET SCHEMA myschema;
.sp
.fi
.SH "互換性"
.PP
標準SQLには\fBALTER AGGREGATE\fR文はありません。
.SH "関連項目"
CREATE AGGREGATE [\fBcreate_aggregate\fR(l)], DROP AGGREGATE [\fBdrop_aggregate\fR(l)]
