.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CREATE VIEW" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
CREATE VIEW \- 新しいビューを定義する

.SH SYNOPSIS
.sp
.nf
CREATE [ OR REPLACE ] [ TEMP | TEMPORARY ] VIEW \fIname\fR [ ( \fIcolumn_name\fR [, ...] ) ]
    AS \fIquery\fR
.sp
.fi
.SH "説明"
.PP
\fBCREATE VIEW\fRは問い合わせによるビューを定義します。
ビューは物理的な実体として存在するものではありません。
その代わり、問い合わせでビューが参照される度に、指定された問い合わせが実行されます。
.PP
\fBCREATE OR REPLACE VIEW\fRも同様の働きをしますが、
このコマンドでは、同じ名前のビューが既に存在している場合、そのビューを置き換えます。
ビューを置き換えることができるのは、新しい問い合わせが同じ列の集合（つまり、列名およびデータ型の組み合わせが同じ）を生成する場合のみです。
.PP
スキーマ名が付けられている場合（例えば、CREATE VIEW myschema.myview ...）、ビューは指定されたスキーマで作成されます。
スキーマ名がなければ、そのビューは現在のスキーマで作成されます。
一時ビューは特別なスキーマで作成されます。
そのため、一時ビューを作成する時にはスキーマ名を付けることはできません。
ビュー名は、同じスキーマ内の他のビュー、テーブル、シーケンス、インデックスとは異なる名前である必要があります。
.SH "パラメータ"
.TP
\fBTEMPORARY or TEMP\fR
これが指定された場合、ビューは一時ビューとして作成されます。
現在のセッションが終わった時、一時ビューは自動的に削除されます。
一時ビューが存在する間、現在のセッションでは、これと同じ名前の永続リレーションはスキーマで修飾した名前で参照していない限り不可視です。

ビューで参照されるテーブルの一部が一時テーブルであった場合、（TEMPORARYの指定があってもなくても）ビューは一時ビューとして作成されます。
.TP
\fB\fIname\fB\fR
作成するビューの名前です（スキーマ修飾名も可）。
.TP
\fB\fIcolumn_name\fB\fR
ビューの列名として使用する名前のリストです。このパラメータは省略可能です。省略された場合、問い合わせに由来する名前が使用されます。
.TP
\fB\fIquery\fB\fR
ビューの列と行を生成するSELECT [\fBselect\fR(l)]またはVALUES [\fBvalues\fR(l)]コマンドです。
.SH "注釈"
.PP
現在のところ、ビューは読み取り専用です。
システムは、ビューに対する挿入、更新、削除を許可しません。
しかし、ビューに対する挿入などを他のテーブルに対する処理に書き換えるルールを作成することで、更新可能なビューと同じように扱うことができます。
詳細については、CREATE RULE [\fBcreate_rule\fR(l)]を参照してください。
.PP
ビューを削除するには、DROP VIEW [\fBdrop_view\fR(l)]文を使用してください。
.PP
ビューの列の名前と型は指定通りに割り当てられることに注意してください。
例えば、次のコマンドを見てください。
.sp
.nf
CREATE VIEW vista AS SELECT 'Hello World';
.sp
.fi
この例は、次の2点から好ましくありません。
まず、列の名前がデフォルトの?column?になります。さらに、列のデータ型もデフォルトの\fBunknown\fRになってしまいます。
ビューの結果として文字リテラルを返したい場合は、次のように指定してください。
.sp
.nf
CREATE VIEW vista AS SELECT text 'Hello World' AS hello;
.sp
.fi
.PP
ビューが参照するテーブルにアクセスできるかどうかは、ビューの所有者の権限で決定されます。
しかし、ビュー内で実行される関数については、ビューを使用した問い合わせにおいて、その関数が直接呼び出された場合と同様に扱われます。
したがって、ビューを使用するユーザには、ビュー内で使用される全ての関数を呼び出す権限が必要です。
.SH "例"
.PP
全てのコメディ映画（Comedy films）からなるビューを作成します。
.sp
.nf
CREATE VIEW comedies AS
    SELECT *
    FROM films
    WHERE kind = 'Comedy';
.sp
.fi
.SH "互換性"
.PP
標準SQLの\fBCREATE VIEW\fR文には、さらにいくつかの機能が規定されています。
.sp
.nf
CREATE VIEW \fIname\fR [ ( \fIcolumn_name\fR [, ...] ) ]
    AS \fIquery\fR
    [ WITH [ CASCADED | LOCAL ] CHECK OPTION ]
.sp
.fi
.PP
このSQLコマンドの全てのオプション句について、次に説明します。
.TP
\fBCHECK OPTION\fR
更新される可能性のあるビューには、このオプションを使用しなければなりません。
ビューに対する全ての\fBINSERT\fRと\fBUPDATE\fRコマンドは、ビュー定義の条件を満足しているかどうか（新しいデータがビューを通して可視であるかどうか）検査されます。
条件を満たしていない場合、その更新は拒否されます。
.TP
\fBLOCAL\fR
このビューの整合性を検査します。
.TP
\fBCASCADED\fR
このビューと依存している全てのビューの整合性を検査します。
CASCADEDまたはLOCALのいずれも指定されていない場合は、CASCADEDとして扱われます。
.PP
.PP
\fBCREATE OR REPLACE VIEW\fRはPostgreSQLの言語拡張です。
つまり一時ビューという概念も言語拡張です。
.SH "関連項目"
DROP VIEW [\fBdrop_view\fR(l)]
