.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CREATE DOMAIN" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
CREATE DOMAIN \- 新しいドメインを定義する

.SH SYNOPSIS
.sp
.nf
CREATE DOMAIN \fIname\fR [ AS ] \fIdata_type\fR
    [ DEFAULT \fIexpression\fR ]
    [ \fIconstraint\fR [ ... ] ]

\fIconstraint\fRは、次のようになります。

[ CONSTRAINT \fIconstraint_name\fR ]
{ NOT NULL | NULL | CHECK (\fIexpression\fR) }
.sp
.fi
.SH "説明"
.PP
\fBCREATE DOMAIN\fRは新しいデータドメインを作成します。
ドメインとは基本的には、特別な制約（設定可能な値集合に対する制限）を持ったデータ型です。
ドメインを定義したユーザが、その所有者となります。
.PP
スキーマ名が付けられている場合（例えば、CREATE DOMAIN myschema.mydomain ...）、ドメインは指定されたスキーマで作成されます。
スキーマ名が付けられていなければ、そのドメインは現在のスキーマで作成されます。
ドメイン名は、そのスキーマ内に存在するデータ型およびドメインの間で、一意である必要があります。
.PP
ドメインを使用すると、共通な制約を1箇所にまとめることができ、メンテナンスに便利です。
たとえば、E-mailアドレスを格納する列が複数のテーブルで使用されていて、アドレス構文の検証のためすべてが同一のCHECK制約を必要としているような場合です。
このような場合、各テーブルに個別に制約を設定するよりも、ドメインを定義してください。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
作成するドメインの名前です（スキーマ修飾名でも可）。
.TP
\fB\fIdata_type\fB\fR
ドメインの基礎となるデータ型です。
配列指定子が含まれる場合があります。
.TP
\fBDEFAULT \fIexpression\fB\fR
DEFAULT句を使用すると、ドメインデータ型の列にデフォルト値を指定できます。
任意の無変数式を値とすることができます（ただし、副問い合わせは許可されません）。
デフォルト式のデータ型は、そのドメインのデータ型と一致する必要があります。
デフォルト値が指定されない場合、デフォルト値はNULL値となります。

デフォルト式は、挿入操作において該当する列に値が指定されなかった場合に使用されます。
特定の列に対してデフォルト値が定義された場合、ドメインに関連するデフォルト値は上書きされます。
反対に、基礎となるデータ型に関連するデフォルト値は、ドメインのデフォルト値によって上書きされます。
.TP
\fBCONSTRAINT \fIconstraint_name\fB\fR
制約の名前です（省略可能です）。
指定されなければ、システムが名前を生成します。
.TP
\fBNOT NULL\fR
ドメインの値としてNULLの使用を禁止します。
.TP
\fBNULL\fR
ドメインの値としてNULLの使用を許可します。
こちらがデフォルトです。

この句は非標準的なSQLデータベースとの互換性を持つためだけに用意されています。
新しいアプリケーションでこの句を使用するのはお勧めできません。
.TP
\fBCHECK (\fIexpression\fB)\fR
CHECK句は、整合性制約やドメインの値が満たさなければならない検査を指定します。
各制約は、Boolean型の結果を生成する式である必要があります。
検査される値を参照するには、VALUEというキーワードを使用すべきです。

現時点では、CHECK式に副問い合わせを含めたり、VALUE以外の変数を参照したりすることはできません。
.SH "例"
.PP
この例では、\fBus_postal_code\fRデータ型を作成し、その型をテーブル定義の中で使用します。
データが有効なUS郵便番号であるかどうかを検証するために正規表現検査が使用されます。
.sp
.nf
CREATE DOMAIN us_postal_code AS TEXT
CHECK(
   VALUE ~ '^\\\\d{5}$'
OR VALUE ~ '^\\\\d{5}-\\\\d{4}$'
);

CREATE TABLE us_snail_addy (
  address_id SERIAL PRIMARY KEY,
  street1 TEXT NOT NULL,
  street2 TEXT,
  street3 TEXT,
  city TEXT NOT NULL,
  postal us_postal_code NOT NULL
);
.sp
.fi
.SH "互換性"
.PP
\fBCREATE DOMAIN\fRコマンドは標準SQLに準拠しています。
.SH "関連項目"
ALTER DOMAIN [\fBalter_domain\fR(l)], DROP DOMAIN [\fBdrop_domain\fR(l)]
