.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "COMMIT PREPARED" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
COMMIT PREPARED \- 二相コミット用に事前に準備されたトランザクションをコミットする

.SH SYNOPSIS
.sp
.nf
COMMIT PREPARED \fItransaction_id\fR
.sp
.fi
.SH "説明"
.PP
\fBCOMMIT PREPARED\fRは準備段階のトランザクションをコミットします。
.SH "パラメータ"
.TP
\fB\fItransaction_id\fB\fR
コミット対象のトランザクションのトランザクション識別子です。
.SH "注釈"
.PP
準備されたトランザクションをコミットするには、元のトランザクションを実行したユーザと同じユーザか、スーパーユーザでなければなりません。
しかし、トランザクションを実行したセッションと同じセッションである必要はありません。
.PP
このコマンドはトランザクションブロックの内側では実行できません。
準備されたトランザクションは即座にコミットされます。
.PP
利用可能な準備されたトランザクションはすべて、\fBpg_prepared_xacts\fRシステムビューで列挙されます。
.SH "例"
.PP
foobarトランザクション識別子で識別されるトランザクションをコミットします。
.sp
.nf
COMMIT PREPARED 'foobar';
.sp
.fi
.SH "関連項目"
PREPARE TRANSACTION [\fBprepare_transaction\fR(l)], ROLLBACK PREPARED [\fBrollback_prepared\fR(l)]
