.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "UNLISTEN" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
UNLISTEN \- 通知の監視を停止する

.SH SYNOPSIS
.sp
.nf
UNLISTEN { \fIname\fR | * }
.sp
.fi
.SH "説明"
.PP
\fBUNLISTEN\fRを使うと、既存の\fBNOTIFY\fRイベントの登録を削除することができます。
\fBUNLISTEN\fRは、現在のPostgreSQLセッションにある、\fIname\fR通知条件用のリスナ登録を全て取り消します。
ワイルドカード*は特別な条件を表します。これを指定すると、現在のセッションにある全てのリスナ登録が取り消されます。
.PP
NOTIFY [\fBnotify\fR(l)]には、\fBLISTEN\fRと\fBNOTIFY\fRについてのより広範な説明があります。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
通知名です（任意の識別子）。
.TP
\fB*\fR
このセッションにおける、全ての監視登録をクリアします。
.SH "注釈"
.PP
監視をまったく行っていない状態でもこのコマンドは実行できます。警告やエラーは表示されません。
.PP
セッション終了時に、自動的に\fBUNLISTEN *\fRが実行されます。
.SH "例"
.PP
登録を行います。
.sp
.nf
LISTEN virtual;
NOTIFY virtual;
Asynchronous notification "virtual" received from server process with PID 8448.
.sp
.fi
.PP
\fBUNLISTEN\fRが実行されると、その後の\fBNOTIFY\fRコマンドは無視されます。
.sp
.nf
UNLISTEN virtual;
NOTIFY virtual;
-- NOTIFYイベントを受け取りません。
.sp
.fi
.SH "互換性"
.PP
標準SQLには\fBUNLISTEN\fRコマンドはありません。
.SH "関連項目"
LISTEN [\fBlisten\fR(l)], NOTIFY [\fBnotify\fR(l)]
