.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SAVEPOINT" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
SAVEPOINT \- 現在のトランザクション内に新規にセーブポイントを定義する

.SH SYNOPSIS
.sp
.nf
SAVEPOINT \fIsavepoint_name\fR
.sp
.fi
.SH "説明"
.PP
\fBSAVEPOINT\fRは、現在のトランザクション内に新しいセーブポイントを設定します。
.PP
セーブポイントとはトランザクション内に付ける特別な印です。セーブポイントを設定しておくと、それ以降に実行されたコマンドを全てロールバックし、トランザクションを設定時の状態に戻すことができます。
.SH "パラメータ"
.TP
\fB\fIsavepoint_name\fB\fR
新しいセーブポイントに付与する名前です。
.SH "注釈"
.PP
セーブポイントまでロールバックするにはROLLBACK TO SAVEPOINT [\fBrollback_to_savepoint\fR(l)]を使用してください。
セーブポイント後に行われたコマンドの効果を保持したままセーブポイントを破棄するには、RELEASE SAVEPOINT [\fBrelease_savepoint\fR(l)]を使用してください。
.PP
セーブポイントはトランザクションブロックの内側のみに設定することができます。
1つのトランザクションの中には、複数のセーブポイントを設定することができます。
.SH "例"
.PP
セーブポイントを設定し、その後に実行した全てのコマンドの効果を取り消します。
.sp
.nf
BEGIN;
    INSERT INTO table1 VALUES (1);
    SAVEPOINT my_savepoint;
    INSERT INTO table1 VALUES (2);
    ROLLBACK TO SAVEPOINT my_savepoint;
    INSERT INTO table1 VALUES (3);
COMMIT;
.sp
.fi
上記のトランザクションでは、1と3は挿入されますが、2は挿入されません。
.PP
セーブポイントを設定し、その後に破棄します。
.sp
.nf
BEGIN;
    INSERT INTO table1 VALUES (3);
    SAVEPOINT my_savepoint;
    INSERT INTO table1 VALUES (4);
    RELEASE SAVEPOINT my_savepoint;
COMMIT;
.sp
.fi
上記のトランザクションでは、3と4の両方が挿入されます。
.SH "互換性"
.PP
SQLでは、同じ名前のセーブポイントが設定された時は、自動的に古い方のセーブポイントを破棄することになっています。
PostgreSQLでは、古いセーブポイントも保持されますが、
ロールバックや解放時には新しい方のセーブポイントが使用されます
（新しいセーブポイントが解放されると、再び\fBROLLBACK TO SAVEPOINT\fRや\fBRELEASE SAVEPOINT\fRから古いセーブポイントが使用できるようになります）。
この点以外は、\fBSAVEPOINT\fRは完全にSQLに従っています。
.SH "関連項目"
BEGIN [\fBbegin\fR(l)], COMMIT [\fBcommit\fR(l)], RELEASE SAVEPOINT [\fBrelease_savepoint\fR(l)], ROLLBACK [\fBrollback\fR(l)], ROLLBACK TO SAVEPOINT [\fBrollback_to_savepoint\fR(l)]
