.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER CONVERSION" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
ALTER CONVERSION \- 変換の定義を変更する

.SH SYNOPSIS
.sp
.nf
ALTER CONVERSION \fIname\fR RENAME TO \fInewname\fR
ALTER CONVERSION \fIname\fR OWNER TO \fInewowner\fR
.sp
.fi
.SH "説明"
.PP
\fBALTER CONVERSION\fRは変換の定義を変更します。
.PP
\fBALTER CONVERSION\fRを使用するには変換の所有者でなければなりません。
所有者を変更するには、直接または間接的に新しいロールのメンバでなければなりません。
また、そのロールが変換のスキーマにおいてCREATEを持たなければなりません。
（この制限により、強制的に、所有者の変更が変換の削除と再作成で行うことができない何かを行わないようになります。
しかし、スーパーユーザはすべての変換の所有者を変更することができます。）
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
既存の変換の名前です（スキーマ修飾名も可）。
.TP
\fB\fInewname\fB\fR
新しい変換の名前です。
.TP
\fB\fInewowner\fB\fR
新しい変換の所有者です。
.SH "例"
.PP
iso_8859_1_to_utf8変換の名前をlatin1_to_unicodeへ変更します。
.sp
.nf
ALTER CONVERSION iso_8859_1_to_utf8 RENAME TO latin1_to_unicode;
.sp
.fi
.PP
iso_8859_1_to_utf8変換の所有者をjoeに変更します。
.sp
.nf
ALTER CONVERSION iso_8859_1_to_utf8 OWNER TO joe;
.sp
.fi
.SH "互換性"
.PP
標準SQLには\fBALTER CONVERSION\fR文はありません。
.SH "関連項目"
CREATE CONVERSION [\fBcreate_conversion\fR(l)], DROP CONVERSION [\fBdrop_conversion\fR(l)]
