.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP RULE" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
DROP RULE \- 書き換えルールを削除する

.SH SYNOPSIS
.sp
.nf
DROP RULE [ IF EXISTS ] \fIname\fR ON \fIrelation\fR [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBDROP RULE\fRは書き換えルールを削除します。
.SH "パラメータ"
.TP
\fBIF EXISTS\fR
ルールが存在しない場合でもエラーになりません。
この場合注意メッセージが発行されます。
.TP
\fB\fIname\fB\fR
削除するルールの名前です。
.TP
\fB\fIrelation\fB\fR
そのルールが適用されたテーブルもしくはビューの名前です（スキーマ修飾名も可）。
.TP
\fBCASCADE\fR
ルールに依存するオブジェクトを自動的に削除します。
.TP
\fBRESTRICT\fR
依存するオブジェクトがある場合、ルールの削除を拒否します。
こちらがデフォルトです。
.SH "例"
.PP
newruleという書き換えルールを削除します。
.sp
.nf
DROP RULE newrule ON mytable;
.sp
.fi
.SH "互換性"
.PP
標準SQLには\fBDROP RULE\fR文はありません。
.SH "関連項目"
CREATE RULE [\fBcreate_rule\fR(l)]
