.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP INDEX" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
DROP INDEX \- インデックスの削除

.SH SYNOPSIS
.sp
.nf
DROP INDEX [ IF EXISTS ] \fIname\fR [, ...] [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBDROP INDEX\fRはデータベースシステムから既存のインデックスを削除します。
このコマンドを実行するには、そのインデックスを所有していなければなりません。
.SH "パラメータ"
.TP
\fBIF EXISTS\fR
インデックスが存在しない場合でもエラーになりません。
この場合注意メッセージが発行されます。
.TP
\fB\fIname\fB\fR
削除するインデックスの名前です（スキーマ修飾名も可）。
.TP
\fBCASCADE\fR
そのインデックスに依存しているオブジェクトを自動的に削除します。
.TP
\fBRESTRICT\fR
依存しているオブジェクトがある場合、そのインデックスの削除を拒否します。
こちらがデフォルトです。
.SH "例"
.PP
次のコマンドはtitle_idxインデックスを削除します。
.sp
.nf
DROP INDEX title_idx;
.sp
.fi
.SH "互換性"
.PP
\fBDROP INDEX\fRはPostgreSQLの言語拡張です。
標準SQLにはインデックスに関する規定はありません。
.SH "関連項目"
CREATE INDEX [\fBcreate_index\fR(l)]
