.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "EXECUTE" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
EXECUTE \- 準備された文を実行する

.SH SYNOPSIS
.sp
.nf
EXECUTE \fIname\fR [ (\fIparameter\fR [, ...] ) ]
.sp
.fi
.SH "説明"
.PP
\fBEXECUTE\fRは、前もって準備された文を実行する際に使用します。 
準備された文はセッション中にしか存在できないため、事前に同一セッション中の\fBPREPARE\fR文によって作成されたものでなければなりません。
.PP
文を作成した\fBPREPARE\fR文にパラメータが指定されている場合は、これに適合するパラメータの集合が\fBEXECUTE\fRに渡される必要があります。
そうしないと、エラーになります。
（関数とは異なり）準備された文は、パラメータのデータ型や個数によってオーバーロードされることはありません。 
準備された文の名前は、1つのデータベースセッション内で一意でなければなりません。
.PP
準備された文の作成方法と使用方法についての詳細はPREPARE [\fBprepare\fR(l)]を参照してください。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
実行する準備された文の名前を指定します。
.TP
\fB\fIparameter\fB\fR
準備された文に対するパラメータの実際の値を式で指定します。
この式は、準備された文が生成された時に決定される、そのパラメータのデータ型と互換性のある値を返す必要があります。
.SH "出力"
.PP
\fBEXECUTE\fRで返されるコマンドタグは、EXECUTEではなく、準備された文のコマンドタグとなります。
.SH "例"
.PP
例はPREPARE [\fBprepare\fR(l)]文書の例 [\fBprepare\fR(l)]節にあります。
.SH "互換性"
.PP
標準SQLには\fBEXECUTE\fR文が含まれていますが、これは埋め込みSQLでのみ使用できます。
また、このバージョンの\fBEXECUTE\fR文では、多少異なる構文が使用されています。
.SH "関連項目"
DEALLOCATE [\fBdeallocate\fR(l)], PREPARE [\fBprepare\fR(l)]
