.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP TABLE" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
DROP TABLE \- テーブルを削除する

.SH SYNOPSIS
.sp
.nf
DROP TABLE [ IF EXISTS ] \fIname\fR [, ...] [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBDROP TABLE\fRはデータベースからテーブルを削除します。
テーブルを削除できるのは、その所有者のみです。 
テーブルを削除するのではなく、テーブルの行を空にするには、DELETE [\fBdelete\fR(l)]またはTRUNCATE [\fBtruncate\fR(l)]を使用してください。
.PP
\fBDROP TABLE\fRは、削除対象のテーブル内に存在するインデックス、ルール、トリガ、制約を全て削除します。
しかし、ビューや他のテーブルから外部キー制約によって参照されているテーブルを削除するにはCASCADEを指定する必要があります
（CASCADEを指定すると、テーブルに依存するビューは完全に削除されます。しかし、外部キー制約によって参照されている場合は、外部キー制約のみが削除され、その外部キーを持つテーブルそのものは削除されません）。
.SH "パラメータ"
.TP
\fBIF EXISTS\fR
テーブルが存在しない場合でもエラーになりません。
この場合、注意メッセージが発行されます。
.TP
\fB\fIname\fB\fR
削除するテーブルの名前です（スキーマ修飾名も可）。
.TP
\fBCASCADE\fR
削除するテーブルに依存しているオブジェクト（ビューなど）を自動的に削除します。
.TP
\fBRESTRICT\fR
依存しているオブジェクトがある場合に、テーブルの削除を拒否します。
こちらがデフォルトです。
.SH "例"
.PP
2つのテーブル、filmsとdistributorsを削除します。
.sp
.nf
DROP TABLE films, distributors;
.sp
.fi
.SH "互換性"
.PP
標準では1コマンドで1テーブルのみを削除できるという点を除き、および、PostgreSQLの拡張であるIF EXISTSオプションを除き、このコマンドは標準SQLに従います。
.SH "関連項目"
ALTER TABLE [\fBalter_table\fR(l)], CREATE TABLE [\fBcreate_table\fR(l)]
