.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "REASSIGN OWNED" "" "2007-05-04" "SQL 言語" "SQLコマンド"
.SH NAME
REASSIGN OWNED \- あるデータベースロールにより所有されたデータベースオブジェクトの所有権を変更する

.SH SYNOPSIS
.sp
.nf
REASSIGN OWNED BY \fIold_role\fR [, ...] TO \fInew_role\fR
.sp
.fi
.SH "説明"
.PP
\fBREASSIGN OWNED\fRは、old_rolesのいずれかが所有するデータベースオブジェクトの所有権をnew_roleに変更するようシステムに指示します。
.SH "パラメータ"
.TP
\fB\fIold_role\fB\fR
ロール名です。
現在のデータベースでこのロールが所有するすべてのオブジェクトの所有権を\fInew_role\fRに割り当てます。
.TP
\fB\fInew_role\fB\fR
対象とするオブジェクトの新しい所有者となるロール名です。
.SH "注釈"
.PP
\fBREASSIGN OWNED\fRは、1つ以上のロールの削除準備によく使用されます。
\fBREASSIGN OWNED\fRは現在のデータベース内のオブジェクトのみに影響を与えますので、通常は、削除対象のロールにより所有されるオブジェクトを有するデータベース毎にこのコマンドを実行する必要があります。
.PP
代わりにDROP OWNED [\fBdrop_owned\fR(l)]コマンドを使用して、1つ以上のロールにより所有されるデータベースオブジェクトすべてを削除することができます。
.PP
\fBREASSIGN OWNED\fRコマンドは、old_rolesにより所有されていないオブジェクトにおいてold_rolesに与えられた権限には影響しません。
こうした権限を取り上げるには、\fBDROP OWNED\fRを使用してください。
.SH "互換性"
.PP
\fBREASSIGN OWNED\fR文はPostgreSQLの拡張です。
.SH "関連項目"
DROP OWNED [\fBdrop_owned\fR(l)], DROP ROLE [\fBdrop_role\fR(l)]
