.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CLUSTER" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
CLUSTER \- インデックスに従ってテーブルをクラスタ化する

.SH SYNOPSIS
.sp
.nf
CLUSTER \fIindexname\fR ON \fItablename\fR
CLUSTER \fItablename\fR
CLUSTER
.sp
.fi
.SH "説明"
.PP
\fBCLUSTER\fRは、\fIindexname\fRで指定されたインデックスに基づき、\fItablename\fRで指定されたテーブルをクラスタ化するように、PostgreSQLに指示します。
このインデックスは前もって\fItablename\fRで定義されていなければなりません。
.PP
テーブルがクラスタ化されると、それぞれのテーブルはインデックス情報に基づいて物理的に並べ直されます。 
クラスタ化は、1回限りの操作です。
クラスタ化後にテーブルが更新されても、その変更はクラスタ化されません。
つまり、新規に追加された行や更新された行は、インデックス順には保管されません。
インデックス順に保管したい場合は、コマンドを再度入力し、定期的に再クラスタ化を行います。
.PP
テーブルがクラスタ化されると、PostgreSQLはクラスタ化に使用されたインデックスを記録します。
\fBCLUSTER \fItablename\fB\fRという構文によって、以前にクラスタ化された時と同じインデックスを使用してテーブルを再クラスタ化します。
.PP
パラメータを指定しないで\fBCLUSTER\fRを実行した場合、呼び出したユーザが所有するデータベース内の全てのテーブルを（スーパーユーザの場合は、全てのテーブルを）クラスタ化します
（これまでにクラスタ化されていないテーブルは含まれません）。
このパラメータを指定しない\fBCLUSTER\fRを、トランザクションブロック内で実行することはできません。
.PP
クラスタ化を行っているテーブルは、ACCESS EXCLUSIVEロックを獲得しています。
これにより、\fBCLUSTER\fRが終わるまで、そのテーブルに対するデータベース操作（読み書き両方）を防ぐことができます。
.SH "パラメータ"
.TP
\fB\fIindexname\fB\fR
インデックスの名前です。
.TP
\fB\fItablename\fB\fR
テーブルの名前です（スキーマ修飾名も可）。
.SH "注釈"
.PP
テーブル内の1つの行にランダムにアクセスする場合、テーブル内のデータの順序は重要でありません。
しかし、テーブル内の特定のデータにアクセスが集中している場合、それらのデータをグループ化しているインデックスが存在する時は、\fBCLUSTER\fRによる利益を享受できます。
テーブルからインデックスの値の範囲や、一致する複数の行を保有する1つのインデックスの値などが知りたい場合、\fBCLUSTER\fRが役に立ちます。
一度インデックスが一致する行に対するテーブルページを認識すると、一致する他の全ての行も同じテーブルページに存在する可能性が高いので、ディスクアクセスを減らして問い合わせ処理の速度を向上することができるからです。
.PP
クラスタ処理の間、インデックス順にテーブルデータを並べた、テーブルの一時コピーが作成されます。 
同様に、テーブルの各インデックスの一時コピーも作成されます。 
したがって、ディスクには、少なくともテーブルとインデックスの合計サイズと同じ容量の空き領域が必要です。
.PP
\fBCLUSTER\fRはクラスタ化に関する情報を記録しているので、一度手作業でテーブルをクラスタ化すれば、周期的に再クラスタ化を実行するよう、\fBVACUUM\fR同様にスケジュールを組むことができます。
.PP
プランナはテーブルの順序付けに関する統計情報を記録しているため、新しくクラスタ化されたテーブルでは、ANALYZE [\fBanalyze\fR(l)]を実行することが推奨されます。 
そうしないと、プランナが問い合わせ計画を適切に選択できない可能性があります。
.PP
データをクラスタ化する方法はもう1つあります。
\fBCLUSTER\fRコマンドは、指定したインデックスを使用してテーブルをスキャンすることで元のテーブルを並び替えます。
この方法では、行はインデックスの順序にテーブルから取り出されますが、テーブルが順番に並んでいない場合、それぞれの項目がばらばらの順序でページ上に存在するため、移動する行ごとに1つのディスクページが取得されることになります。
したがって、大規模なテーブルでは低速になることがあります
（PostgreSQLにはキャッシュがありますが、大規模なテーブルの大多数はキャッシュに収めきれません）。
次に、テーブルをクラスタ化するもう1つの方法を示します。
.sp
.nf
CREATE TABLE \fInewtable\fR AS
    SELECT * FROM \fItable\fR ORDER BY \fIcolumnlist\fR;
.sp
.fi
このSQL文では、PostgreSQLのソート用のコードを使用し、必要な並び替えを作成しています。
この方法は、通常、順序付けられていないデータに対するインデックススキャンよりも処理時間がずっと短くなります。
その後、古いテーブルを削除し、\fBALTER TABLE...RENAME\fRで\fInewtable\fRを以前の名前に書き換えてから、テーブルのインデックスを再生成してください。
しかし、この方法では、テーブルのOID、制約、外部キー関係、権限、およびその他の付属情報が保持されないという大きな欠点があります。
これらの付属情報は、手動で再作成する必要があります。
他にもこの方法には、対象のテーブル自体と同サイズの、一時的なソート用のファイルが必要であるという欠点もあります。
このため、最大のディスク使用量はテーブルサイズの倍ではなく約3倍になります。
.SH "例"
.PP
emp_indインデックスに基づいて、empテーブルをクラスタ化します。
.sp
.nf
CLUSTER emp_ind ON emp;
.sp
.fi
.PP
以前に使用したインデックスを使用して、empテーブルをクラスタ化します。
.sp
.nf
CLUSTER emp;
.sp
.fi
.PP
データベース内の、以前にクラスタ化されたテーブルを全てクラスタ化します。
.sp
.nf
CLUSTER;
.sp
.fi
.SH "互換性"
.PP
標準SQLには\fBCLUSTER\fR文はありません。
.SH "関連項目"
clusterdb [\fBclusterdb\fR(1)]
