.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP SEQUENCE" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
DROP SEQUENCE \- シーケンスを削除する

.SH SYNOPSIS
.sp
.nf
DROP SEQUENCE [ IF EXISTS ] \fIname\fR [, ...] [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBDROP SEQUENCE\fRはシーケンス番号ジェネレータを削除します。
.SH "パラメータ"
.TP
\fBIF EXISTS\fR
シーケンスが存在しない場合でもエラーになりません。
この場合、注意メッセージが発行されます。
.TP
\fB\fIname\fB\fR
シーケンスの名前です（スキーマ修飾名も可）。
.TP
\fBCASCADE\fR
このシーケンスに依存しているオブジェクトを自動的に削除します。
.TP
\fBRESTRICT\fR
依存オブジェクトがある場合に、シーケンスの削除を拒否します。
こちらがデフォルトです。
.SH "例"
.PP
serialという名前のシーケンスを削除します。
.sp
.nf
DROP SEQUENCE serial;
.sp
.fi
.SH "互換性"
.PP
標準では1コマンドで1つのシーケンスだけを削除できるという点を除き、および、PostgreSQLの拡張である IF EXISTSオプションを除き、\fBDROP SEQUENCE\fRは標準SQLに準拠します。
.SH "関連項目"
CREATE SEQUENCE [\fBcreate_sequence\fR(l)], ALTER SEQUENCE [\fBalter_sequence\fR(l)]
