.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER TABLESPACE" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
ALTER TABLESPACE \- テーブル空間の定義を変更する

.SH SYNOPSIS
.sp
.nf
ALTER TABLESPACE \fIname\fR RENAME TO \fInewname\fR
ALTER TABLESPACE \fIname\fR OWNER TO \fInewowner\fR
.sp
.fi
.SH "説明"
.PP
\fBALTER TABLESPACE\fRはテーブル空間の定義を変更します。
.PP
\fBALTER TABLESPACE\fRを使用するにはテーブル空間の所有者でなければなりません。
所有者を変更するには、直接または間接的に新しい所有者ロールのメンバでなければなりません。
（スーパーユーザがこれらの権限を自動的に持つことに注意してください。）
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
既存のテーブル空間の名前です。
.TP
\fB\fInewname\fB\fR
新しいテーブル空間の名前です。
pg_から始まる名前は、システムのテーブル空間用に予約されているため使用することができません。
.TP
\fB\fInewowner\fB\fR
新しいテーブル空間の所有者です。
.SH "例"
.PP
index_spaceテーブル空間をfast_raidという名前に変更します。
.sp
.nf
ALTER TABLESPACE index_space RENAME TO fast_raid;
.sp
.fi
.PP
index_spaceテーブル空間の所有者を変更します。
.sp
.nf
ALTER TABLESPACE index_space OWNER TO mary;
.sp
.fi
.SH "互換性"
.PP
標準SQLには\fBALTER TABLESPACE\fR文はありません。
.SH "関連項目"
CREATE TABLESPACE [\fBcreate_tablespace\fR(l)], DROP TABLESPACE [\fBdrop_tablespace\fR(l)]
