.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "UPDATE" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
UPDATE \- テーブルの行を更新する

.SH SYNOPSIS
.sp
.nf
UPDATE [ ONLY ] \fItable\fR [ [ AS ] \fIalias\fR ]
    SET { \fIcolumn\fR = { \fIexpression\fR | DEFAULT } |
          ( \fIcolumn\fR [, ...] ) = ( { \fIexpression\fR | DEFAULT } [, ...] ) } [, ...]
    [ FROM \fIfromlist\fR ]
    [ WHERE \fIcondition\fR ]
    [ RETURNING * | \fIoutput_expression\fR [ AS \fIoutput_name\fR ] [, ...] ]
.sp
.fi
.SH "説明"
.PP
\fBUPDATE\fRは、条件を満たす全ての行の指定した列の値を変更します。
SET句には、変更する列のみを指定する必要があります。
SET句にて明示的に指定されなかった列の値は変更されません。
.PP
デフォルトでは、\fBUPDATE\fRは指定したテーブルとその副テーブルの行を更新します。
指定されたテーブルのみを更新したい場合はONLY句を使用してください。
.PP
データベース内の他のテーブルの情報を使用してテーブルを変更するには、2つの方法があります。
1つは副問い合わせを使用する方法、もう1つはFROM句で追加するテーブルを指定する方法です。
どちらの方法が適切であるかは状況次第です。
.PP
省略可能なRETURNING句により、\fBUPDATE\fRは実際に更新された各行に基づいて計算された値を返すようになります。
そのテーブルの列、FROMで指定された他のテーブルの列、あるいは、その両方を使用した式を計算することができます。
テーブル列の新しい（更新された後の）値が使用されます。
RETURNINGリストの構文は\fBSELECT\fRの出力リストと同一です。
.PP
テーブルを変更するにはUPDATE権限が必要です。
さらに、\fIexpressions\fRや\fIcondition\fRで読み込むテーブルに対するSELECT権限も必要になります。
.SH "パラメータ"
.TP
\fB\fItable\fB\fR
更新対象のテーブルの名前です（スキーマ修飾名でも可）。 
.TP
\fB\fIalias\fB\fR
対象テーブルの代替名です。
別名が指定されると、テーブルの実際の名前は完全に隠蔽されます。
たとえば、UPDATE foo AS fでは、\fBUPDATE\fR文の残りの部分ではfooではなくfとしてこのテーブルを参照しなければなりません。
.TP
\fB\fIcolumn\fB\fR
\fItable\fR内の列名です。
必要に応じて、列名を副フィールド名や配列の指示子で修飾することも可能です。
対象列の指定にはテーブル名を含めないでください。
たとえば、UPDATE tab SET tab.col = 1は無効です。
.TP
\fB\fIexpression\fB\fR
列に代入する式です。
この式では、テーブル内の対象列やその他の列の変更前の値を使用することができます。
.TP
\fBDEFAULT\fR
列にデフォルト値を設定します
（デフォルト式が割り当てられていない場合はNULLになります）。
.TP
\fB\fIfromlist\fB\fR
WHERE条件や更新用の式において、他のテーブルの列を指定するために使用するテーブル式の集合です。
これは\fBSELECT\fR文のFROM句 [\fBselect\fR(l)]で指定するテーブルのリストに似ています。
自己結合を行う場合を除き、\fIfromlist\fRに更新対象のテーブルを含める必要はありません
（自己結合を行う場合は、\fIfromlist\fR内で更新対象のテーブルとその別名を指定しておく必要があります）。
.TP
\fB\fIcondition\fB\fR
\fBboolean\fR型の値を返す式です。
この式がtrueを返す行のみが更新されます。
.TP
\fB\fIoutput_expression\fB\fR
各行を更新した後に計算され、\fBUPDATE\fRによって返される式です。
この式には、\fItable\fRまたはFROMで指定したテーブル（複数可）の任意の列名を使用することができます。
すべての列を返す場合は*と記載してください。
.TP
\fB\fIoutput_name\fB\fR
返される列で使用される名前です。
.SH "出力"
.PP
正常に処理が終わると、\fBUPDATE\fRコマンドは以下の形式のコマンドタグを返します。
.sp
.nf
UPDATE \fIcount\fR
.sp
.fi
\fIcount\fRは更新された行数を意味します。
\fIcount\fRが0の場合は\fIcondition\fRに一致する行がなかったことを意味します
（これはエラーとはみなされません）。
.PP
\fBUPDATE\fRコマンドがRETURNING句を持つ場合、その結果は、RETURNINGリストで定義した列と値を持ち、そのコマンドで更新された行全体に対して計算を行う\fBSELECT\fR文の結果と似たものになるでしょう。
.SH "注釈"
.PP
FROM句が存在する場合、基本的に、対象テーブルと\fIfromlist\fRで指定されたテーブルが結合され、この結合の出力行が対象テーブルの更新操作の結果となります。
FROM句を使用する場合、更新対象テーブルの1行に対して、結合結果が複数行にならないように注意してください。
言い換えると、対象テーブルの個々の行は、他テーブルの複数の行と結合すべきではありません。
結合結果が複数行になった場合、対象行の更新には結合結果のいずれか1行のみが使用されますが、どの行が使用されるかは簡単には予測できません。
.PP
このような問題があるため、他テーブルの参照は副問い合わせ内のみに留めておいた方がより安全です（ただし、結合よりも可読性や実行速度は低下します）。
.SH "例"
.PP
\fBfilms\fRテーブルの\fBkind\fR列にあるDramaという単語をDramaticに変更します。
.sp
.nf
UPDATE films SET kind = 'Dramatic' WHERE kind = 'Drama';
.sp
.fi
.PP
weatherテーブルの特定の行に対し、気温という項目を調整し、降水量をデフォルト値に戻します。
.sp
.nf
UPDATE weather SET temp_lo = temp_lo+1, temp_hi = temp_lo+15, prcp = DEFAULT
  WHERE city = 'San Francisco' AND date = '2003-07-03';
.sp
.fi
.PP
同じ操作を行い、更新された項目を返します。
.sp
.nf
UPDATE weather SET temp_lo = temp_lo+1, temp_hi = temp_lo+15, prcp = DEFAULT
  WHERE city = 'San Francisco' AND date = '2003-07-03'
  RETURNING temp_lo, temp_hi, prcp;
.sp
.fi
.PP
別の列リスト構文を使用して同様の更新を行います。
.sp
.nf
UPDATE weather SET (temp_lo, temp_hi, prcp) = (temp_lo+1, temp_lo+15, DEFAULT)
  WHERE city = 'San Francisco' AND date = '2003-07-03';
.sp
.fi
.PP
FROM句構文を使用して、アクメ社を顧客とするセールスマンのセールスカウントを1増加させます。
.sp
.nf
UPDATE employees SET sales_count = sales_count + 1 FROM accounts
  WHERE accounts.name = 'Acme Corporation'
  AND employees.id = accounts.sales_person;
.sp
.fi
.PP
WHERE句で副問い合わせを使用して、同じ操作を行います。
.sp
.nf
UPDATE employees SET sales_count = sales_count + 1 WHERE id =
  (SELECT sales_person FROM accounts WHERE name = 'Acme Corporation');
.sp
.fi
.PP
新しい商品とその在庫数を挿入します。
既にその商品が存在している場合は、代わりに既存商品の在庫数を更新します。
トランザクション全体が失敗することがないようにこの操作を行うには、セーブポイントを使用してください。
.sp
.nf
BEGIN;
-- 何かしらの他の操作を行います。
SAVEPOINT sp1;
INSERT INTO wines VALUES('Chateau Lafite 2003', '24');
-- 上記のコマンドが一意キー違反により失敗したとします。
-- この場合、次のコマンドを実行します。
ROLLBACK TO sp1;
UPDATE wines SET stock = stock + 24 WHERE winename = 'Chateau Lafite 2003';
-- 他の操作を続けた後、最後に次を実行します。
COMMIT;
.sp
.fi
.SH "互換性"
.PP
このコマンドは標準SQLに準拠しています。
ただしFROM句およびRETURNING句はPostgreSQLの拡張です。
.PP
標準に従うと、列リスト構文は、副選択のような単一の行値式から代入される列のリストを許可しなければなりません。
.sp
.nf
UPDATE accounts SET (contact_last_name, contact_first_name) =
    (SELECT last_name, first_name FROM salesmen
     WHERE salesmen.id = accounts.sales_id);
.sp
.fi
これは現時点ではサポートされていません。ソースは独立した式でなければなりません。
.PP
他のデータベースシステムには、FROMオプション内で、対象テーブルが再度指定されることを前提として動作するものもあります。
これはPostgreSQLにおけるFROMの解釈方法とは異なります。
FROM拡張機能を使用するアプリケーションを移植する時は注意してください。
