.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DELETE" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
DELETE \- テーブルから行を削除する

.SH SYNOPSIS
.sp
.nf
DELETE FROM [ ONLY ] \fItable\fR [ [ AS ] \fIalias\fR ]
    [ USING \fIusinglist\fR ]
    [ WHERE \fIcondition\fR ]
    [ RETURNING * | \fIoutput_expression\fR [ AS \fIoutput_name\fR ] [, ...] ]
.sp
.fi
.SH "説明"
.PP
\fBDELETE\fRは、指定したテーブルからWHERE句を満たす行を削除します。
WHEREがない場合、指定したテーブルの全ての行を削除することになります。
この結果、そのテーブルは存在するが中身が空のテーブルになります。
.sp
.RS
.B "Tip:"
PostgreSQLによる拡張であるTRUNCATE [\fBtruncate\fR(l)]は、より高速に、テーブルから全ての行を削除する仕組みを持っています。
.RE
.sp
.PP
デフォルトでは、\fBDELETE\fRは指定されたテーブルおよびその全ての子テーブルの行を削除します。
指定されたテーブルのみを削除したい場合は、ONLY句を使用してください。
.PP
データベース内のほかのテーブルに含まれる情報を用いてテーブル内の行を削除する方法には、副問い合わせとUSING句で追加テーブルを指定する方法という2つがあります。
どちらの技法が適切かはその状況によります。
.PP
省略可能なRETURNING句により、\fBDELETE\fRは実際に削除された各行に基づいて計算された値を返すようになります。
そのテーブルの列、USINGで指定された他のテーブルの列、あるいは、その両方を使用した式を計算することができます。
RETURNINGリストの構文は\fBSELECT\fRの出力リストと同一です。
.PP
削除を実行するには、そのテーブルのDELETE権限が必要です。
また、USING句内のテーブルに対するSELECT権限、および、\fIcondition\fRで使用する値を読み取るために、その値が含まれるテーブルに対するSELECT権限も必要です。
.SH "パラメータ"
.TP
\fBONLY\fR
指定された場合、指名したテーブルのみから行を削除します。
指定されなかった場合、指名したテーブルを継承するテーブルも処理されます。
.TP
\fB\fItable\fB\fR
既存のテーブル名です（スキーマ修飾名も可）。
.TP
\fB\fIalias\fB\fR
対象テーブルの代理名称です。
別名が与えられた場合、実際のテーブル名は完全に隠蔽されます。
たとえば、DELETE FROM foo AS fを考えます。
この\fBDELETE\fR文の残りの部分ではこのテーブルをfooではなくfとして参照しなければなりません。
.TP
\fB\fIusinglist\fB\fR
WHERE条件内に他のテーブルの列を許可するための、テーブル式のリストです。
これは、\fBSELECT\fR文のFROM句 [\fBselect\fR(l)]において指定できるテーブルのリストと同様です。
例えば、テーブル名の別名も指定することができます。
自己結合を設定する目的以外では\fIusinglist\fRに対象のテーブルを繰り返さないでください。
.TP
\fB\fIcondition\fB\fR
削除すべき行を決定する、\fBboolean\fR型の値を返す式です。
.TP
\fB\fIoutput_expression\fB\fR
各行を削除した後に計算され、\fBDELETE\fRによって返される式です。
この式には、\fItable\fRまたはUSINGで指定したテーブル（複数可）の任意の列名を使用することができます。
すべての列を返す場合は*と記載してください。
.TP
\fB\fIoutput_name\fB\fR
返される列で使用される名前です。
.SH "出力"
.PP
正常に終了した場合、\fBDELETE\fRコマンドは以下の形式のコマンドタグを返します。
.sp
.nf
DELETE \fIcount\fR
.sp
.fi
\fIcount\fRは削除した行数です。
\fIcount\fRが0の場合、\fIcondition\fRを満たす行が存在しなかったことを示します
（これはエラーとはみなされません）。
.PP
\fBDELETE\fRコマンドがRETURNING句を持つ場合、その結果は、RETURNINGリストで定義した列と値を持ち、そのコマンドで削除された行全体に対して計算を行う\fBSELECT\fR文の結果と似たものになるでしょう。
.SH "注釈"
.PP
PostgreSQLでは、USING句で他のテーブルを指定することで、WHERE条件内で他のテーブルを参照することができます。
例えば、指定したプロデューサが製作した全ての映画を削除する時は、次のようなコマンドを実行します。
.sp
.nf
DELETE FROM films USING producers
  WHERE producer_id = producers.id AND producers.name = 'foo';
.sp
.fi
ここでは、\fBfilms\fRと\fBproducers\fRとを結合して、\fBfilms\fR行に削除用の印を付けるという作業を行っています。
この構文は標準に従ったものではありません。
より標準的な方法は以下の通りです。
.sp
.nf
DELETE FROM films
  WHERE producer_id IN (SELECT id FROM producers WHERE name = 'foo');
.sp
.fi
.SH "例"
.PP
filmsテーブルからmusical以外を全て削除します。
.sp
.nf
DELETE FROM films WHERE kind <> 'Musical';
.sp
.fi
.PP
filmsテーブルを空にします。
.sp
.nf
DELETE FROM films;
.sp
.fi
.PP
完了した作業（statusがDONE）を削除し、削除された行を完全に返します。
.sp
.nf
DELETE FROM tasks WHERE status = 'DONE' RETURNING *;
.sp
.fi
.SH "互換性"
.PP
このコマンドは標準SQLに準拠しています。
ただし、USING句とRETURNING句はPostgreSQLの拡張です。
