.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CHECKPOINT" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
CHECKPOINT \- トランザクションログのチェックポイントを強制的に実行する

.SH SYNOPSIS
.sp
.nf
CHECKPOINT
.sp
.fi
.SH "説明"
.PP
WAL（ログ先行書き込み）は、トランザクションログに頻繁にチェックポイントを設定します（自動で行われるチェックポイント間隔の調整については、実行時設定オプションのcheckpoint_segmentsとcheckpoint_timeoutを参照してください）。
\fBCHECKPOINT\fRコマンドが発行されると、予定されている次のチェックポイントを待つことなく、即座にチェックポイントを実行します。
.PP
チェックポイントとは、ログ内の情報を反映するために全てのデータファイルを更新する、トランザクションログのある一時点を指します。
チェックポイントによって、全てのデータファイルがディスクに書き出されます。
WALシステムの詳細については、in the documentationを参照してください。
.PP
\fBCHECKPOINT\fRを実行できるのはスーパーユーザのみです。
このコマンドは、通常動作での使用は意図されていません。
.SH "互換性"
.PP
\fBCHECKPOINT\fRコマンドは、PostgreSQLの拡張です。
