.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "REINDEX" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
REINDEX \- インデックスを再構築する

.SH SYNOPSIS
.sp
.nf
REINDEX { INDEX | TABLE | DATABASE | SYSTEM } \fIname\fR [ FORCE ]
.sp
.fi
.SH "説明"
.PP
\fBREINDEX\fRは、インデックスのテーブルに保存されたデータを使用してインデックスを再構築し、古いインデックスのコピーと置き換えます。
以下に\fBREINDEX\fRが使用される状況を示します。
.TP 0.2i
\(bu
インデックスが破損してしまい、有効なデータがなくなった場合です。
理論的には決して起こらないはずですが、実際には、ソフトウェアのバグやハードウェアの障害によりインデックスが破損することがあります。
\fBREINDEX\fRはこの修復手段を提供します。
.TP 0.2i
\(bu
インデックスが``膨張状態''、つまり、多くの空、もしくは、ほとんど空のページを持つ状態になっている場合です。
この状況は、PostgreSQLのB-treeインデックスが特定のパターンでアクセスされた場合に起こり得ます。
\fBREINDEX\fRを使って、使用されないページを取り除いた新しいインデックス作成すると、インデックスの領域消費量を減少することができます。
詳細はin the documentationを参照してください。
.TP 0.2i
\(bu
インデックスの格納パラメータ（fillファクタなど）を変更し、この変更が有効かどうかを確認したい場合です。
.TP 0.2i
\(bu
CONCURRENTLYオプションをつけたインデックス作成が失敗し、``無効な''インデックスが残った場合です。
こうしたインデックスは使用されませんが、\fBREINDEX\fRを使用して簡単に再作成することができます。
\fBREINDEX\fRでは同時構築ができないことに注意してください。
運用に影響を与えずにインデックスを作成するためには、インデックスを削除してから\fBCREATE INDEX CONCURRENTLY\fRコマンドを再発行しなければなりません。
.PP
.SH "パラメータ"
.TP
\fBINDEX\fR
指定したインデックスを再作成します。
.TP
\fBTABLE\fR
指定したテーブルの全インデックスを再作成します。
テーブルに2次的な``TOAST''テーブルがあっても、同様にインデックスを再作成します。
.TP
\fBDATABASE\fR
現在のデータベースのすべてのシステムインデックスを再作成します。
また、スタンドアロンモード（後述）以外のモードでは、共有システムカタログのインデックスは処理されません。
この構文の\fBREINDEX\fRをトランザクションブロック内で実行することはできません。
.TP
\fBSYSTEM\fR
現在のデータベースのすべてのシステムカタログのインデックスを再作成します。
ユーザテーブルのインデックスは処理されません。
また、スタンドアロンモード（後述）以外のモードでは、共有システムカタログのインデックスは処理されません。
この構文の\fBREINDEX\fRをトランザクションブロック内で実行することはできません。
.TP
\fB\fIname\fB\fR
インデックスを再作成するインデックス、テーブル、データベースの名前です。
インデックスとテーブルはスキーマで修飾可能です。
現状では、\fBREINDEX DATABASE\fRと\fBREINDEX SYSTEM\fRは現在のデータベースのインデックスのみを再作成することができます。
そのため、このパラメータは現在のデータベース名と一致する必要があります。
.TP
\fBFORCE\fR
このオプションは廃止されました。
指定されても無視されます。
.SH "注釈"
.PP
ユーザテーブル上の特定のインデックスに破損の疑いがある場合、そのインデックスを再構築してください。
テーブル上の全てのインデックスに破損の疑いがある場合は、\fBREINDEX INDEX\fRか\fBREINDEX TABLE\fRを使用してください。
.PP
システムテーブルのインデックスの破損を復旧する場合の手順はより複雑になります。
この場合、システムによって破損の可能性があるインデックス自体が使用されないようにすることが重要です
（実際は、このようなケースでは、破損したインデックスに依存していたため、サーバプロセスが起動時に強制終了してしまう可能性があります）。
安全に復旧させるには、システムカタログ検索時のインデックスの使用を禁止する\fB-P\fRオプションを使用してサーバを起動しなければなりません。
.PP
考えられる方法の1つは次の方法です。まず、サーバを停止して、コマンドラインから\fB-P\fRオプションを指定してシングルユーザ状態のPostgreSQLサーバを起動します。
そして、再構成する範囲に応じて、\fBREINDEX DATABASE\fR、\fBREINDEX SYSTEM\fR、\fBREINDEX TABLE\fR、または、\fBREINDEX INDEX\fRコマンドを発行します。
範囲が不明な場合は、\fBREINDEX SYSTEM\fRを使用して、そのデータベースの全てのシステムインデックスを再構成してください。
その後、シングルユーザ状態のサーバセッションを停止して、実サーバを再起動します。
シングルユーザ状態のサーバインタフェースの操作方法についての詳細は、\fBpostgres\fR(1)マニュアルページを参照してください。
.PP
その他、コマンドラインで\fB-P\fRを指定して実サーバセッションを起動することもできます。
具体的な方法は、クライアントによって異なります。
しかし、\fBlibpq\fRベースのクライアントであれば、クライアントを起動する前に\fBPGOPTIONS\fR環境変数を-Pに設定すれば実現できます。
この方法では他のクライアントを締め出す必要はありませんが、修復が終わるまで破損したデータベースへの他のユーザの接続を防止する方が良いことに注意してください。
.PP
共有システムカタログ（\fBpg_authid\fR、\fBpg_auth_members\fR、\fBpg_database\fR、\fBpg_pltemplate\fR、\fBpg_shdepend\fR、\fBpg_shdescription\fR、\fBpg_tablespace\fR）のいずれかのインデックスが破損した疑いがある場合は、スタンドアロンサーバを使用して修復しなければいけません。
\fBREINDEX\fRは、マルチユーザモードでは共有カタログを処理しません。
.PP
共有システムカタログ以外の全てのインデックスでは、\fBREINDEX\fRはクラッシュセーフかつトランザクションセーフです。
ただし、共有インデックスに対する\fBREINDEX\fRはクラッシュセーフではありません。
これが、通常の運用状態で実行できない理由です。
スタンドアロンモードで、これらのカタログのインデックス再作成処理中に問題が発生した場合、問題が修正されるまで実サーバを再起動することができなくなります
（共有インデックスの再構築が不十分であることを示す症状として、``index is not a btree''というエラーが発生することがよくあります）。
.PP
\fBREINDEX\fRは、インデックスの中身を1から作り直すという点では、インデックスを削除してから再作成する処理と似ています。
しかし、ロックに関しては異なります。
\fBREINDEX\fRはインデックスの元となるテーブルの書き込みをロックしますが、読み込みはロックしません。
また、処理中のインデックスに対する排他ロックを取得するので、そのインデックスを使用する読み込みはブロックされます。
一方、\fBDROP INDEX\fRは瞬間的に元となるテーブルの排他ロックを取得するので、書き込みも読み込みもブロックされます。
その後に行う\fBCREATE INDEX\fRでは書き込みのみをロックし、読み込みはロックしません。
インデックスは存在しないので、インデックスを使用する読み込みは発生しません。
したがって、読み込みがブロックされることはありませんが、コストが高いシーケンシャルスキャンの使用を強制されることになります。
この他、削除してから再作成する方法では、キャッシュ済みのインデックスを使用する問い合わせ計画が無効になりますが、\fBREINDEX\fRでは無効にならないことも重要な違いです。
.PP
単一インデックスまたは単一テーブルのインデックス再作成を行うには、そのインデックスまたはテーブルの所有者でなければなりません。
データベースに対するインデックス再作成を行うには、データベースの所有者でなければなりません（したがって、この所有者は他のユーザが所有するテーブルのインデックスを再作成することができます）。
もちろん、スーパーユーザは常にすべてのインデックス再作成を行うことができます。
.PP
PostgreSQL 8.1より前まででは、\fBREINDEX DATABASE\fRは名前から想像されるすべてのインデックスに対する処理ではなく、システムインデックスのみを処理していました。
\fBREINDEX SYSTEM\fRで、この以前の処理を行わせることができます。
.PP
PostgreSQL 7.4より前までは、\fBREINDEX TABLE\fRはTOASTテーブルに対して自動的に処理を行いませんでした。
そのため、別のコマンドでインデックスを再作成しなければなりませんでした。
現在でもこれは可能ですが、冗長です。
.SH "例"
.PP
単一のインデックスを再構築します。
.sp
.nf
REINDEX INDEX my_index;
.sp
.fi
.PP
my_tableテーブル上のすべてのインデックスを再構築します。
.sp
.nf
REINDEX TABLE my_table;
.sp
.fi
.PP
システムインデックスが有効かどうかを確認することなく、あるデータベース内の全てのインデックスを再構築します。
.sp
.nf
$ \fBexport PGOPTIONS="-P"\fR
$ \fBpsql broken_db\fR
...
broken_db=> REINDEX DATABASE broken_db;
broken_db=> \\q
.sp
.fi
.SH "互換性"
.PP
標準SQLには\fBREINDEX\fRはありません。
