.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER GROUP" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
ALTER GROUP \- ロールの名前またはメンバ資格を変更する

.SH SYNOPSIS
.sp
.nf
ALTER GROUP \fIgroupname\fR ADD USER \fIusername\fR [, ... ]
ALTER GROUP \fIgroupname\fR DROP USER \fIusername\fR [, ... ]

ALTER GROUP \fIgroupname\fR RENAME TO \fInewname\fR
.sp
.fi
.SH "説明"
.PP
\fBALTER GROUP\fRはユーザグループの属性を変更します。
後方互換性のために受け付けられていますが、このコマンドは廃止予定です。
グループ（ユーザも同様）は、より一般化されたロールという概念に置き換えられたからです。
.PP
最初の2つの構文は、ユーザをグループに追加もしくはグループから削除します
（この場合、任意のロールを``ユーザ''部分として、または``グループ'' 部分として使用することができます）。
この種の構文は、実のところ、``グループ''として指名された ロール内のメンバ資格の付与、削除と同じです。
ですので、GRANT [\fBgrant\fR(l)]やREVOKE [\fBrevoke\fR(l)]を使用する方法を薦めます。
.PP
3番目の構文はグループの名前を変更します。
これは、ALTER ROLE [\fBalter_role\fR(l)]を使用したロール名の変更とまったく同じです。
.SH "パラメータ"
.TP
\fB\fIgroupname\fB\fR
変更するグループ（ロール）の名前です。
.TP
\fB\fIusername\fB\fR
グループに追加または削除されるユーザ（ロール）です。
指定するユーザは存在するものでなければいけません。
\fBALTER GROUP\fRは、ユーザの作成も削除も行いません。
.TP
\fB\fInewname\fB\fR
新しいグループ名です。
.SH "例"
.PP
ユーザをグループに追加します。
.sp
.nf
ALTER GROUP staff ADD USER karl, john;
.sp
.fi
ユーザをグループから削除します。
.sp
.nf
ALTER GROUP workers DROP USER beth;
.sp
.fi
.SH "互換性"
.PP
標準SQLには\fBALTER GROUP\fR文はありません。
.SH "関連項目"
GRANT [\fBgrant\fR(l)], REVOKE [\fBrevoke\fR(l)], ALTER ROLE [\fBalter_role\fR(l)]
