.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ROLLBACK PREPARED" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
ROLLBACK PREPARED \- 事前に二相コミット用に準備されたトランザクションを取り消します。

.SH SYNOPSIS
.sp
.nf
ROLLBACK PREPARED \fItransaction_id\fR
.sp
.fi
.SH "説明"
.PP
\fBROLLBACK PREPARED\fRは、準備段階のトランザクションをロールバックします。
.SH "パラメータ"
.TP
\fB\fItransaction_id\fB\fR
ロールバックさせるトランザクションのトランザクション識別子です。
.SH "注釈"
.PP
準備されたトランザクションをロールバックするには、トランザクションを元々実行したユーザかスーパーユーザでなければなりません。
しかし、トランザクションを実行したセッション内で実行する必要はありません。
.PP
このコマンドはトランザクションブロック内では実行できません。
準備されたトランザクションは即座にロールバックされます。
.PP
現在利用できるすべての準備されたトランザクションは\fBpg_prepared_xacts\fRシステムビュー内に列挙されています。
.SH "例"
.PP
トランザクション識別子foobarで識別されるトランザクションをロールバックします。
.sp
.nf
ROLLBACK PREPARED 'foobar';
.sp
.fi
.SH "関連項目"
PREPARE TRANSACTION [\fBprepare_transaction\fR(l)], COMMIT PREPARED [\fBcommit_prepared\fR(l)]
