.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER INDEX" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
ALTER INDEX \- インデックス定義を変更する

.SH SYNOPSIS
.sp
.nf
ALTER INDEX \fIname\fR RENAME TO \fInew_name\fR
ALTER INDEX \fIname\fR SET TABLESPACE \fItablespace_name\fR
ALTER INDEX \fIname\fR SET ( \fIstorage_parameter\fR = \fIvalue\fR [, ... ] )
ALTER INDEX \fIname\fR RESET ( \fIstorage_parameter\fR [, ... ] )
.sp
.fi
.SH "説明"
.PP
\fBALTER INDEX\fRは既存のインデックスの定義を変更します。
以下のような副構文が存在します。
.TP
\fBRENAME\fR
このRENAME構文は、インデックスの名前を変更します。
格納されたデータには影響しません。
.TP
\fBSET TABLESPACE\fR
この構文は、インデックスのテーブル空間を指定したテーブル空間に変更し、インデックスに関連する（複数の）データファイルを移動します。
CREATE TABLESPACE [\fBcreate_tablespace\fR(l)]も参照してください。
.TP
\fBSET ( \fIstorage_parameter\fB = \fIvalue\fB [, ... ] )\fR
この構文は、インデックスに対し、インデックスメソッド固有の1つ以上の格納パラメータを変更します。
設定可能なパラメータについてはCREATE INDEX [\fBcreate_index\fR(l)]を参照してください。
このコマンドにより、インデックスの内容は即座に変更されないことに注意してください。
パラメータによりますが、予定の効果を得るためにREINDEX [\fBreindex\fR(l)]を使用してインデックスを再構築しなければならない場合もあります。
.TP
\fBRESET ( \fIstorage_parameter\fB [, ... ] )\fR
この構文は、1つ以上のインデックスメソッド固有の格納パラメータをデフォルト値に再設定します。
SET同様、インデックスを完全に更新するためにREINDEXが必要になる場合があります。
.PP
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
変更対象の既存のインデックスの名前です（スキーマ修飾名も可）。
.TP
\fB\fInew_name\fB\fR
インデックスの新しい名前です。
.TP
\fB\fItablespace_name\fB\fR
インデックスの移動先のテーブル空間です。
.TP
\fB\fIstorage_parameter\fB\fR
インデックスメソッド固有の格納パラメータの名前です。
.TP
\fB\fIvalue\fB\fR
インデックスメソッド固有の格納パラメータの新しい値です。
パラメータに応じてこれが数値になることも文字列になることもあります。
.SH "注釈"
.PP
これらの操作はALTER TABLE [\fBalter_table\fR(l)]を使用して行うこともできます。
実際には、\fBALTER INDEX\fRは、\fBALTER TABLE\fRのインデックス用構文の別名に過ぎません。
.PP
以前は\fBALTER INDEX OWNER\fRという種類の構文がありましたが、（警告なく）無視されるようになりました。
インデックスの所有者は基のテーブルの所有者と異なるものにすることができません。
テーブルの所有者を変更すると自動的にインデックスの所有者も変わります。
.PP
システムカタログ用インデックスに対する変更は許されていません。
.SH "例"
.PP
既存のインデックスの名前を変更します。
.sp
.nf
ALTER INDEX distributors RENAME TO suppliers;
.sp
.fi
.PP
インデックスを別のテーブル空間に移動します。
.sp
.nf
ALTER INDEX distributors SET TABLESPACE fasttablespace;
.sp
.fi
.PP
インデックスのFILLファクタを変更します（インデックスメソッドがFILLファクタをサポートしていることを仮定します）。
.sp
.nf
ALTER INDEX distributors SET (fillfactor = 75);
REINDEX INDEX distributors;
.sp
.fi
.SH "互換性"
.PP
\fBALTER INDEX\fRはPostgreSQLの拡張です。
.SH "関連項目"
CREATE INDEX [\fBcreate_index\fR(l)], REINDEX [\fBreindex\fR(l)]
