.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CREATE TRIGGER" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
CREATE TRIGGER \- 新しいトリガを定義する

.SH SYNOPSIS
.sp
.nf
CREATE TRIGGER \fIname\fR { BEFORE | AFTER } { \fIevent\fR [ OR ... ] }
    ON \fItable\fR [ FOR [ EACH ] { ROW | STATEMENT } ]
    EXECUTE PROCEDURE \fIfuncname\fR ( \fIarguments\fR )
.sp
.fi
.SH "説明"
.PP
\fBCREATE TRIGGER\fRは新しいトリガを作成します。
作成したトリガは指定したテーブルと関連付けられ、特定のイベントが発生した時に指定した関数\fIfuncname\fRを実行します。
.PP
トリガでは、起動のタイミングとして、行への操作が開始される前（制約条件のチェックと\fBINSERT\fR、\fBUPDATE\fRまたは\fBDELETE\fRが行われる前）、あるいは、操作が完了した後（制約条件がチェックされ、\fBINSERT\fR、\fBUPDATE\fRまたは\fBDELETE\fRが完了した後）のいずれかを指定することができます。
イベントの前にトリガが起動する場合、そのトリガは対象行に対する操作を省略したり、（\fBINSERT\fRと\fBUPDATE\fRの操作時のみ）挿入する行を変更したりすることができます。
イベントの後にトリガが起動する場合、最後に行われた挿入、更新、削除などの全ての変更が、トリガに対して``可視''状態となります。
.PP
FOR EACH ROW付きのトリガは、その操作によって変更される行ごとに1回ずつ呼び出されます。
例えば、10行に影響を与える\fBDELETE\fR操作は、対象リレーション上のON DELETEトリガを、行が削除される度に1回ずつ、個別に10回呼び出すことになります。
反対に、FOR EACH STATEMENT付きのトリガは、その操作によって何行変更されたかにかかわらず、任意の操作ごとに1回のみ実行されます
（変更対象が0行となる操作でも、適用できるFOR EACH STATEMENTトリガがあれば実行されます）。
.PP
同一イベントに同じ種類の複数のトリガが定義された場合、名前のアルファベット順で実行されます。
.PP
\fBSELECT\fRはまったく行を変更しないため、\fBSELECT\fRトリガを作成することはできません。
この場合は、ルールやビューの方が適しています。
.PP
トリガに関するより詳細については、in the documentationを参照してください。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
新しいトリガに付与する名前です。
同じテーブルの他のトリガと異なる名前にする必要があります。
.TP
\fBBEFORE\fR
.TP
\fBAFTER\fR
関数の呼び出しをイベントの前に行うか後に行うかを決定します。
.TP
\fB\fIevent\fB\fR
\fBINSERT\fR、\fBUPDATE\fR、\fBDELETE\fRのいずれかが入ります。
このパラメータは、トリガを起動するイベントを指定します。
ORを使用して、複数のイベントを指定することができます。
.TP
\fB\fItable\fB\fR
トリガを作成するテーブルの名前です（スキーマ修飾名も可）。
.TP
\fBFOR EACH ROW\fR
.TP
\fBFOR EACH STATEMENT\fR
このパラメータは、トリガプロシージャを、トリガイベントによって影響を受ける行ごとに1回起動するか、SQL文ごとに1回のみ起動するかを指定します。
どちらも指定されない場合は、FOR EACH STATEMENTがデフォルトです。
.TP
\fB\fIfuncname\fB\fR
ユーザが提供する関数です。この関数は、引数を取らずtrigger型を返すよう定義します。トリガが起動した時に実行されます。
.TP
\fB\fIarguments\fB\fR
トリガ実行時に関数に渡される引数をカンマで区切ったリストです。このパラメータは省略可能です。
引数として指定するのは、リテラル文字列定数です。
単純な名前および数値定数を記述できますが、全て文字列に変換されます。
関数内でこのトリガ引数にアクセスする方法については、トリガ関数を実装した言語の説明を参照してください。
通常の関数引数とは異なる場合があります。
.SH "注釈"
.PP
テーブルにトリガを作成するには、ユーザがそのテーブルに対しTRIGGER権限を持っている必要があります。
.PP
PostgreSQL 7.3より前のバージョンでは、トリガ関数の戻り値の型を、\fBtrigger\fR型ではなくプレースホルダである\fBopaque\fR型として宣言する必要がありました。
古いダンプファイルのロードをサポートするため、\fBCREATE TRIGGER\fRでは\fBopaque\fR型を返すよう宣言された関数を受け入れます。
しかし、注意を促すメッセージを表示し、宣言された関数の戻り値型を\fBtrigger\fRに変換します。
.PP
トリガを削除するには、DROP TRIGGER [\fBdrop_trigger\fR(l)]コマンドを使用してください。
.SH "例"
.PP
in the documentationに完全な例があります。
.SH "互換性"
.PP
PostgreSQLにおける\fBCREATE TRIGGER\fR文は標準SQLのサブセットを実装したものです
ただし、PostgreSQLには、次の機能がありません。
.TP 0.2i
\(bu
SQLでは、指定した列への更新時に起動するトリガを認めています
（例えば、AFTER UPDATE OF col1, col2）。
.TP 0.2i
\(bu
SQLでは、``old''や``new''、トリガによって起動する動作の定義が使用するテーブルに、別名を定義することができます。
（例えば、CREATE TRIGGER ... ON tablename REFERENCING OLD ROW AS somename NEW ROW AS othername ...）。
PostgreSQLでは、複数のユーザ定義言語でトリガプロシージャを作成できるので、データへのアクセスは言語固有の方法で扱われます。
.TP 0.2i
\(bu
PostgreSQLでは、トリガ動作として、1つのユーザ定義関数の実行しか認めていません。
標準では、他のSQLコマンドを複数実行させることができます。
例えば、トリガ動作として\fBCREATE TABLE\fRを実行させることも可能です。
この制限を回避する方法は簡単です。必要なコマンドを実行するユーザ定義関数を作成すればよいのです。
.PP
.PP
SQLでは、複数のトリガは、作成時刻順に起動すべきであると規定しています。
PostgreSQLでは名前順であり、より簡単に判断することができます。
.PP
SQLでは、数珠繋ぎの削除に対するBEFORE DELETEは、数珠繋ぎのDELETEが完了した\fB後に\fR発行するものと規定しています。
PostgreSQLでは、BEFORE DELETEは常に削除操作よりも後に行われます。
この方がより一貫性があると考えています。
また、参照性合成に関する操作によって後で変更される行をBEFOREトリガが変更する時の振舞いは予測できません。
これは、制約違反となるかもしれませんし、参照性合成制約に合わないデータを格納してしまうかもしれません。
.PP
ORを使用して単一トリガに複数の動作を指定する機能は、標準SQLに対するPostgreSQLの拡張です。
.SH "関連項目"
CREATE FUNCTION [\fBcreate_function\fR(l)], ALTER TRIGGER [\fBalter_trigger\fR(l)], DROP TRIGGER [\fBdrop_trigger\fR(l)]
