.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER OPERATOR" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
ALTER OPERATOR \- 演算子の定義を変更する

.SH SYNOPSIS
.sp
.nf
ALTER OPERATOR \fIname\fR ( { \fIlefttype\fR | NONE } , { \fIrighttype\fR | NONE } ) OWNER TO \fInewowner\fR
.sp
.fi
.SH "説明"
.PP
\fBALTER OPERATOR\fRは演算子の定義を変更します。
現在、演算子の所有者の変更のみが可能です。
.PP
\fBALTER OPERATOR\fRを使用するには演算子の所有者でなければなりません。
所有者を変更するには、直接または間接的に新しい所有者ロールのメンバでなければなりません。
また、そのロールが演算子のスキーマにおいてCREATEを持たなければなりません。
（この制限により、強制的に、所有者の変更が演算子の削除と再作成で行うことができない何らかの処理を行わないようになります。
しかし、スーパーユーザはすべての演算子の所有者を変更することができます。）
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
既存の演算子の名前です（スキーマ修飾名も可）。
.TP
\fB\fIlefttype\fB\fR
演算子の左オペランドのデータ型です。
左オペランドがない演算子の場合はNONEを指定します。
.TP
\fB\fIrighttype\fB\fR
演算子の右オペランドのデータ型です。
右オペランドがない演算子の場合はNONEを指定します。
.TP
\fB\fInewowner\fB\fR
新しい演算子の所有者です。
.SH "例"
.PP
\fBtext\fR型用の独自の演算子a @@ bの所有者を変更します。
.sp
.nf
ALTER OPERATOR @@ (text, text) OWNER TO joe;
.sp
.fi
.SH "互換性"
.PP
標準SQLには\fBALTER OPERATOR\fR文はありません。
.SH "関連項目"
CREATE OPERATOR [\fBcreate_operator\fR(l)], DROP OPERATOR [\fBdrop_operator\fR(l)]
