.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER TYPE" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
ALTER TYPE \- 型定義を変更する

.SH SYNOPSIS
.sp
.nf
ALTER TYPE \fIname\fR OWNER TO \fInew_owner\fR 
ALTER TYPE \fIname\fR SET SCHEMA \fInew_schema\fR
  
.sp
.fi
.SH "説明"
.PP
\fBALTER TYPE\fRは既存の型の定義を変更します。
現在変更できるのは、型の所有者とスキーマのみです。
.PP
\fBALTER TYPE\fRを使用するには型の所有者でなければなりません。
型のスキーマを変更するには、新しいスキーマにおけるCREATE権限も必要です。
所有者を変更するには、直接または間接的に新しい所有者ロールのメンバでなければなりません。
また、そのロールが型のスキーマにおいてCREATEを持たなければなりません。
（この制限により、強制的に、所有者の変更が型の削除と再作成で行うことができない何らかの処理を行わないようになります。
しかし、スーパーユーザはすべての型の所有者を変更することができます。）
.SH "パラメータ"
.PP
.TP
\fB\fIname\fB\fR
変更対象の既存の型の名前です（スキーマ修飾名も可）。
.TP
\fB\fInew_owner\fB\fR
新しい型の所有者のユーザ名です。
.TP
\fB\fInew_schema\fB\fR
型の新しいスキーマです。
.PP
.SH "例"
.PP
emailユーザ定義型の所有者をjoeに変更します。
.sp
.nf
ALTER TYPE email OWNER TO joe;
   
.sp
.fi
.PP
emailユーザ定義型のスキーマをcustomersに変更します。
.sp
.nf
ALTER TYPE email SET SCHEMA customers;
   
.sp
.fi
.SH "互換性"
.PP
標準SQLには\fBALTER TYPE\fR文はありません。
