.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "LISTEN" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
LISTEN \- 通知を監視する

.SH SYNOPSIS
.sp
.nf
LISTEN \fIname\fR
.sp
.fi
.SH "説明"
.PP
\fBLISTEN\fRは現在のセッションを、通知条件\fIname\fRのリスナとして登録します。
現在のセッションが既に指定した通知条件のリスナとして登録されている場合は、何も起こりません。
.PP
このセッションまたは同一データベースに接続している別のセッションによって\fBNOTIFY \fIname\fB\fRが実行されると、現在その通知条件を監視している全てのセッションに対して通知されます。 
次に、各セッションは接続中のクライアントアプリケーションにこれを通知します。
詳細については\fBNOTIFY\fRを参照してください。
.PP
\fBUNLISTEN\fRコマンドを使って、セッションに登録された指定通知条件を解除できます。
また、セッションの監視登録はそのセッションが終了した時点で自動的に削除されます。
.PP
クライアントアプリケーションが通知イベントを検出する方法は、使用しているPostgreSQLアプリケーションプログラミングインタフェースに依存します。
\fBlibpq\fRライブラリを使用するアプリケーションでは、\fBLISTEN\fRを通常のSQLコマンドとして発行し、その後、\fBPQnotifies\fRルーチンを定期的に呼び出して通知イベントが受信されたかどうかを調べる必要があります。
\fBlibpgtcl\fR等の他のインタフェースには、通知イベントを扱うより高レベルな方法が用意されています。
実際、\fBlibpgtcl\fRを使ったアプリケーションの場合、プログラマが\fBLISTEN\fRや\fBUNLISTEN\fRを直接発行する必要すらありません。
詳細については、使用中のインタフェースのドキュメントを参照してください。
.PP
NOTIFY [\fBnotify\fR(l)]には、\fBLISTEN\fRおよび\fBNOTIFY\fRについてのより広範な説明があります。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
通知条件の名前です（任意の識別子）。
.SH "例"
.PP
\fBpsql\fRから、監視/通知処理の設定と実行を行います。
.sp
.nf
LISTEN virtual;
NOTIFY virtual;
Asynchronous notification "virtual" received from server process with PID 8448.
.sp
.fi
.SH "互換性"
.PP
標準SQLに\fBLISTEN\fRはありません。
.SH "関連項目"
NOTIFY [\fBnotify\fR(l)], UNLISTEN [\fBunlisten\fR(l)]
