.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP OPERATOR" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
DROP OPERATOR \- 演算子を削除する

.SH SYNOPSIS
.sp
.nf
DROP OPERATOR [ IF EXISTS ] \fIname\fR ( { \fIlefttype\fR | NONE } , { \fIrighttype\fR | NONE } ) [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBDROP OPERATOR\fRはデータベースシステムから既存の演算子を削除します。
このコマンドを実行するには、その演算子の所有者でなければなりません。
.SH "パラメータ"
.TP
\fBIF EXISTS\fR
演算子が存在しない場合でもエラーになりません。
この場合注意メッセージが発行されます。
.TP
\fB\fIname\fB\fR
既存の演算子の名前です（スキーマ修飾名も可）。
.TP
\fB\fIlefttype\fB\fR
演算子の左項のデータ型です。
演算子に左項がない場合は、NONEと記述します。
.TP
\fB\fIrighttype\fB\fR
演算子の右項のデータ型です。
演算子に右項がない場合は、NONEと記述します。
.TP
\fBCASCADE\fR
演算子に依存するオブジェクトを自動的に削除します。
.TP
\fBRESTRICT\fR
依存するオブジェクトがある場合、演算子の削除を拒否します。
これがデフォルトです。
.SH "例"
.PP
\fBinteger\fR型の累乗を行う演算子a^nを削除します。
.sp
.nf
DROP OPERATOR ^ (integer, integer);
.sp
.fi
.PP
\fBbit\fR型のビット列の否定を行う左単項演算子~bを削除します。
.sp
.nf
DROP OPERATOR ~ (none, bit);
.sp
.fi
.PP
\fBbigint\fR型の階乗を行う右単項演算子x!を削除します。
.sp
.nf
DROP OPERATOR ! (bigint, none);
.sp
.fi
.SH "互換性"
.PP
標準SQLには\fBDROP OPERATOR\fR文はありません。
.SH "関連項目"
CREATE OPERATOR [\fBcreate_operator\fR(l)], ALTER OPERATOR [\fBalter_operator\fR(l)]
