.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER TABLE" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
ALTER TABLE \- テーブル定義を変更する

.SH SYNOPSIS
.sp
.nf
ALTER TABLE [ ONLY ] \fIname\fR [ * ]
    \fIaction\fR [, ... ]
ALTER TABLE [ ONLY ] \fIname\fR [ * ]
    RENAME [ COLUMN ] \fIcolumn\fR TO \fInew_column\fR
ALTER TABLE \fIname\fR
    RENAME TO \fInew_name\fR
ALTER TABLE \fIname\fR
    SET SCHEMA \fInew_schema\fR

ここで、\fIaction\fRは以下のいずれかです。

    ADD [ COLUMN ] \fIcolumn\fR \fItype\fR [ \fIcolumn_constraint\fR [ ... ] ]
    DROP [ COLUMN ] \fIcolumn\fR [ RESTRICT | CASCADE ]
    ALTER [ COLUMN ] \fIcolumn\fR TYPE \fItype\fR [ USING \fIexpression\fR ]
    ALTER [ COLUMN ] \fIcolumn\fR SET DEFAULT \fIexpression\fR
    ALTER [ COLUMN ] \fIcolumn\fR DROP DEFAULT
    ALTER [ COLUMN ] \fIcolumn\fR { SET | DROP } NOT NULL
    ALTER [ COLUMN ] \fIcolumn\fR SET STATISTICS \fIinteger\fR
    ALTER [ COLUMN ] \fIcolumn\fR SET STORAGE { PLAIN | EXTERNAL | EXTENDED | MAIN }
    ADD \fItable_constraint\fR
    DROP CONSTRAINT \fIconstraint_name\fR [ RESTRICT | CASCADE ]
    DISABLE TRIGGER [ \fItrigger_name\fR | ALL | USER ]
    ENABLE TRIGGER [ \fItrigger_name\fR | ALL | USER ]
    CLUSTER ON \fIindex_name\fR
    SET WITHOUT CLUSTER
    SET WITHOUT OIDS
    SET ( \fIstorage_parameter\fR = \fIvalue\fR [, ... ] )
    RESET ( \fIstorage_parameter\fR [, ... ] )
    INHERIT \fIparent_table\fR
    NO INHERIT \fIparent_table\fR
    OWNER TO \fInew_owner\fR
    SET TABLESPACE \fInew_tablespace\fR
.sp
.fi
.SH "説明"
.PP
\fBALTER TABLE\fRは既存のテーブルの定義を変更します。 
このコマンドには、次のような副構文があります。
.TP
\fBADD COLUMN\fR
この構文を使用すると、CREATE TABLE [\fBcreate_table\fR(l)]と同じ構文を使って新しい列をテーブルに追加できます。
.TP
\fBDROP COLUMN\fR
この構文を使用すると、テーブルから列を削除できます。 
削除する列を含んでいるインデックスおよびテーブル制約も自動的に削除されます。 
また、削除する列にテーブル以外（例えば、外部キー制約、ビューなど）が依存している場合、CASCADEを付ける必要があります。
.TP
\fBALTER COLUMN TYPE\fR
この構文を使用すると、テーブルの列の型を変更できます。
その列を含むインデックスと簡単なテーブル制約は、元々与えられた式を再解析し、新しい型を使用するように自動的に変換されます。
USING句は、古い列値をどのように新しい値に計算するかを指定します。この句は省略可能です。
省略された場合、デフォルトの変換は、古いデータ型から新しいデータ型への代入キャストと同じになります。
古いデータ型から新しいデータ型への暗黙キャストあるいは代入キャストがない場合、USING句を指定しなければなりません。
.TP
\fBSET/DROP DEFAULT\fR
これらの構文を使用すると、列のデフォルト値を設定または削除できます。
指定したデフォルト値は、変更後に行われる\fBINSERT\fRコマンドのみに適用されます。 
テーブル内の既存の行は変更されません。 
デフォルト値はビューに対して設定することも可能です。
この場合、ビューのON INSERTルールが適用される前に、ビューの\fBINSERT\fR文にデフォルトが挿入されます。
.TP
\fBSET/DROP NOT NULL\fR
これらの構文は、列の値としてNULL値を使用できるかどうか設定します。
SET NOT NULLは、その列にNULL値が1つもない場合にのみ設定可能です。
.TP
\fBSET STATISTICS\fR
この構文は、コマンド実行後に行なわれるANALYZE [\fBanalyze\fR(l)]操作において、列単位での統計情報収集対象を設定します。
対象として、0から1000までの範囲の値を設定可能です。
対象を-1に設定すると、システムのデフォルト統計情報対象（default_statistics_target）が使用されます。
PostgreSQLの問い合わせプランナによる統計情報の使用に関する詳細は、in the documentationを参照してください。

.TP
\fBSET STORAGE\fR
この構文は、列の保管モードを設定します。
列をインラインで保持するか補足テーブルに保持するか、また、データを圧縮するかどうかを制御できます。
PLAINは、\fBinteger\fRのような固定長の値に対して使用します。インラインで保持され、圧縮されません。
MAINは、インラインで保持されていて、圧縮可能なデータに使用します。
EXTERNALは圧縮されていない外部データに使用します。
EXTENDEDは圧縮された外部データに使用します。
EXTENDEDは、PLAIN以外の保管をサポートするほとんどのデータ型におけるデフォルトです。
EXTERNALを使用すると、\fBtext\fRおよび\fBbytea\fR列に対する部分文字列操作の処理速度が向上しますが、必要な保管容量が増えるというデメリットがあります。
SET STORAGE自体はテーブルをまったく変更しないことに注意してください。
以後のテーブルの更新時に遂行する戦略を設定するだけです。
詳細はin the documentationを参照してください。
.TP
\fBADD \fItable_constraint\fB\fR
この構文を使用すると、CREATE TABLE [\fBcreate_table\fR(l)]と同じ構文を使って新しい制約をテーブルに追加できます。
.TP
\fBDROP CONSTRAINT\fR
この構文を使用すると、テーブル上の指定した制約を削除できます。 
.TP
\fBDISABLE/ENABLE TRIGGER\fR
この構文を使用すると、テーブルに属するトリガを無効または有効にすることができます。
無効にされたトリガはシステム上に存在し続けますが、トリガイベントが発生したとしても実行されません。
遅延トリガの場合、有効無効状態の確認は、トリガ関数を実際に実行しようとする時ではなく、イベントの発生時に行われます。
名前でトリガを1つ指定して有効または無効にすることもできますし、テーブル上のすべてのトリガを指定することもできます。
また、ユーザトリガのみを指定することも可能です（このオプションは外部キー制約を実装するために使用されるトリガを除外します）。
制約用のトリガを有効または無効にするにはスーパーユーザ権限が必要です。
トリガが実行されなかった場合に当然ながら制約の整合性が保証されませんので、注意して実行しなければなりません。
.TP
\fBCLUSTER\fR
この構文は、以後のCLUSTER [\fBcluster\fR(l)]操作用のデフォルトインデックスを選択します。
実際のテーブルの再クラスタ化は行いません。
.TP
\fBSET WITHOUT CLUSTER\fR
この構文は、テーブルから、一番最後に適用されたCLUSTER [\fBcluster\fR(l)]インデックス指定を削除します。
以後のインデックスを指定しないクラスタ操作に影響を及ぼします。
.TP
\fBSET WITHOUT OIDS\fR
この構文は、テーブルからoidシステム列を削除します。
既にoid列が存在しなくても警告が表示されない点を除けば、DROP COLUMN oid RESTRICTとまったく同等です。

OIDを削除後、再度テーブルにOIDを保存するよう指定する\fBALTER TABLE\fRの副構文は存在しないことに注意してください。
.TP
\fBSET ( \fIstorage_parameter\fB = \fIvalue\fB [, ... ] )\fR
この構文は、1つ以上のテーブルの格納パラメータを変更します。
設定可能なパラメータに関してはCREATE TABLE [\fBcreate_table\fR(l)]を参照してください。
このコマンドによってテーブルの内容が即座に変更されない点に注意してください。
パラメータによりますが、予定の効果を得るためにテーブルを書き換える必要がある場合があります。
このためには、テーブルを強制的に書き換えるCLUSTER [\fBcluster\fR(l)]または\fBALTER TABLE\fRの構文のいずれかを使用してください。
.sp
.RS
.B "Note:"
\fBCREATE TABLE\fRではOIDSをWITH (\fIstorage_parameter\fR)構文で指定することができますが、\fBALTER TABLE\fRではOIDSを格納パラメータとして扱っていません。
.RE
.sp
.TP
\fBRESET ( \fIstorage_parameter\fB [, ... ] )\fR
この構文は、1つ以上の格納パラメターをデフォルト値に再設定します。
SET同様、テーブル全体を更新するためにテーブルの書き換えが必要になる場合があります。
.TP
\fBINHERIT \fIparent_table\fB\fR
この構文は、対象テーブルを指定した親テーブルの子テーブルとして追加します。
その後に行われる親テーブルへの問い合わせには対象テーブルの項目も含まれます。
子テーブルとして追加するためには、対象テーブルには親テーブルと同じ列がすべて含まれていなければなりません。
（この他の列を持つこともできます。）
これらの列のデータ型は一致している必要があり、親テーブルでNOT NULL制約がある場合は、子テーブルでも同様にNOT NULL制約を持たなければなりません。

また、親テーブルのCHECK制約すべてについても、一致する制約が子テーブルに存在しなければなりません。
現時点ではUNIQUE、PRIMARY KEY、FOREIGN KEY制約は無視されますが、将来変更されるかもしれません。
.TP
\fBNO INHERIT \fIparent_table\fB\fR
この構文は、指定した親テーブルから子テーブル群を削除します。
親テーブルへの問い合わせでは、対象としたテーブルからのデータが含まれなくなります。
.TP
\fBOWNER\fR
この形式を使用すると、テーブル、シーケンス、またはビューの所有者を、指定したユーザに変更できます。
.TP
\fBSET TABLESPACE\fR
この構文を使用すると、テーブルのテーブル空間を指定したテーブル空間に変更し、テーブルに関連するデータファイルを新しいテーブル空間に移動することができます。
テーブルにインデックスがあっても移動されません。
インデックスを移動するには、別途SET TABLESPACEコマンドを実行します。
CREATE TABLESPACE [\fBcreate_tablespace\fR(l)]も参照してください。
.TP
\fBRENAME\fR
RENAME構文を使用すると、テーブル（もしくは、インデックス、シーケンス、ビュー）の名前や、テーブルの個々の列名を変更できます。 
格納されているデータへの影響はありません。
.TP
\fBSET SCHEMA\fR
この構文を使用して、テーブルを別のスキーマに移動することができます。
関連するインデックスや制約、テーブル列により所有されるシーケンスも同様に移動されます。
.PP
.PP
RENAMEおよびSET SCHEMA以外の全ての操作は、結合して複数の変更リストにまとめて、並行に処理することができます。
例えば、複数の列の追加、型の変更を単一のコマンドで実行することができます。
これは特に巨大なテーブルでは便利です。変更のために必要なテーブル全体の走査が1回で済むからです。
.PP
\fBALTER TABLE\fRコマンドを使用するには、変更するテーブルを所有している必要があります。
テーブルのスキーマを変更するには、新しいスキーマにおけるCREATE権限も持たなければなりません。
親テーブルに新しい子テーブルを追加するには、親テーブルも同様に所有している必要があります。
また、所有者を変更するには、新しい所有ロールの直接あるいは間接的なメンバでなければならず、かつ、そのロールがテーブルのスキーマにおけるCREATE権限を持たなければなりません
（この制限により強制的に所有者の変更が、テーブルの削除と再作成を行ってもできないことを行わないようにします。
ただし、スーパーユーザはすべてのテーブルの所有者を変更することができます）。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
変更対象となる既存のテーブルの名前です（スキーマ修飾名も可）。 
ONLYが指定された場合、そのテーブルのみが変更されます。 
ONLYが指定されていない場合、そのテーブルおよび（存在する場合は）そのテーブルを継承する全てのテーブルが更新されます。 
テーブル名に *を付けると継承テーブルが変更されることを明示できますが、現在のバージョンでは、継承テーブルの変更はデフォルトで行われます
（7.1より前のリリースでは、ONLYがデフォルトでした。
デフォルトの設定は、sql_inheritance設定オプションで変更できます）。
.TP
\fB\fIcolumn\fB\fR
新規または既存の列の名前です。
.TP
\fB\fInew_column\fB\fR
既存の列の新しい名前です。
.TP
\fB\fInew_name\fB\fR
テーブルの新しい名前です。
.TP
\fB\fItype\fB\fR
新しい列のデータ型、もしくは既存の列に対する新しいデータ型です。
.TP
\fB\fItable_constraint\fB\fR
テーブルの新しいテーブル制約です。
.TP
\fB\fIconstraint_name\fB\fR
削除する既存の制約の名前です。
.TP
\fBCASCADE\fR
削除された列や制約に依存しているオブジェクト（例えば、削除された列を参照しているビューなど）を、自動的に削除します。
.TP
\fBRESTRICT\fR
依存しているオブジェクトがある場合、列または制約の削除要求を拒否します。
これがデフォルトの動作です。
.TP
\fB\fItrigger_name\fB\fR
有効または無効にする単一のトリガの名前です。
.TP
\fBALL\fR
テーブルに属するすべてのトリガを有効または無効にします。
（外部キー制約用のトリガが含まれる場合、スーパーユーザ権限が必要です。）
.TP
\fBUSER\fR
外部キー制約用のトリガ以外のテーブルに属するトリガすべてを有効または無効にします。
.TP
\fB\fIindex_name\fB\fR
指定したインデックス名でテーブルをクラスタ化するように印を付けます。
.TP
\fB\fIstorage_parameter\fB\fR
テーブルの格納パラメータの名前です。
.TP
\fB\fIvalue\fB\fR
テーブルの格納パラメータの新しい値です。
パラメータによりこれは数値となることも文字列となることもあります。
.TP
\fB\fIparent_table\fB\fR
このテーブルに関連付ける、または、このテーブルから関連付けを取り除く親テーブルです。
.TP
\fB\fInew_owner\fB\fR
テーブルの新しい所有者のユーザ名です。
.TP
\fB\fInew_tablespace\fB\fR
テーブルを移動する先のテーブル空間の名前です。
.TP
\fB\fInew_schema\fB\fR
テーブルを移動する先のスキーマの名前です。
.SH "注釈"
.PP
COLUMNキーワードはノイズであり、省略可能です。
.PP
ADD COLUMNによって列を追加した時、テーブル内の既存行に追加された列は、全てデフォルト値（DEFAULTが指定されていない場合はNULL）で初期化されます。
.PP
NULLではないデフォルト値を持つ列を追加したり、既存の列の型を変更するには、テーブル全体の書き換えが必要になります。
テーブルが巨大な場合、この処理に非常に時間がかかる可能性があります。また、一時的に2倍のディスク容量が必要とされます。
.PP
CHECKあるいはNOT NULL制約を追加する時は、既存の行が制約に従うかどうかを検証するためにテーブルの走査が必要になります。
.PP
単一の\fBALTER TABLE\fR内に複数の変更を指定できるオプションを提供する主な理由は、複数のテーブル走査や書き換えを1回のテーブル走査にまとめることができるようにすることです。
.PP
DROP COLUMN構文は、列を物理的には削除せず、SQLを操作する上で不可視にします。 
このコマンドを実行した後、テーブルに挿入または更新が行われると、削除した列にはNULLが格納されます。 
したがって、列の削除は短時間で行えます。
しかし、削除された列が占めていた領域がまだ回収されていないため、テーブルのディスク上のサイズはすぐには小さくなりません。 
この領域は、その後既存の行が更新されるタイミングで回収されます。 
.PP
ALTER TYPEがテーブル全体の書き換えを必要とすることが利点になる場合もあります。
書き換え処理によって、テーブル内の不要となった領域が除去されるからです。
例えば、削除した列が使用していた領域を即座に回収したい場合、最も高速なコマンドは次のようになります。
.sp
.nf
ALTER TABLE table ALTER COLUMN anycol TYPE anytype;
.sp
.fi
ここでanycolには既存のテーブル列を、anytypeには既存の列と同一の型を指定します。
このコマンドを実行すると、見た目にはテーブルに有意な変更はありませんが、不要となったデータを取り除く強制的な書き換えが行われます。
.PP
ALTER TYPEのUSINGオプションでは、その行の古い値を含め、どのような式でも指定できます。
つまり、変換対象の列と同様に、その他の列も参照することができます。
そのため、一般的な変換をALTER TYPE構文で行うことができます。
この柔軟性のため、USING式は列のデフォルト値には（仮に存在していても）適用されません。
結果が定数式にならない可能性があるためです（デフォルト値は定数式でなければいけません）。
したがって、古い型から新しい型への暗黙キャストや代入キャストが存在しない場合、USINGが指定されていても、ALTER TYPEがデフォルト値の変換に失敗する可能性があります。
この場合は、DROP DEFAULTでデフォルト値を削除し、ALTER TYPEを実行した後で、SET DEFAULTを使用して再度適切なデフォルト値を指定してください。
変更対象の列を持つインデックスと制約も同様の配慮が必要です。
.PP
そのテーブルを継承するテーブルがある場合、子テーブルに同じ処理を実行しなければ、親テーブルに対する列の追加、列の名前、型の変更を実行することはできません。
つまり、\fBALTER TABLE ONLY\fRコマンドは受け付けられません。
この制限により、子テーブルの列が常に親テーブルと一致していることが保証されます。
.PP
再帰的なDROP COLUMN操作では、子テーブルが他の親テーブルからその列を継承しておらず、かつ、独立した列定義を持っていない場合のみ、その子テーブルの列を削除します。 
再帰的でないDROP COLUMN（例えば、\fBALTER TABLE ONLY ... DROP COLUMN\fRなど）操作では、継承された列は削除されません。
削除する代わりに、その列は継承されておらず独立して定義されているという印を付けます。
.PP
TRIGGER、CLUSTER、OWNERおよびTABLESPACEは子テーブルに再帰的に伝わりません。
つまり、常にONLYが指定されているかのように動作します。
制約の追加は、CHECK制約に関してのみ再帰的に伝わります。
.PP
システムカタログテーブルについては、いかなる部分の変更も許可されていません。
.PP
有効なパラメータの詳しい説明はCREATE TABLE [\fBcreate_table\fR(l)]を参照してください。
in the documentationに、継承に関するさらに詳しい情報があります。
.SH "例"
.PP
\fBvarchar\fR型の列をテーブルに追加します。
.sp
.nf
ALTER TABLE distributors ADD COLUMN address varchar(30);
.sp
.fi
.PP
テーブルから列を削除します。
.sp
.nf
ALTER TABLE distributors DROP COLUMN address RESTRICT;
.sp
.fi
.PP
1つの操作で既存の2つの列の型を変更します。
.sp
.nf
ALTER TABLE distributors
    ALTER COLUMN address TYPE varchar(80),
    ALTER COLUMN name TYPE varchar(100);
.sp
.fi
.PP
USING句を使用して、Unixタイムスタンプを持つinteger型の列を\fBtimestamp with time zone\fRに変更します。
.sp
.nf
ALTER TABLE foo
    ALTER COLUMN foo_timestamp TYPE timestamp with time zone
    USING
        timestamp with time zone 'epoch' + foo_timestamp * interval '1 second';
.sp
.fi
.PP
上と同じです。
ただし、その列は、自動的に新しいデータ型にキャストされないデフォルト式を持ちます。
.sp
.nf
ALTER TABLE foo
    ALTER COLUMN foo_timestamp DROP DEFAULT,
    ALTER COLUMN foo_timestamp TYPE timestamp with time zone
    USING
        timestamp with time zone 'epoch' + foo_timestamp * interval '1 second',
    ALTER COLUMN foo_timestamp SET DEFAULT now();
.sp
.fi
.PP
既存の列の名前を変更します。
.sp
.nf
ALTER TABLE distributors RENAME COLUMN address TO city;
.sp
.fi
.PP
既存のテーブルの名前を変更します。
.sp
.nf
ALTER TABLE distributors RENAME TO suppliers;
.sp
.fi
.PP
列に非NULL制約を付与します。
.sp
.nf
ALTER TABLE distributors ALTER COLUMN street SET NOT NULL;
.sp
.fi
列から非NULL制約を削除します。
.sp
.nf
ALTER TABLE distributors ALTER COLUMN street DROP NOT NULL;
.sp
.fi
.PP
テーブルにCHECK制約を付与します。
.sp
.nf
ALTER TABLE distributors ADD CONSTRAINT zipchk CHECK (char_length(zipcode) = 5);
.sp
.fi
.PP
テーブルとその子テーブルからCHECK制約を削除します。
.sp
.nf
ALTER TABLE distributors DROP CONSTRAINT zipchk;
.sp
.fi
.PP
テーブルに外部キー制約を付与します。
.sp
.nf
ALTER TABLE distributors ADD CONSTRAINT distfk FOREIGN KEY (address) REFERENCES addresses (address) MATCH FULL;
.sp
.fi
.PP
テーブルに（複数列の）一意性制約を付与します。
.sp
.nf
ALTER TABLE distributors ADD CONSTRAINT dist_id_zipcode_key UNIQUE (dist_id, zipcode);
.sp
.fi
.PP
自動的に命名されるプライマリキー制約をテーブルに付与します。 
1つのテーブルが持てるプライマリキーは1つだけであることに注意してください。
.sp
.nf
ALTER TABLE distributors ADD PRIMARY KEY (dist_id);
.sp
.fi
.PP
テーブルを別のテーブル空間に移動します。
.sp
.nf
ALTER TABLE distributors SET TABLESPACE fasttablespace;
.sp
.fi
.PP
テーブルを別のスキーマに移動します。
.sp
.nf
ALTER TABLE myschema.distributors SET SCHEMA yourschema;
.sp
.fi
.SH "互換性"
.PP
ADD、DROP、SET DEFAULT構文は標準SQLに従います。
他の構文は標準SQLに対するPostgreSQLの拡張です。
また、単一の\fBALTER TABLE\fRコマンド内に複数の操作を指定する機能もPostgreSQLの拡張です。
.PP
\fBALTER TABLE DROP COLUMN\fRを使って、1つしか列がないテーブルから列を削除して、列がないテーブルを作成することができます。
これはPostgreSQLの拡張です。SQLでは、列を持たないテーブルは認められていません。
