.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP SCHEMA" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
DROP SCHEMA \- スキーマを削除する

.SH SYNOPSIS
.sp
.nf
DROP SCHEMA [ IF EXISTS ] \fIname\fR [, ...] [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBDROP SCHEMA\fRはデータベースからスキーマを削除します。
.PP
スキーマを削除できるのは、所有者またはスーパーユーザのみです。 
所有者は、スキーマ内に自分が所有していないオブジェクトが含まれていても、そのスキーマ（およびそこに含まれる全てのオブジェクト）を削除できます。
.SH "パラメータ"
.TP
\fBIF EXISTS\fR
スキーマが存在しない場合でもエラーになりません。
この場合注意メッセージが発行されます。
.TP
\fB\fIname\fB\fR
スキーマの名前です。
.TP
\fBCASCADE\fR
スキーマに含まれるオブジェクト（テーブル、関数など）を自動的に削除します。
.TP
\fBRESTRICT\fR
スキーマにオブジェクトが含まれている場合は、スキーマの削除を拒否します。
こちらがデフォルトです。
.SH "例"
.PP
データベースからmystuffスキーマ、およびそこに含まれる全てのオブジェクトを削除します。
.sp
.nf
DROP SCHEMA mystuff CASCADE;
.sp
.fi
.SH "互換性"
.PP
標準SQLでは一度のコマンド実行につき1つのスキーマしか削除できないという点を除き、および、PostgreSQLの拡張であるIF EXISTSを除き、\fBDROP SCHEMA\fRは、標準SQLと完全な互換性を持ちます。
.SH "関連項目"
ALTER SCHEMA [\fBalter_schema\fR(l)], CREATE SCHEMA [\fBcreate_schema\fR(l)]
