.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP TYPE" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
DROP TYPE \- データ型の削除

.SH SYNOPSIS
.sp
.nf
DROP TYPE [ IF EXISTS ] \fIname\fR [, ...] [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBDROP TYPE\fRはユーザ定義型を削除します。
データ型を削除できるのは、その所有者のみです。
.SH "パラメータ"
.TP
\fBIF EXISTS\fR
型が存在しない場合でもエラーになりません。
この場合、注意メッセージが発行されます。
.TP
\fB\fIname\fB\fR
削除するデータ型の名前です（スキーマ修飾名も可）。
.TP
\fBCASCADE\fR
削除するデータ型に依存するオブジェクト（テーブルの列、関数、演算子など）を自動的に削除します。
.TP
\fBRESTRICT\fR
依存しているオブジェクトがある場合に、データ型の削除を拒否します。
こちらがデフォルトです。
.SH "例"
.PP
\fBbox\fRデータ型を削除します。
.sp
.nf
DROP TYPE box;
.sp
.fi
.SH "互換性"
.PP
このコマンドは、PostgreSQLの拡張であるIF EXISTSオプションを除き、標準SQL内の対応するコマンドと似ています。
しかし、PostgreSQLの\fBCREATE TYPE\fRコマンドとデータ型拡張機構は標準SQLとは異なる点に注意してください。
.SH "関連項目"
CREATE TYPE [\fBcreate_type\fR(l)], ALTER TYPE [\fBalter_type\fR(l)]
