.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "BEGIN" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
BEGIN \- トランザクションブロックを開始する

.SH SYNOPSIS
.sp
.nf
BEGIN [ WORK | TRANSACTION ] [ \fItransaction_mode\fR [, ...] ]

\fItransaction_mode\fRは以下のいずれかです。

    ISOLATION LEVEL { SERIALIZABLE | REPEATABLE READ | READ COMMITTED | 
    READ UNCOMMITTED }
    READ WRITE | READ ONLY
.sp
.fi
.SH "説明"
.PP
\fBBEGIN\fRはトランザクションブロックを初期化します。
\fBBEGIN\fRコマンド以降の文は全て、明示的なCOMMIT [\fBcommit\fR(l)]もしくはROLLBACK [\fBrollback\fR(l)]が与えられるまで、単一のトランザクションの中で実行されます。
デフォルト（\fBBEGIN\fRがない場合）は、PostgreSQLはトランザクションを``自動コミット''で実行します。
つまり、各文はそれぞれ固有のトランザクションの中で実行され、文の終わりで暗黙的にコミットが実行されます（これは実行が成功した場合です。失敗した場合はロールバックされます）。
.PP
トランザクションブロック内では、文はより迅速に実行されます。
なぜなら、トランザクションの開始やコミットは、CPUとディスクにかなり高い負荷をかけるからです。
また、1つのトランザクションで複数の文を実行することは、複数の関連するテーブルを更新する際、確実に一貫性を保つためにも役立ちます。
関連する更新の中に完了していないものが存在する中間的な状態が、他のセッションから参照できなくなるからです。
.PP
隔離レベルもしくは読み書きモードが指定されている場合、新しいトランザクションは、SET TRANSACTION [\fBset_transaction\fR(l)]が実行された時と同様の特性を持ちます。
.SH "パラメータ"
.TP
\fBWORK\fR
.TP
\fBTRANSACTION\fR
省略可能なキーワードです。これらは何も効果がありません。
.PP
BEGIN文のこの他のパラメータについては、SET TRANSACTION [\fBset_transaction\fR(l)]を参照してください。
.PP
.SH "注釈"
.PP
START TRANSACTION [\fBstart_transaction\fR(l)]には、\fBBEGIN\fRと同じ機能があります。
.PP
トランザクションを終了させるには、COMMIT [\fBcommit\fR(l)]またはROLLBACK [\fBrollback\fR(l)]を使用してください。
.PP
トランザクションブロック内で\fBBEGIN\fRを発行すると、警告メッセージが表示されます。
ただし、トランザクションの状態には影響ありません。
トランザクションブロック内でトランザクションを入れ子にするには、セーブポイントを使用してください
（詳しくはSAVEPOINT [\fBsavepoint\fR(l)]を参照してください）。
.PP
後方互換性の保持のため、連続する\fItransaction_modes\fR間のカンマは省略することができます。
.SH "例"
.PP
トランザクションブロックを開始します。
.sp
.nf
BEGIN;
.sp
.fi
.SH "互換性"
.PP
\fBBEGIN\fRはPostgreSQLの拡張です。
標準SQLのSTART TRANSACTION [\fBstart_transaction\fR(l)]コマンドと等価です。
こちらにさらに詳細な互換性についての情報があります。
.PP
埋め込みSQLでは、BEGINというキーワードを異なった目的に使用しています。
データベースアプリケーションを移植する時は、トランザクションの意味で使用されているのかどうかに注意してください。
.SH "関連項目"
COMMIT [\fBcommit\fR(l)], ROLLBACK [\fBrollback\fR(l)], START TRANSACTION [\fBstart_transaction\fR(l)], SAVEPOINT [\fBsavepoint\fR(l)]
