.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "RELEASE SAVEPOINT" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
RELEASE SAVEPOINT \- 設定済みのセーブポイントを破棄する

.SH SYNOPSIS
.sp
.nf
RELEASE [ SAVEPOINT ] \fIsavepoint_name\fR
.sp
.fi
.SH "説明"
.PP
\fBRELEASE SAVEPOINT\fRは、現在のトランザクションで事前に設定されていたセーブポイントを破棄します。
.PP
セーブポイントを破棄すると、ロールバックするポイントとして使用できなくなります。
他にユーザの目に付くような動作はありません。
このコマンドは、セーブポイントの設定後に実行されたコマンドの効果を取り消すわけではありません
（これを行う方法はROLLBACK TO SAVEPOINT [\fBrollback_to_savepoint\fR(l)]を参照してください）。
不要になったセーブポイントを破棄することにより、システムがトランザクションの終了前に多少のリソースを回収することができます。
.PP
また、\fBRELEASE SAVEPOINT\fRが実行されると、指定したセーブポイントの後に設定されたセーブポイントは全て破棄されます。
.SH "パラメータ"
.TP
\fB\fIsavepoint_name\fB\fR
破棄するセーブポイントの名前です。
.SH "注釈"
.PP
設定されていないセーブポイント名を指定するとエラーになります。
.PP
トランザクションがアボート状態の時には、セーブポイントを解放することはできません。
.PP
同じ名前のセーブポイントが複数存在する場合、最後に設定されたセーブポイントが解放されます。
.SH "例"
.PP
セーブポイントを設定し、その後、破棄します。
.sp
.nf
BEGIN;
    INSERT INTO table1 VALUES (3);
    SAVEPOINT my_savepoint;
    INSERT INTO table1 VALUES (4);
    RELEASE SAVEPOINT my_savepoint;
COMMIT;
.sp
.fi
上記のトランザクションでは、3と4の両方が挿入されます。
.SH "互換性"
.PP
このコマンドは標準SQLに準拠しています。
SQL:2003標準では、SAVEPOINTは必須であると規定されています。
PostgreSQLではSAVEPOINTキーワードを省略することができます。
.SH "関連項目"
BEGIN [\fBbegin\fR(l)], COMMIT [\fBcommit\fR(l)], ROLLBACK [\fBrollback\fR(l)], ROLLBACK TO SAVEPOINT [\fBrollback_to_savepoint\fR(l)], SAVEPOINT [\fBsavepoint\fR(l)]
