.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CREATE CONSTRAINT TRIGGER" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
CREATE CONSTRAINT TRIGGER \- 新しい制約トリガを定義する

.SH SYNOPSIS
.sp
.nf
CREATE CONSTRAINT TRIGGER \fIname\fR
    AFTER \fIevent [ OR ... ]\fR
    ON \fItable_name\fR
    [ FROM \fIreferenced_table_name\fR ]
    { NOT DEFERRABLE | [ DEFERRABLE ] { INITIALLY IMMEDIATE | INITIALLY DEFERRED } }
    FOR EACH ROW
    EXECUTE PROCEDURE \fIfuncname\fR ( \fIarguments\fR )
.sp
.fi
.SH "説明"
.PP
\fBCREATE CONSTRAINT TRIGGER\fRは、\fBCREATE TABLE\fR/\fBALTER TABLE\fRの中、または\fBpg_dump\fRによって使用され、参照整合性用の特殊なトリガを作成します。
一般的な使用を意図したものではありません。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
制約トリガの名前です。
作成されるトリガの実際の名前はRI_ConstraintTrigger_0000といった形になります（ここで0000はサーバから割り振られるなんらかの数字です）。
トリガを削除する場合は、割り当てられた名前を使用してください。
.TP
\fB\fIevent\fB\fR
INSERT、UPDATE、DELETEのいずれかです。
これはトリガを発行するイベントを指定するものです。
ORを使用して複数のイベントを指定することができます。
.TP
\fB\fItable_name\fB\fR
トリガイベントが発生するテーブルの名前です（スキーマ修飾可）。
.TP
\fB\fIreferenced_table_name\fB\fR
この制約により参照されるテーブルの名前です（スキーマ修飾可）。
外部キー制約トリガによって使用されます。
.TP
\fBDEFERRABLE\fR
.TP
\fBNOT DEFERRABLE\fR
.TP
\fBINITIALLY IMMEDIATE\fR
.TP
\fBINITIALLY DEFERRED\fR
これらの制約オプションについてはCREATE TABLE [\fBcreate_table\fR(l)]を参照してください。
.TP
\fB\fIfuncname\fB(\fIargs\fB)\fR
トリガ処理の一部として呼び出される関数です。
CREATE TRIGGER [\fBcreate_trigger\fR(l)]を参照してください。
.SH "互換性"
.PP
\fBCREATE CONTRAINT TRIGGER\fRは、標準SQLに対するPostgreSQLの拡張です。
