.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "REVOKE" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
REVOKE \- アクセス権限を取り消す

.SH SYNOPSIS
.sp
.nf
REVOKE [ GRANT OPTION FOR ]
    { { SELECT | INSERT | UPDATE | DELETE | REFERENCES | TRIGGER }
    [,...] | ALL [ PRIVILEGES ] }
    ON [ TABLE ] \fItablename\fR [, ...]
    FROM { \fIusername\fR | GROUP \fIgroupname\fR | PUBLIC } [, ...]
    [ CASCADE | RESTRICT ]

REVOKE [ GRANT OPTION FOR ]
    { { USAGE | SELECT | UPDATE }
    [,...] | ALL [ PRIVILEGES ] }
    ON SEQUENCE \fIsequencename\fR [, ...]
    FROM { \fIusername\fR | GROUP \fIgroupname\fR | PUBLIC } [, ...]
    [ CASCADE | RESTRICT ]

REVOKE [ GRANT OPTION FOR ]
    { { CREATE | CONNECT | TEMPORARY | TEMP } [,...] | ALL [ PRIVILEGES ] }
    ON DATABASE \fIdbname\fR [, ...]
    FROM { \fIusername\fR | GROUP \fIgroupname\fR | PUBLIC } [, ...]
    [ CASCADE | RESTRICT ]

REVOKE [ GRANT OPTION FOR ]
    { EXECUTE | ALL [ PRIVILEGES ] }
    ON FUNCTION \fIfuncname\fR ( [ [ \fIargmode\fR ] [ \fIargname\fR ] \fIargtype\fR [, ...] ] ) [, ...]
    FROM { \fIusername\fR | GROUP \fIgroupname\fR | PUBLIC } [, ...]
    [ CASCADE | RESTRICT ]

REVOKE [ GRANT OPTION FOR ]
    { USAGE | ALL [ PRIVILEGES ] }
    ON LANGUAGE \fIlangname\fR [, ...]
    FROM { \fIusername\fR | GROUP \fIgroupname\fR | PUBLIC } [, ...]
    [ CASCADE | RESTRICT ]

REVOKE [ GRANT OPTION FOR ]
    { { CREATE | USAGE } [,...] | ALL [ PRIVILEGES ] }
    ON SCHEMA \fIschemaname\fR [, ...]
    FROM { \fIusername\fR | GROUP \fIgroupname\fR | PUBLIC } [, ...]
    [ CASCADE | RESTRICT ]

REVOKE [ GRANT OPTION FOR ]
    { CREATE | ALL [ PRIVILEGES ] }
    ON TABLESPACE \fItablespacename\fR [, ...]
    FROM { \fIusername\fR | GROUP \fIgroupname\fR | PUBLIC } [, ...]
    [ CASCADE | RESTRICT ]

REVOKE [ ADMIN OPTION FOR ]
    \fIrole\fR [, ...] FROM \fIusername\fR [, ...]
    [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBREVOKE\fRコマンドは、1つ以上のロールに対して、以前に与えた権限を取り消します。
PUBLICキーワードは暗黙的に定義された全ロールからなるグループです。
.PP
権限の種類の意味についてはGRANT [\fBgrant\fR(l)]コマンドの説明を参照してください。
.PP
全てのロールは、そのロールに直接許可された権限、現在属しているロールに許可された権限、PUBLICに許可された権限という3つの権限を合わせた権限を持っていることに注意してください。
したがって、例えば、PUBLICからSELECT権限を取り消すことは、必ずしも全てのロールがそのオブジェクトに対するSELECT権限を失うことを意味しません。
権限が直接許可されているロール、あるいは、別ロール経由で許可されているロールは、SELECT権限を持ち続けます。
.PP
GRANT OPTION FORが指定された場合、権限自体ではなく、その権限のグラントオプションのみが取り消されます。
指定されていなければ、権限とグラントオプションの両方が取り消されます。
.PP
グラントオプション付きの権限を保持しているユーザが、その権限を他ユーザに与えていた場合、与えられたユーザが保持する権限は依存権限と呼ばれます。
権限を与えたユーザ自身の権限やグラントオプションが取り消された時、その権限に依存権限が存在する場合、CASCADEが指定されていると依存権限も取り消されます。指定されていなければ、権限の取り消しが失敗します。
この再帰的な権限の取り消しは、ユーザ権限の連鎖を通じて与えられた権限の中でも、REVOKEを実行されたユーザから追跡可能な範囲にのみ影響します。
したがって、依存権限を持つユーザが他のユーザからも同じ権限を与えられている場合は、REVOKEが実行された後もその権限を保持している可能性があります。
.PP
ロールのメンバ資格を取り消す場合、同様に振舞いますが、GRANT OPTIONではなくADMIN OPTIONが呼び出されます。
また、このコマンド構文では無意味なGROUPという単語を受け付けないことに注意してください。
.SH "注釈"
.PP
既存オブジェクトに付与された権限を表示するには\fBpsql\fR(1)の\fB\\z\fRコマンドを使用してください。
この書式についてはGRANT [\fBgrant\fR(l)]を参照してください。
.PP
取り消すことができるのは、ユーザが直接付与した権限のみです。
例えば、もし、ユーザAがグラントオプションを付けてユーザBに権限を与え、その後、ユーザBがユーザCにその権限を与えたとすると、ユーザAはユーザCの権限を直接取り消すことはできません。
その代わり、ユーザAがユーザBのグラントオプションをCASCADEオプション付きで取り消すことで、ユーザCに与えられた権限を取り消すことができます。
別の状況を考えてみます。AとBの両方が同じ権限をCに与えた場合、AはAの与えた権限を取り消すことはできますが、Bの与えた権限を取り消すことはできません。
したがって、Cは実質的にその権限を持ち続けることになります。
.PP
オブジェクトの所有者以外がそのオブジェクト上の権限に対して\fBREVOKE\fRを実行した場合、ユーザがオブジェクトに対して何の権限も持っていなければ、即座にコマンドが失敗します。
何らかの権限があればコマンド処理が続行されますが、取り消すことができるのはそのユーザがグラントオプションを持つ権限のみです。
\fBREVOKE ALL PRIVILEGES\fR構文をまったく権限を持たない状態で実行すると、警告が出力されます。
他の構文の場合は、そのコマンドで指名した権限に対するグラントオプションを持たない状態で実行すると、警告が出力されます
（原理上、上記の説明はオブジェクト所有者にも適用されますが、所有者は常に全てのグラントオプションを保持しているので、こうした問題が発生することはありません）。
.PP
スーパーユーザが\fBGRANT\fRや\fBREVOKE\fRコマンドを発行した場合、そのコマンドは、対象のオブジェクトの所有者によって発行されものであるかのように動作します。
根本的には全ての権限はオブジェクトの所有者から渡されるものなので（ただし、グラントオプションの連鎖により間接的に渡される場合もありますが）、スーパーユーザは、全ての権限を取り消すことができます。
ただし、この場合は上述のCASCADEを使用する必要があります。
.PP
\fBREVOKE\fRおよび\fBREVOKE\fRは、影響するオブジェクトの所有者以外のロールによって実行することもできますが、
オブジェクトを所有するロールのメンバであるか、そのオブジェクトに対しWITH GRANT OPTION権限を持つロールのメンバでなければなりません。
この場合、
そのオブジェクトの実際の所有者ロールまたはWITH GRANT OPTION権限を持つロールによって発行されたかのように、このコマンドは実行されます。
例えば、t1テーブルがg1ロールによって所有され、u1がg1ロールのメンバであるとします。
この場合、u1はg1で付与されたものと記録されている権限を取り上げることができます。
これには、u1が付与した権限とg1ロールの他のメンバによって付与された権限が含まれます。
.PP
\fBREVOKE\fRを実行したロールが、ロールの持つ複数メンバ資格の経路を通して間接的に必要な権限を持つ場合、
どのロールが権限を付与したロールとして記録されるかについては指定されません。
こうした場合、\fBSET ROLE\fRを使用して、\fBREVOKE\fRを行わせたい特定のロールになることを推奨します。
こうしないと、意図しないロールによって権限を取り上げることになったり、取り上げ辞退が失敗することになったりします。
.SH "例"
.PP
publicに与えたfilmsテーブルに対する挿入権限を取り消します。
.sp
.nf
REVOKE INSERT ON films FROM PUBLIC;
.sp
.fi
.PP
kindsビューから、manuelユーザに与えた全ての権限を取り上げます。
.sp
.nf
  
REVOKE ALL PRIVILEGES ON kinds FROM manuel;
.sp
.fi
これは``自分が与えた全ての権限を取り消す''ことを意味します。
.PP
ユーザjoeからロールadmins内のメンバ資格を取り上げます。
.sp
.nf
REVOKE admins FROM joe;
.sp
.fi
.SH "互換性"
.PP
GRANT [\fBgrant\fR(l)]コマンドの互換性についての注釈は\fBREVOKE\fRにも当てはまります。
構文の要約を以下に示します。
.sp
.nf
REVOKE [ GRANT OPTION FOR ] \fIprivileges\fR
    ON \fIobject\fR [ ( \fIcolumn\fR [, ...] ) ]
    FROM { PUBLIC | \fIusername\fR [, ...] }
    { RESTRICT | CASCADE }
.sp
.fi
標準では、RESTRICTかCASCADEのどちらかが必須です。
しかし、PostgreSQLではデフォルトでRESTRICTと仮定されます。
.SH "関連項目"
GRANT [\fBgrant\fR(l)]
