.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP DOMAIN" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
DROP DOMAIN \- ドメインを削除する

.SH SYNOPSIS
.sp
.nf
DROP DOMAIN [IF EXISTS ] \fIname\fR [, ...]  [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBDROP DOMAIN\fRはドメインを削除します。
ドメインを削除できるのは、ドメインの所有者のみです。
.SH "パラメータ"
.TP
\fBIF EXISTS\fR
ドメインが存在しない場合でもエラーになりません。
この場合注意メッセージが発行されます。
.TP
\fB\fIname\fB\fR
既存のドメインの名前です（スキーマ修飾名も可）。
.TP
\fBCASCADE\fR
ドメインに依存するオブジェクト（テーブルの列など）を自動的に削除します。
.TP
\fBRESTRICT\fR
依存しているオブジェクトがある場合、そのドメインの削除要求を拒否します。
これがデフォルトです。
.SH "例"
.PP
\fBbox\fRドメインを削除します。
.sp
.nf
DROP DOMAIN box;
.sp
.fi
.SH "互換性"
.PP
このコマンドは、PostgreSQLの拡張であるIF EXISTSオプションを除き、標準SQLに準拠しています。
.SH "関連項目"
CREATE DOMAIN [\fBcreate_domain\fR(l)], ALTER DOMAIN [\fBalter_domain\fR(l)]
