.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP DATABASE" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
DROP DATABASE \- データベースを削除する

.SH SYNOPSIS
.sp
.nf
DROP DATABASE [ IF EXISTS ] \fIname\fR
.sp
.fi
.SH "説明"
.PP
\fBDROP DATABASE\fRは、データベースを削除します。
そのデータベースの項目をカタログから削除し、データを保存していたディレクトリを削除します。
データベースの所有者のみがこのコマンドを実行することができます。
また、このコマンドを実行しようとしているユーザ自身や他のユーザが、対象とするデータベースに接続している時は実行できません
（このコマンドを実行する時は、postgresや他のデータベースに接続してください）。
.PP
\fBDROP DATABASE\fRは元に戻すことができません。
十分注意して使用してください。
.SH "パラメータ"
.TP
\fBIF EXISTS\fR
データベースが存在しない場合でもエラーになりません。
この場合注意メッセージが発行されます。
.TP
\fB\fIname\fB\fR
削除するデータベースの名前です。
.SH "注釈"
.PP
\fBDROP DATABASE\fRはトランザクションブロックの内部では実行できません。
.PP
対象とするデータベースに接続している間は、このコマンドを実行することができません。
したがって、このコマンドのラッパであるdropdb [\fBdropdb\fR(1)]プログラムを使用する方がより便利であるかもしれません。
.SH "互換性"
.PP
標準SQLには\fBDROP DATABASE\fR文はありません。
.SH "関連項目"
CREATE DATABASE [\fBcreate_database\fR(l)]
