.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "RESET" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
RESET \- 実行時パラメータの値をデフォルト値に戻す

.SH SYNOPSIS
.sp
.nf
RESET \fIconfiguration_parameter\fR
RESET ALL
.sp
.fi
.SH "説明"
.PP
\fBRESET\fRは実行時パラメータをデフォルト値に戻します。
\fBRESET\fRは下記のように記述することもできます。
.sp
.nf
SET \fIconfiguration_parameter\fR TO DEFAULT
.sp
.fi
詳細はSET [\fBset\fR(l)]を参照してください。
.PP
デフォルト値とは、現行セッション内で\fBSET\fRコマンドが発行されなかった場合に変数が保持していた値として定義されます。
デフォルト値は、コンパイル時に指定したデフォルト、設定ファイル、コマンドラインオプション、データベースごと、ユーザごとのデフォルト設定のいずれかを元にしています。
詳細はin the documentationを参照してください。
.PP
\fBRESET\fRのトランザクションでの振舞いの詳細は、\fBSET\fRマニュアルページを参照してください。
.SH "パラメータ"
.TP
\fB\fIconfiguration_parameter\fB\fR
実行時パラメータの名前です。
一覧についてはSET [\fBset\fR(l)]を参照してください。
.TP
\fBALL\fR
設定可能な全ての実行時パラメータをデフォルト値に戻します。
.SH "例"
.PP
geqo設定変数をデフォルト値に設定します。
.sp
.nf
RESET geqo;
.sp
.fi
.SH "互換性"
.PP
\fBRESET\fRはPostgreSQLの拡張です。
