.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER OPERATOR CLASS" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
ALTER OPERATOR CLASS \- 演算子クラスの定義を変更する

.SH SYNOPSIS
.sp
.nf
ALTER OPERATOR CLASS \fIname\fR USING \fIindex_method\fR RENAME TO \fInewname\fR
ALTER OPERATOR CLASS \fIname\fR USING \fIindex_method\fR OWNER TO \fInewowner\fR
.sp
.fi
.SH "説明"
.PP
\fBALTER OPERATOR CLASS\fRは演算子クラスの定義を変更します。
.PP
\fBALTER OPERATOR CLASS\fRを使用するには演算子クラスの所有者でなければなりません。
所有者を変更するには、直接または間接的に新しい所有者ロールのメンバでなければなりません。
また、そのロールが演算子クラスのスキーマにおいてCREATEを持たなければなりません。
（この制限により、強制的に、所有者の変更が演算子クラスの削除と再作成で行うことができない何らかの処理を行わないようになります。
しかし、スーパーユーザはすべての演算子クラスの所有者を変更することができます。）
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
既存の演算子クラスの名前です（スキーマ修飾名も可）。
.TP
\fB\fIindex_method\fB\fR
演算子クラス用のインデックスメソッドの名前です。
.TP
\fB\fInewname\fB\fR
新しい演算子クラス名です。
.TP
\fB\fInewowner\fB\fR
新しい演算子クラスの所有者です。
.SH "互換性"
.PP
標準SQLには\fBALTER OPERATOR CLASS\fR文はありません。
.SH "関連項目"
CREATE OPERATOR CLASS [\fBcreate_operator_class\fR(l)], DROP OPERATOR CLASS [\fBdrop_operator_class\fR(l)]
