.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP USER" "" "2007-05-04" "SQL - 言語" "SQLコマンド"
.SH NAME
DROP USER \- データベースロールを削除する

.SH SYNOPSIS
.sp
.nf
DROP USER [ IF EXISTS ] \fIname\fR [, ...]
.sp
.fi
.SH "説明"
.PP
\fBDROP USER\fRはDROP ROLE [\fBdrop_role\fR(l)]の別名となりました。詳細はDROP ROLE [\fBdrop_role\fR(l)]を参照してください。
.SH "互換性"
.PP
\fBDROP USER\fR文はPostgreSQLの拡張です。 
標準SQLでは、ユーザの定義は実装に任されています。
.SH "関連項目"
DROP ROLE [\fBdrop_role\fR(l)]
